Ext.define('documentation.mixins.Component', {TR:function(key) {
  return documentation.Support.TR(key);
}, getCacheFromBoth:function(key) {
  return documentation.util.State.get(key) || documentation.util.SessionState.get(key);
}, dataToString:function(data) {
  return documentation.Module.xmlSerializer.serializeToString(data);
}, defaultDockTb:function(dock) {
  return {xtype:'toolbar', padding:this.paddedIntString(5), dock:dock};
}, faIcon:function(cls) {
  return documentation.Support.faIcon(cls);
}, getSetting:function(id) {
  return BpcCommon.Api.getSetting(this.moduleId, id);
}, getLanguage:function() {
  return BpcCommon.Api.getSetting('_core', 'language');
}, newLocalStore:function(data) {
  return documentation.Support.newLocalStore(data);
}, spacerCfg:function(height) {
  height = height === void 0 ? 5 : height;
  return {xtype:'tbspacer', height:height};
}, showInfoItem:function(text) {
  text = text === void 0 ? '' : text;
  var isString = typeof text === 'string';
  var notificationItem = isString ? this.TR(text) : text;
  BpcCommon.Api.showNotification(notificationItem);
}, getDiagramRoute:function() {
  return documentation.util.Url.getDiagramRoute();
}, doCopy:function(str, trKey) {
  str = str === void 0 ? '' : str;
  var copyRes = documentation.Support.copyToClp(str, this);
  if (trKey) {
    this.showInfoItem(trKey);
    return;
  }
  return copyRes;
}, dataDefined:function(data) {
  if (typeof data === 'undefined') {
    return false;
  }
  if (Array.isArray(data)) {
    return data.filter(function(i) {
      return typeof i !== 'undefined';
    }).length === data.length;
  }
  if (typeof data === 'string') {
    return true;
  }
}, delay:function(time) {
  time = time === void 0 ? 1000 : time;
  return documentation.Module.delay(time);
}, isReadyForStates:false, instanceStateId:undefined, makeStateful:function(id) {
  var $jscomp$this = this;
  if (id) {
    this.instanceStateId = id;
  }
  this.delay().then(function() {
    $jscomp$this.isReadyForStates = true;
    console.debug('isReadyForStates: ' + $jscomp$this.instanceStateId, $jscomp$this);
  });
}, getLocal:function(id) {
  return documentation.util.State.get(id);
}, doGetStateData:undefined, saveLocal:function(id, data) {
  if (this.isReadyForStates) {
    if (this.dataDefined([id, data]) === false && this.dataDefined(this.instanceStateId)) {
      if (!this.doGetStateData) {
        return;
      }
      id = this.instanceStateId;
      data = this.doGetStateData();
    }
    documentation.util.State.set(id, data);
  }
}, paddedIntString:function() {
  var args = $jscomp.getRestArguments.apply(0, arguments);
  return documentation.util.String.paddedIntString.apply(documentation.util.String, $jscomp.arrayFromIterable(args));
}});
Ext.define('documentation.Support', {singleton:true, mixins:['BpcCommon.mixin.BpcModuleUtilsMixin', 'BpcCommon.mixins.Support'], faIcon:function(cls) {
  return BpcCommon.util.Icons.getBpcIconCls(cls);
}, getWindow:function(title, iconCls, cmpAlias, cmpConfig, stateId) {
  title = title === void 0 ? '' : title;
  iconCls = iconCls === void 0 ? 'fa-info' : iconCls;
  var w = Ext.create({xtype:'documentationWindow', constrain:true, title:this.TR(title) || '', height:document.body.clientHeight * 0.8, width:document.body.clientWidth * 0.6, layout:'fit', iconCls:this.faIcon(iconCls || 'fa-info'), listeners:{resize:function(c) {
    return c.saveLocal();
  }, move:function(c) {
    return c.saveLocal();
  }, boxready:function(c) {
    if (stateId) {
      c.makeStateful(stateId);
    }
  }}});
  cmpConfig = cmpConfig || {};
  cmpConfig.windowReference = w;
  cmpConfig.closeWindow = function() {
    w.close();
  };
  w.add(Ext.create(Ext.apply({xtype:cmpAlias}, cmpConfig)));
  return w;
}, decode:function(str) {
  str = str === void 0 ? '' : str;
  try {
    return JSON.parse(str);
  } catch (e) {
    return null;
  }
}, exportName:function(prefix, ending) {
  prefix = prefix === void 0 ? 'BPC_Doc_' : prefix;
  ending = ending === void 0 ? '.pdf' : ending;
  return [prefix, Date.now(), ending].join('');
}, newLocalStore:function(data) {
  data = data === void 0 ? [] : data;
  return Ext.create('Ext.data.Store', {data:data});
}, getSortArrayFunction:function(propA, propB, lowerCase) {
  propA = propA === void 0 ? 'text' : propA;
  propB = propB === void 0 ? 'text' : propB;
  lowerCase = lowerCase === void 0 ? true : lowerCase;
  return function(a, b) {
    a = a[propA];
    b = b[propB];
    if (lowerCase) {
      a = a.toLowerCase();
      b = b.toLowerCase();
    }
    if (a < b) {
      return -1;
    } else if (a > b) {
      return 1;
    } else {
      return 0;
    }
  };
}, getWorkflowName:function(name, isSingular) {
  name = name === void 0 ? '' : name;
  var trKey;
  name = name || '';
  if (name === 'bpd') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_BPD';
  }
  if (name === 'technical') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_TW';
  }
  if (name === 'soamap') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_SM';
  }
  if (name === 'systemdiagram') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_SD';
  }
  if (name === 'organigram') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_OD';
  }
  if (name === 'processmap') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_PM';
  }
  if (name === 'constraintsdiagram') {
    trKey = 'DOCUMENTATION_DIAGRAM_TYPE_BOD';
  }
  if (trKey && isSingular) {
    trKey += '_SING';
  }
  return BpcCommon.Api.getTranslation(trKey);
}, secondConversion:function(seconds) {
  if (seconds == 0) {
    return '';
  }
  var secondsDay = 24 * 60 * 60;
  var secondsHour = 60 * 60;
  var tailHours = seconds % secondsDay;
  var days = (seconds - tailHours) / secondsDay;
  var tailMinutes = tailHours % secondsHour;
  var hours = (tailHours - tailMinutes) / secondsHour;
  seconds = tailMinutes % 60;
  var minutes = (tailMinutes - seconds) / 60;
  return (days > 0 ? days + 'd ' : '') + (hours > 0 ? hours + 'h ' : '') + (minutes > 0 ? minutes + 'm ' : '') + (seconds + 's');
}, onlyOneWindowOpen:true, closeAllMetaDialogs:function() {
  var windows = Ext.ComponentQuery.query('documentationMetaWindow');
  if (windows.length) {
    windows.map(function(w) {
      return w.close();
    });
  }
}, createMetaWindow:function(parentCmp, title) {
  var $jscomp$destructuring$var0 = parentCmp;
  var wfModule = $jscomp$destructuring$var0.wfModule;
  var moduleId = $jscomp$destructuring$var0.moduleId;
  wfModule = wfModule || {};
  var windowConfig = {wfModule:wfModule, parentCmp:parentCmp, moduleId:moduleId, width:document.body.clientWidth * 0.6, moduleInstance:(parentCmp || {}).moduleInstance, title:title};
  var state = documentation.util.State.getWindowState(), position = undefined;
  if (state) {
    var hasUndefinedProperties = Object.keys(function(k) {
      return typeof state[k] === 'undefined';
    }).indexOf(true) !== -1;
    var validState = !hasUndefinedProperties;
    var $jscomp$destructuring$var1 = state;
    var width = $jscomp$destructuring$var1.width;
    var winX = $jscomp$destructuring$var1.winX;
    var winY = $jscomp$destructuring$var1.winY;
    if (validState) {
      Object.assign(windowConfig, {width:width});
      position = [winX, winY];
    }
  }
  if (this.onlyOneWindowOpen) {
    this.closeAllMetaDialogs();
  }
  var win = Ext.createByAlias('widget.documentationMetaWindow', windowConfig);
  this.mayShowWindowAt(win, position);
}, mayShowWindowAt:function(win, position) {
  if (position) {
    win.showAt(position);
    return;
  }
  win.show();
}, copyToClp:function(stringWithNewLines, cmp) {
  try {
    var myFluffyTextarea = document.createElement('textarea');
    myFluffyTextarea.innerHTML = stringWithNewLines;
    var parentElement = document.getElementById(cmp.getId());
    parentElement.appendChild(myFluffyTextarea);
    myFluffyTextarea.select();
    document.execCommand('copy');
    parentElement.removeChild(myFluffyTextarea);
    return true;
  } catch (e) {
    console.debug('copy error', e);
    return false;
  }
}, convertToLinkedDiagramData:function(data) {
  var $jscomp$this = this;
  return data.map(function(item) {
    var data = item || {};
    data.iconCls = item.isBacklink ? 'fa-caret-up' : 'fa-caret-down';
    data.icon = '/bpc-fe-documentation/resources/icons/' + data.WorkflowType + '.png';
    data.linkName = data.WorkflowDisplayName + ' ( ' + $jscomp$this.getWorkflowName(data.WorkflowType, true) + ' )';
    return data;
  });
}, getModuleName:function(wfModule) {
  var $jscomp$destructuring$var2 = wfModule || {};
  var WorkflowLink = $jscomp$destructuring$var2.WorkflowLink;
  var name = $jscomp$destructuring$var2.name;
  var $jscomp$destructuring$var3 = $jscomp.makeIterator(WorkflowLink || []);
  var first = $jscomp$destructuring$var3.next().value;
  var LinkType = first || {};
  return LinkType === 'ConnectionLineLink' || LinkType === 'DataLink' ? '' : name || '';
}});
Ext.define('documentation.widget.Main', {extend:'Ext.panel.Panel', alias:'widget.bpcDocumentationWidget', mixins:['BpcCommon.mixin.Widget', 'documentation.mixins.Component'], statics:{WIDGET_NAME:documentation.Support.TR('DOCUMENTATION_WIDGET_NAME'), WIDGET_DESCRIPTION:documentation.Support.TR('DOCUMENTATION_WIDGET_DESCRIPTION'), WIDGET_ICON_CLS:documentation.Support.faIcon('fa-cloud')}, widgetConfigSettingMap:{moduleId:{settingType:'moduleInstance'}}, config:{widgetConfiguration:{}}, header:false, 
layout:'card', activeItem:0, title:false, moduleId:undefined, initComponent:function() {
  this.initWidgetSettings();
  this.callParent(arguments);
  this.createWidgetWrapper();
  this.settingPanel = this.add({xtype:'bpcSettingPanel', settings:this.settingStore, buttons:[{text:this.TR('ACTION_OK'), ui:'primary', handler:this.configureWidget.bind(this)}]});
  var nextPanel = this.settingPanel;
  if (this.moduleId) {
    this.createWidgetView();
    nextPanel = this.wrapper;
  }
  this.getLayout().setActiveItem(nextPanel);
}, createWidgetWrapper:function() {
  this.wrapper = this.add({xtype:'container', layout:'fit', items:[]});
}, createWidgetView:function() {
  this.wrapper.removeAll();
  this.wrapper.add({xtype:'container', moduleId:this.moduleId, html:'work in progress'});
}, refreshWidget:function() {
}, configureWidget:function() {
  var nextPanel;
  if (this.settingPanel.isVisible(true)) {
    this.createWidgetView();
    nextPanel = this.wrapper;
  } else {
    nextPanel = this.settingPanel;
  }
  this.getLayout().setActiveItem(nextPanel);
}});
Ext.define('documentation.BpcInterface', {extend:'BpcCommon.BpcInterface', requires:['documentation.widget.Main'], config:{moduleConfigurationComponents:[], requiredModules:[], requiredLibraries:['Ace', 'Vkbeautify'], widgets:['documentation.widget.Main']}});
Ext.define('documentation.LegendIconMapping', {singleton:true, basePath:'/bpc-fe-documentation/resources/workflowSymbols/', bpd:{SequenceFlowNone:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SEQUENCE_FLOW'), src:'sequenceflow_normal.gif'}, SequenceFlowDefault:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_DEFAULT_SEQUENCE_FLOW'), 
src:'sequenceflow_default.gif'}, SequenceFlowExpression:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CONDITIONAL_FLOW'), src:'sequenceflow_conditional.gif'}, AssociationBoth:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_BIDIRECTIONAL_ASSOCIATION'), src:'bidirectional_association.gif'}, 
AssociationNone:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_ASSOCIATION'), src:'directed_association.gif'}, ConversationLink:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CONVERSATION'), src:'conversationlink.gif'}, MessageFlow:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_MESSAGE_FLOW'), src:'messageflow.gif'}, PoolHorizontal:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_PROCESS_ACTIVITIES'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_HORIZONTAL_POOL'), src:'pool_horizontal.gif'}, PoolLane:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_PROCESS_ACTIVITIES'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_POOL_LANE'), 
src:'pool_horizontal.gif'}, PoolVertical:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_PROCESS_ACTIVITIES'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_VERTICAL_POOL'), src:'pool_vertical.gif'}, PoolBlackBox:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_PROCESS_ACTIVITIES'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_BLACKBOX_POOL'), src:'pool_blackbox.gif'}, 
CallActivity:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_PROCESS_ACTIVITIES'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CALL_ACTIVITY'), src:'call_activity.gif'}, TaskUser:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_USER'), src:'task_user.gif'}, TaskManual:{group:'Processes And Activities', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_MANUAL'), src:'task_manual.gif'}, TaskBusinessRule:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_BUSINESS_RULE'), src:'task_businessrule.gif'}, TaskScript:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_SCRIPT'), src:'task_script.gif'}, TaskNone:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASKS'), src:'task.gif'}, TaskService:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_SERVICE'), 
src:'task_service.gif'}, TaskSend:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_SEND'), src:'task_send.gif'}, TaskReceive:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TASK'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TASK_RECEIVE'), src:'task_receive.gif'}, SubProcessEvent:{group:'Processes And Activities', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SUB_PROCESS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SUB_PROCESS_EVENT'), src:'event_subprocess.gif'}, SubProcess:{group:'Processes And Activities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SUB_PROCESS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SUB_PROCESS'), src:'subprocess.gif'}, StartEventNone:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT'), src:'start_none.gif'}, StartEventCompensation:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_COMPENSATION'), src:'start_compensation.gif'}, StartEventConditional:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_CONDITIONAL'), 
src:'start_conditional.gif'}, StartEventSignal:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_SIGNAL'), src:'start_signal.gif'}, StartEventMultiple:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_MULTIPLE'), src:'start_multiple.gif'}, StartEventParallelMultiple:{group:'Start Events', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_MULTIPLE_PARALLEL'), src:'start_parallelmultiple.gif'}, StartEventMessage:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_MESSAGE'), src:'start_message.gif'}, StartEventTimer:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_TIMER'), src:'start_timer.gif'}, StartEventError:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_ERROR'), src:'start_error.gif'}, StartEventEscalation:{group:'Start Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_START_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_START_EVENT_ESCALATION'), 
src:'start_escalation.gif'}, IntermediateEventNone:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT'), src:'intermediate_none.gif'}, IntermediateEventEscalation:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_ESCALATION'), 
src:'intermediate_escalation.gif'}, IntermediateEventMultipleThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_MULTIPLE_THROWING'), src:'intermediate_multiple_throwing.gif'}, IntermediateEventEscalationThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_ESCALATION_THROWING'), 
src:'intermediate_escalation_throwing.gif'}, IntermediateEventParallelMultiple:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_PARALLEL_MULTIPLE'), src:'intermediate_parallelmultiple.gif'}, IntermediateEventCancel:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_CANCEL'), 
src:'intermediate_cancel.gif'}, IntermediateEventCompensation:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_COMPENSATION'), src:'intermediate_compensation.gif'}, IntermediateEventCompensationThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_COMPENSATION_THROWING'), 
src:'intermediate_compensation_throwing.gif'}, IntermediateEventConditional:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_CONDITIONAL'), src:'intermediate_conditional.gif'}, IntermediateEventLink:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_LINK'), 
src:'intermediate_link.gif'}, IntermediateEventMessage:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_MESSAGE'), src:'intermediate_message.gif'}, IntermediateEventLinkThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_LINK_THROWING'), 
src:'intermediate_link_throwing.gif'}, IntermediateEventMessageThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_MESSAGE_THROWING'), src:'intermediate_message_throwing.gif'}, IntermediateEventSignal:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_SIGNAL'), 
src:'intermediate_signal.gif'}, IntermediateEventTimer:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_TIMMER'), src:'intermediate_timer.gif'}, IntermediateEventSignalThrowing:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_SIGNAL_THROWING'), 
src:'intermediate_signal_throwing.gif'}, IntermediateEventError:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_ERROR'), src:'intermediate_error.gif'}, IntermediateEventMultiple:{group:'Intermediate Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_INTERMEDIATE_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INTERMEDIATE_EVENT_MULTIPLE'), 
src:'intermediate_multiple.gif'}, StopEventNone:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP'), src:'stop_none.gif'}, StopEventMultiple:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_MULTIPLE'), src:'stop_multiple.gif'}, StopEventError:{group:'End Events', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_ERROR'), src:'stop_error.gif'}, StopEventEscalation:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_ESCALATION'), src:'stop_escalation.gif'}, StopEventCompensation:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_COMPENSATION'), src:'stop_compensation.gif'}, StopEventMessage:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_MESSAGE'), src:'stop_message.gif'}, StopEventSignal:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_SIGNAL'), 
src:'stop_signal.gif'}, StopEventCancel:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_CANCEL'), src:'stop_cancel.gif'}, StopEventTerminate:{group:'End Events', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_STOP_EVENT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_STOP_TERMINATE'), src:'stop_terminate.gif'}, GatewayExclusiveDataBased:{group:'Gateways', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_GATEWAYS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GATEWAY_EXCLUSIVE'), src:'gateway_exclusive_databased.gif'}, GatewayInclusive:{group:'Gateways', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_GATEWAYS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GATEWAY_INCLUSIVE'), src:'gateway_or.gif'}, GatewayComplex:{group:'Gateways', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_GATEWAYS'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GATEWAY_COMPLEX'), src:'gateway_complex.gif'}, GatewayParallel:{group:'Gateways', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_GATEWAYS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GATEWAY_PARALLEL'), src:'gateway_and.gif'}, GatewayExclusiveEventBased:{group:'Gateways', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_GATEWAYS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GATEWAY_EXCLUSIVE_EVENT_BASED'), 
src:'gateway_eventbased.gif'}, DataObject:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_DATA_OBJECT'), src:'data_object.gif'}, DataInput:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_DATA_INPUT'), src:'data_input.gif'}, DataOutput:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_DATA_OUTPUT'), src:'data_output.gif'}, Message:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_MESSAGE'), src:'message.gif'}, TextAnnotation:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TEXT_ANNOTATION'), src:'text_annotation.gif'}, 
Group:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GROUP'), src:'group.gif'}, DataStore:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_DATA_STORE'), src:'data_store.gif'}, Communication:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMMUNICATION'), src:'communication.gif'}, CallConversation:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CALL_CONVERSATION'), src:'call_conversation.gif'}, ChoreographyTask:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CHOREOGRAPHY_TASK'), src:'choreography_task.gif'}, CallChoreographyActivity:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CALL_CHOREOGRAPHY_ACTIVITY'), src:'call_choreography_activity.gif'}, ChoreographySubProcess:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CHOREOGRAPHY_SUB_PROCESS'), src:'choreography_subprocess.gif'}, SubConversation:{group:'Conversation and Choreography', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONVERSATION_CHOREOGRAPHY'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SUB_CONVERSATION'), src:'subconversation.gif'}}, processmap:{Standard:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CONNECTION_LINE'), src:'icon_22x22_processmap_standard_connectionline.gif'}, Comments:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMMENT_CONNECTION'), src:'icon_22x22_processmap_comments_connectionline.gif'}, ProcessMapProcess:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PROCESS'), src:'ProcessMap-tool_process_22.svg'}, ProcessMapProcessGroup:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PROCESS_GROUP'), src:'ProcessMap-tool_process-group_22.svg'}, ProcessMapProcessUser:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PROCESS_USER'), 
src:'ProcessMap-tool_process-user_22.svg'}}, organigram:{orgUnit:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_ORGANISATION_UNIT'), src:'icon_22x22_orgunit.gif'}, orgRole:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_ROLE'), src:'icon_22x22_role.gif'}, orgChiefRole:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SUPERVISOR_ROLE'), src:'icon_22x22_rolepro.gif'}, orgPerson:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PERSON'), src:'icon_22x22_person.gif'}, orgSubstitutePerson:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_SUBSTITUTE'), 
src:'icon_22x22_personpro.gif'}}, systemdiagram:{sdFirewall:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_FIREWALL'), src:'icon_22x22_firewall.gif'}, sdPartner:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PARTNER'), src:'icon_22x22_partner.gif'}, sdVisualRulesSuite:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_VISUAL_RULES'), src:'icon_22x22_visualrulessuite.gif'}, sdInubitIS:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INUBIT_IS'), src:'icon_22x22_inubitis.gif'}, sdInubitRC:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_INUBIT_RC'), 
src:'icon_22x22_inubitrc.gif'}, sdExtSystem:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_EXTERNAL_SYSTEM'), src:'icon_22x22_system.gif'}, sdUserTask:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_USER_TASK'), src:'icon_22x22_usertask.gif'}, sdCommunicationCloud:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMMUNICATED_CLOUD'), src:'icon_22x22_communicationcloud.gif'}}, soamap:{SOAMapUser:{group:'Actors', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_ACTORS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_USER'), src:'icon_22x22_soamap_user.gif'}, SOAMapComponent:{group:'Actors', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_ACTORS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMPONENT'), 
src:'icon_22x22_soamap_component.gif'}, SOAMapUnknownArea:{group:'Actors', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_ACTORS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_UNKNOWN_AREA'), src:'icon_22x22_soamap_unknownarea.gif'}, SOAMapProblem:{group:'Actors', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_ACTORS'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PROBLEM'), src:'icon_22x22_soamap_problem.gif'}, SOAMapGroup:{group:'Atrifacts', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GROUP'), src:'icon_22x22_soamap_group.gif'}}, constraintsdiagram:{composition:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMPOSITION'), src:'icon_16x16_composition.gif'}, aggregation:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_AGGREGATION'), src:'icon_16x16_aggregation.gif'}, association:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_ASSOCIATION'), src:'icon_16x16_association.gif'}, generalization:{group:'Connection', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_CONNECTION'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_GENERALIZATION'), 
src:'icon_16x16_generalization.gif'}, cdClass:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_CLASS'), src:'icon_16x16_class.gif'}}, technical:{Process:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_PROCESS'), src:'icon_22x22_process.gif'}, TransactionScope:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_TRANSACTION_SCOPE'), src:'icon_22x22_transactionscope.gif'}, ForEachLoop:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'ForEach loop', src:'tool_for-each_22.svg'}, Pick:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'Pick', src:'icon_22x22_pick.gif'}, PartnerManagement:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), 
text:'Partner management', src:'icon_22x22_partnermanagement.gif'}, Scope:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'Scope', src:'icon_22x22_scope.gif'}, Flow:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'Flow', src:'icon_22x22_flow.gif'}, SwitchLoop:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'Switch case', src:'icon_22x22_switch.gif'}, 
If:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'If', src:'icon_22x22_if.gif'}, WhileLoop:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'While loop', src:'tool_while_22.svg'}, RepeatUntilLoop:{group:'Tools', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_TOOL'), text:'Repeat-until loop', src:'tool_repeat-until_22.svg'}, 'Complex Lookup Table':{group:'Data converter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_DATA_CONVERTER'), 
text:'Complex Lookup Table', src:'lookup.gif'}, 'FO Converter':{group:'Data converter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_DATA_CONVERTER'), text:'FO Converter', src:'fo_creator.svg'}, 'Lookup Table':{group:'Data converter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_DATA_CONVERTER'), text:'Lookup Table', src:'lookup.svg'}, 'XSLT Converter':{group:'Data converter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_DATA_CONVERTER'), 
text:'XSLT Converter', src:'xml_to_xml.svg'}, 'Task Generator':{group:'Data converter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_DATA_CONVERTER'), text:'Task Generator', src:'task_generator.svg'}, 'CSV Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'CSV Adapter', src:'csv_adapter.svg'}, 'CSV-XML Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), 
text:'CSV-XML Adapter', src:'csv_to_xml.svg'}, 'EDI-XML Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'EDI-XML Adapter', src:'edi_to_xml.svg'}, 'Flat-XML Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'Flat-XML Adapter', src:'flat_xml.svg'}, 'JSON Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), 
text:'JSON Adapter', src:'json_adapter.svg'}, 'MIME-XML Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'MIME-XML Adapter', src:'mime_to_xml.svg'}, 'XLS-XML Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'XLS-XML Adapter', src:'xls_xml.svg'}, 'XLSX Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), 
text:'XLSX Adapter', src:'xlsx.svg'}, 'XML-CSV Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'XML-CSV Adapter', src:'xml_csv_icon.svg'}, 'XML-EDI Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'XML-EDI Adapter', src:'xml_to_edi.svg'}, 'XML-Flat Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), 
text:'XML-Flat Adapter', src:'xml_flat.svg'}, 'XML-MIME Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'XML-MIME Adapter', src:'xml_to_mime.svg'}, 'XML-XLS Adapter':{group:'Format Adapter', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_FORMAT_ADAPTER'), text:'XML-XLS Adapter', src:'xml_xls.svg'}, 'AS/400 Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'AS/400 Connector', src:'as400.svg'}, 'AS2 Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'AS2 Connector', src:'as2_connector.svg'}, 'AS4 Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'AS4 Connector', src:'as4_connector.svg'}, 'Backup Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'Backup Connector', src:'backup_connector.svg'}, 'Database Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Database Connector', src:'database_connector.svg'}, 'Database Object Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Database Object Connector', src:'db_object_connector.svg'}, 'Execution Connector':{group:'System Connector', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Execution Connector', src:'execution_connector.svg'}, 'File Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'File Connector', src:'file_connector.svg'}, 'FTP Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'FTP Connector', src:'ftp_connector.svg'}, 
'HTTP Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'HTTP Connector', src:'http_connector.svg'}, 'ICR Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'ICR Connector', src:'icr_connector.gif'}, 'inubit IS Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'inubit IS Connector', src:'ibis_connector.svg'}, 'Java Reflection Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Java Reflection Connector', src:'reflection_connector.svg'}, 'JMS Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'JMS Connector', src:'jms_connector.svg'}, 'LDAP Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'LDAP Connector', src:'ldap_connector.svg'}, 'Livelink PDMS Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Livelink PDMS Connector', src:'connector.svg'}, 'Mail Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Mail Connector', src:'mail_connector.svg'}, 'OpenOffice Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'OpenOffice Connector', src:'oo_connector.svg'}, 'OSCI Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'OSCI Connector', src:'osciconnector.svg'}, 'REST Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'REST Connector', src:'rest_connector.svg'}, 'RosettaNet HTTPS Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'RosettaNet HTTPS Connector', src:'rosettanet_connector.svg'}, 'SAP Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'SAP Connector', src:'sap_connector.svg'}, 'Secrypt Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Secrypt Connector', src:'secrypt_connector.svg'}, 'Security Token Service':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'Security Token Service', src:'SecurityTokenService.svg'}, 'Selenium Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Selenium Connector', src:'selenium_connector.svg'}, 'SNMP Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'SNMP Connector', src:'snmp_connector.svg'}, 'VFS Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), 
text:'VFS Connector', src:'vfs_connector.svg'}, 'VR Execution Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'VR Execution Connector', src:'vr_execution_connector.svg'}, 'Web Application Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Web Application Connector', src:'webapplication_connector.svg'}, 'Web Services Connector':{group:'System Connector', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'Web Services Connector', src:'webservices_connector.svg'}, 'WebDAV Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'WebDAV Connector', src:'webdav_connector.svg'}, 'WebSphere Connector':{group:'System Connector', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_SYSTEM_CONNECTOR'), text:'WebSphere Connector', 
src:'mq_connector.svg'}, 'Barcode Generator':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Barcode Generator', src:'barcode_generator.svg'}, 'Certificate Reader':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Certificate Reader', src:'certificatereader.svg'}, 'Compressor':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Compressor', 
src:'compressor.svg'}, 'Cryptographer':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Cryptographer', src:'cryptographer_icon.svg'}, 'Data Stream Analyzer':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Data Stream Analyzer', src:'datastream_analyzer.svg'}, 'Data Stream Modifier':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), 
text:'Data Stream Modifier', src:'datastream_modifier.svg'}, 'Encoder':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Encoder', src:'encoder.svg'}, 'inubit IS Configuration':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'inubit IS Configuration', src:'configuration_plugin.svg'}, 'Line Reader':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), 
text:'Line Reader', src:'line_reader.svg'}, 'PDF Toolbox':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'PDF Toolbox', src:'pdf_toolbox.svg'}, 'Process Data Logger':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'Process Data Logger', src:'process_data_logger.svg'}, 'Report Data Collector':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), 
text:'Report Data Collector', src:'report_data_collector.svg'}, 'SMIME':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'SMIME', src:'smime.svg'}, 'XML Diff':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'XML Diff', src:'ibisxmldiff.svg'}, 'XML Enveloper':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'XML Enveloper', src:'xml_enveloper.svg'}, 
'XML Formatter':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'XML Formatter', src:'xml_formatter.svg'}, 'XML Validator':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'XML Validator', src:'schema_checker.gif'}, 'ZUGFeRD':{group:'Utilities', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_UTILITIES'), text:'ZUGFeRD', src:'zugferd_icon.svg'}, 'Invoke':{group:'Web Service Controls', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WEB_SERVICE_CONTROL'), text:'Invoke', src:'invoke.svg'}, 'OnMessage':{group:'Web Service Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WEB_SERVICE_CONTROL'), text:'OnMessage', src:'onmessage.svg'}, 'Receive':{group:'Web Service Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WEB_SERVICE_CONTROL'), text:'Receive', src:'receive.svg'}, 'Reply':{group:'Web Service Controls', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WEB_SERVICE_CONTROL'), text:'Reply', src:'reply.svg'}, 'Assign':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Assign', src:'assign.svg'}, 'Compensate':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Compensate', src:'compensate.svg'}, 'Compensate Scope':{group:'Workflow Controls', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Compensate Scope', src:'compensatescope.svg'}, 'Demultiplexer':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Demultiplexer', src:'demultiplexer.svg'}, 'Empty':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Empty', src:'empty.svg'}, 'Exit':{group:'Workflow Controls', 
category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Exit', src:'exit.svg'}, 'Joiner':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Joiner', src:'joiner.svg'}, 'Multiplexer':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Multiplexer', src:'multiplexer.svg'}, 'Rethrow':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), 
text:'Rethrow', src:'rethrow.svg'}, 'Splitter':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Splitter', src:'splitter.svg'}, 'Throw':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Throw', src:'throw.svg'}, 'Validate':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Validate', 
src:'validate.svg'}, 'Wait':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Wait', src:'wait.svg'}, 'Workflow Connector':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), text:'Workflow Connector', src:'workflow_connector.svg'}, 'Workflow Starter':{group:'Workflow Controls', category:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_CATEGORY_WORKFLOW_CONTROL'), 
text:'Workflow Starter', src:'WorkflowStarter.svg'}}, common:{Label:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_FRAME'), src:'Diagram-tool_Artifact_frame_22.svg'}, Text:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:'Text', src:'Diagram-tool_Artifact_text-mono_22.svg'}, Comment:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), 
text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_COMMENT'), src:'Diagram-tool_Artifact_comment_22.svg'}, RepositoryImage:{group:'Artifacts', category:BpcCommon.Api.getTranslation('DOCUMENTATION_ARTIFACT_TEXT'), text:BpcCommon.Api.getTranslation('DOCUMENTATION_LEGEND_TEXT_REPOSITORY_IMAGE'), src:'Diagram-tool_Artifact_image_22.svg'}}, getConnectionIconSrc:function(module, connectionType) {
  var basePath = this.basePath, connectionProps;
  if (connectionType) {
    connectionProps = Ext.clone(this[module.WorkFlowType][connectionType]);
    if (connectionProps !== undefined) {
      connectionProps.src = basePath + module.WorkFlowType + '/' + connectionProps.src;
      return connectionProps;
    }
  }
}, getIconSrc:function(module) {
  var basePath = this.basePath, moduleType, moduleProps;
  var commonModuleTypes = ['Label', 'Text', 'Comment', 'RepositoryImage'];
  var moduleWithoutProps = ['processmap', 'organigram', 'systemdiagram', 'soamap', 'constraintsdiagram', 'technical'];
  if (module.WorkFlowType === 'bpd') {
    var bpdModulesWithoutProperties = ['PoolHorizontal', 'PoolVertical', 'PoolBlackBox', 'PoolLane', 'CallActivity', 'DataObject', 'DataInput', 'DataOutput', 'Message', 'RepositoryImage', 'TextAnnotation', 'Group', 'DataStore', 'Communication', 'CallConversation', 'ChoreographyTask', 'CallChoreographyActivity', 'ChoreographySubProcess', 'SubConversation'];
    if (bpdModulesWithoutProperties.indexOf(module.ModuleType) > -1) {
      moduleType = module.ModuleType;
    } else if (module.ModuleType === 'Task' || module.ModuleType === 'SubProcess' || module.ModuleType === 'StartEvent' || module.ModuleType === 'IntermediateEvent' || module.ModuleType === 'StopEvent' || module.ModuleType === 'Gateway') {
      moduleType = module.ModuleType + module.ModuleTypeProp;
    }
    if (moduleType && moduleProps) {
      moduleProps = Ext.clone(this[module.WorkFlowType][moduleType]);
      moduleProps.src = basePath + module.WorkFlowType + '/' + moduleProps.src;
      return moduleProps;
    }
  } else if (moduleWithoutProps.indexOf(module.WorkFlowType) > -1 && module.ModuleType !== module.WorkFlowType) {
    moduleType = module.ModuleType;
  } else if (module.ModuleType === module.WorkFlowType) {
    moduleType = module.ModuleGroupName;
  }
  if (commonModuleTypes.indexOf(module.ModuleType) > -1) {
    module.WorkFlowType = 'common';
    moduleType = module.ModuleType;
  }
  if (moduleType && this[module.WorkFlowType].hasOwnProperty(moduleType)) {
    moduleProps = Ext.clone(this[module.WorkFlowType][moduleType]);
    moduleProps.src = basePath + module.WorkFlowType + '/' + moduleProps.src;
    return moduleProps;
  }
}, getModuleNameCompat:function(item) {
  item = item === void 0 ? {} : item;
  var $jscomp$destructuring$var4 = item || {};
  var ModuleType = $jscomp$destructuring$var4.ModuleType;
  var ModuleTypeProp = $jscomp$destructuring$var4.ModuleTypeProp;
  var WorkFlowType = $jscomp$destructuring$var4.WorkFlowType;
  return this.getModuleName({wfModule:{wfType:WorkFlowType, type:ModuleType, typeProp:ModuleTypeProp}});
}, getModuleName:function(hotspotObject) {
  var $jscomp$destructuring$var5 = hotspotObject;
  var wfModule = $jscomp$destructuring$var5.wfModule;
  var $jscomp$destructuring$var6 = wfModule || {};
  var wfType = $jscomp$destructuring$var6.wfType;
  var type = $jscomp$destructuring$var6.type;
  var typeProp = $jscomp$destructuring$var6.typeProp;
  return this.getModuleNameForSearch(wfType, type + typeProp);
}, getModuleNameForSearch:function(diagramType, moduleName) {
  if (diagramType && moduleName && this[diagramType].hasOwnProperty(moduleName)) {
    return this[diagramType][moduleName].text;
  } else if (this['common'].hasOwnProperty(moduleName)) {
    return this['common'][moduleName].text;
  }
  return moduleName;
}});
Ext.define('documentation.util.CSS', {singleton:true, createCustomStyling:function() {
  var $jscomp$this = this;
  var rules = BpcCommon.Api.getSetting('documentation', 'css_rules_json') || [];
  rules.map(function(item) {
    var $jscomp$destructuring$var7 = item;
    var clsName = $jscomp$destructuring$var7.clsName;
    var clsDefinition = $jscomp$destructuring$var7.clsDefinition;
    $jscomp$this.create(clsName, clsDefinition);
  });
}, create:function(className, classDefinition) {
  Ext.util.CSS.createStyleSheet(className + classDefinition);
}});
Ext.define('documentation.Module', {requires:['documentation.util.CSS'], singleton:true, mixins:['BpcCommon.mixin.BpcModuleUtilsMixin'], constructor:function() {
  BpcCommon.Api.onReady(this.onBpcReady.bind(this));
}, xmlSerializer:undefined, delay:function(time) {
  time = time === void 0 ? 1000 : time;
  return new Promise(function(resolve) {
    return setTimeout(resolve, time);
  });
}, onBpcReady:function() {
  var $jscomp$this = this;
  documentation.util.CSS.createCustomStyling();
  if (!this.xmlSerializer) {
    this.xmlSerializer = new XMLSerializer();
  }
  this.delay().then(function() {
    return $jscomp$this.loadLibraries();
  });
}, replaceSpace:function(str) {
  if (str.indexOf(' ') > -1) {
    str = str.replaceAll(' ', '+');
  }
  return str;
}, moduleBaseUrl:function() {
  return BpcCommon.Api.getBackendUrl('documentation') + '/bpc-documentation/';
}});
Ext.define('documentation.ModuleDimentions', {singleton:true, bpd:{Task:{height:60, width:100}, CallActivity:{height:60, width:100}, SubProcess:{height:60, width:120}, StartEvent:{height:30, width:30}, StopEvent:{height:30, width:30}, IntermediateEvent:{height:30, width:30}, Gateway:{height:40, width:40}, PoolBlackBox:{height:100, width:400}, PoolHorizontal:{height:100, width:400}, PoolVertical:{height:400, width:200}, DataObject:{height:35, width:30}, DataInput:{height:35, width:30}, DataOutput:{height:35, 
width:30}, DataStore:{height:50, width:50}, Group:{height:150, width:300}, Message:{height:20, width:30}, RepositoryImage:{height:40, width:40}, TextAnnotation:{height:100, width:180}, Communication:{height:40, width:40}, SubConversation:{height:40, width:40}, CallConversation:{height:40, width:40}, ChoreographyTask:{height:100, width:140}, ChoreographySubProcess:{height:220, width:300}, CallChoreographyActivity:{height:145, width:145}, Image:{height:1, width:1}}, processmap:{ProcessMapProcess:{height:60, 
width:120}, ProcessMapProcessGroup:{height:50, width:180}, ProcessMapProcessUser:{height:60, width:60}, RepositoryImage:{height:40, width:40}, Label:{height:300, width:200}, Text:{height:50, width:200}, Comment:{height:70, width:100}}, soamap:{SOAMapUser:{height:40, width:40}, SOAMapComponent:{height:60, width:90}, SOAMapUnknownArea:{height:80, width:120}, SOAMapProblem:{height:40, width:40}, SOAMapGroup:{height:80, width:250}, RepositoryImage:{height:40, width:40}, Text:{height:50, width:200}, Comment:{height:70, 
width:100}, SOAMapApplication:{height:550, width:250}}, systemdiagram:{sdVisualRulesSuite:{height:30, width:100}, sdInubitIS:{height:50, width:50}, sdInubitRC:{height:30, width:30}, sdUserTask:{height:30, width:30}, sdExtSystem:{height:30, width:80}, sdCommunicationCloud:{height:100, width:150}, sdFirewall:{height:40, width:20}, sdPartner:{height:100, width:200}, RepositoryImage:{height:40, width:40}, Label:{height:300, width:200}, Text:{height:50, width:200}, Comment:{height:70, width:100}}, constraintsdiagram:{cdClass:{height:100, 
width:120}, RepositoryImage:{height:40, width:40}, Label:{height:300, width:200}, Text:{height:50, width:200}, Comment:{height:70, width:100}}, organigram:{orgUnit:{height:30, width:110}, orgRole:{height:30, width:110}, orgChiefRole:{height:30, width:110}, orgPerson:{height:30, width:110}, orgSubstitutePerson:{height:30, width:110}, RepositoryImage:{height:40, width:40}, Label:{height:300, width:200}, Text:{height:50, width:200}, Comment:{height:70, width:100}}, technical:{technical:{height:45, width:60}, 
Label:{height:300, width:200}, Text:{height:50, width:200}, Comment:{height:70, width:100}, Pick:{height:150, width:300}, ForEachLoop:{height:150, width:300}, RepeatUntilLoop:{height:150, width:300}, WhileLoop:{height:150, width:300}, If:{height:150, width:300}, SwitchLoop:{height:150, width:300}, TransactionScope:{height:150, width:300}, Scope:{height:150, width:300}, Process:{height:150, width:300}, Flow:{height:150, width:300}}, link:{datalink:{height:10, width:15}}});
Ext.define('documentation.view.Image', {extend:'Ext.Img', alias:['widget.documentationImage'], mixins:['documentation.mixins.Component'], treeNode:undefined, moduleId:undefined, imageLoaded:false, initComponent:function() {
  var $jscomp$this = this;
  this.listeners = {afterrender:function() {
    return $jscomp$this.onAfterRender();
  }};
  this.callParent(arguments);
}, registerContextMenu:function() {
  var $jscomp$this = this;
  var elem = this.getEl();
  elem.on('contextmenu', function(e) {
    e.preventDefault();
    var m = $jscomp$this.createMenu();
    m.showAt(e.getXY());
  });
}, onAfterRender:function() {
  var $jscomp$this = this;
  var $jscomp$destructuring$var8 = this.getEl();
  var dom = $jscomp$destructuring$var8.dom;
  dom.onload = function() {
    return $jscomp$this.onImageLoaded();
  };
  var $jscomp$destructuring$var9 = this.getSetting('ui_flags') || {};
  var diagram_thumbnails_doNotLoad = $jscomp$destructuring$var9.diagram_thumbnails_doNotLoad;
  if (diagram_thumbnails_doNotLoad) {
    this.registerContextMenu();
  } else {
  }
}, getImageUrl:function() {
  return this.treeNode ? documentation.util.Image.getImageUrl(this.moduleId, this.treeNode) : undefined;
}, onImageLoaded:function() {
  try {
    this.setLoading(false);
  } catch (e) {
  }
}, doLoadImage:function(url) {
  this.setLoading(this.TR('LOADING_DATA'));
  this.updateSrc(url);
}, imageLoading:false, initImage:function() {
  var $jscomp$this = this;
  if (!this.imageLoaded && !this.imageLoading) {
    this.imageLoading = true;
    return documentation.util.Image.getImageAsDataUrl(this.getImageUrl()).then(function(dataUrl) {
      $jscomp$this.imageLoaded = true;
      $jscomp$this.imageLoading = false;
      $jscomp$this.doLoadImage(dataUrl);
    }).then(function() {
      return true;
    });
  }
  return Promise.resolve();
}, createMenu:function() {
  var $jscomp$this = this;
  return Ext.create('Ext.menu.Menu', {margin:'0 0 10 0', items:[{text:this.TR('LOAD_THUMBNAIL'), handler:function() {
    $jscomp$this.doLoadImage($jscomp$this.getImageUrl());
  }}]});
}});
Ext.define('documentation.components.LinkedDiagramsGrid', {extend:'Ext.grid.Panel', alias:'widget.documentationLinkedDiagrams', mixins:['documentation.mixins.Component'], workflowData:[], initComponent:function() {
  var $jscomp$this = this;
  this.title = this.TR('LINKED_DIAGRAMS');
  this.iconCls = this.faIcon('fa-link');
  this.listeners = {rowdblclick:function(tv, r) {
    $jscomp$this.onDoOpenWorkflow(r);
  }};
  this.store = this.newLocalStore(documentation.Support.convertToLinkedDiagramData(this.workflowData));
  this.hidden = this.store.getCount() === 0;
  this.columns = [{dataIndex:'iconCls', hidden:true}, {dataIndex:'icon', hidden:true}, {dataIndex:'linkName', flex:1}, {xtype:'actioncolumn', width:50, items:[{iconCls:this.faIcon('fa-external-link'), tooltip:this.TR('OPEN_LINKED_DIAGRAM'), handler:function(grid, rowIndex, colIndex, item, e, r) {
    return $jscomp$this.onDoOpenWorkflow(r);
  }}]}];
  this.callParent(arguments);
}, onDoOpenWorkflow:function(record) {
  this.fireEvent('openWorkflow', this, record.getData());
}});
Ext.define('documentation.view.components.StatefulCheckbox', {extend:'Ext.form.field.Checkbox', alias:'widget.statefulCheckbox', stateful:true, stateEvents:['change'], getState:function() {
  return {checked:this.getValue()};
}, applyState:function(state) {
  this.setValue(state.checked);
}});
Ext.define('documentation.components.TextEditor', {extend:'Ext.panel.Panel', alias:'widget.documentationTextEditor', mixins:['documentation.mixins.Component'], layout:'fit', editor:undefined, value:undefined, mime:undefined, readOnly:false, initComponent:function() {
  this.editorId = Ext.id();
  this.items = [this.fullWidthContainer(this.editorId)];
  this.listeners = {afterrender:this.initEditor.bind(this), beforedestroy:this.destroyEditor.bind(this), resize:this.onResize.bind(this)};
  this.lineButton = Ext.create({xtype:'button', iconCls:this.faIcon('fa-grip-lines'), overCls:'', focusCls:'', tooltip:this.TR('LINES_COUNT'), text:'0'});
  this.encodingButton = Ext.create({xtype:'button', iconCls:this.faIcon('fa-file-code'), overCls:'', focusCls:'', tooltip:this.TR('FILE_STREAM_ENCODING')});
  this.warningButton = Ext.create({xtype:'button', iconCls:this.faIcon('exclamation-triangle flextable-error'), overCls:'flextable-cursor-pointer', focusCls:'', hidden:true, handleMouseEvents:false, text:'0'});
  this.addEditToolbar();
  this.bbar = [this.lineButton, {xtype:'tbfill'}, this.encodingButton];
  this.callParent(arguments);
}, setWarning:function(text, visible) {
  text = text === void 0 ? '' : text;
  visible = visible === void 0 ? true : visible;
  this.warningButton.setVisible(visible);
  this.warningButton.setText(text);
}, addEditToolbar:function() {
  var $jscomp$this = this;
  this.pageUp = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-arrow-up'), tooltip:this.TR('EDITOR_PAGE_UP'), handler:function() {
    $jscomp$this.editor.gotoPageUp();
  }});
  this.pageDown = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-arrow-down'), tooltip:this.TR('EDITOR_PAGE_DOWN'), handler:function() {
    $jscomp$this.editor.gotoPageDown();
  }});
  this.copyAll = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-clipboard'), tooltip:this.TR('EDITOR_COPY_ALL'), handler:function() {
  }});
  this.copySelection = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-copy'), tooltip:this.TR('EDITOR_COPY_SELECTION'), handler:function() {
  }});
  this.fontIncrease = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-plus'), tooltip:this.TR('EDITOR_COPY_SELECTION'), handler:function() {
    var fontSize = $jscomp$this.editor.getFontSize();
    fontSize++;
    $jscomp$this.editor.setFontSize(fontSize);
  }});
  this.fontDecrease = Ext.create({xtype:'button', ui:'secondary', iconCls:this.faIcon('fa-minus'), tooltip:this.TR('EDITOR_COPY_SELECTION'), handler:function() {
    var fontSize = $jscomp$this.editor.getFontSize();
    fontSize--;
    $jscomp$this.editor.setFontSize(fontSize);
  }});
  this.tbar = [this.pageUp, this.pageDown, this.copyAll, this.copySelection, this.fontIncrease, this.fontDecrease, {xtype:'tbspacer', width:32}, this.warningButton];
}, initEditor:function() {
  this.editor = ace.edit(this.editorId);
  this.editor.setTheme('ace/theme/chrome');
  this.setMime(this.mime || 'xml');
  this.editor.setOptions({enableBasicAutocompletion:true, enableLiveAutocompletion:true, showLineNumbers:true, showPrintMargin:false});
  if (this.readOnly) {
    this.editor.setReadOnly(true);
  }
  if (this.value) {
    this.setValue(this.value);
  }
}, setMime:function(mime) {
  mime = mime === void 0 ? '' : mime;
  var map = {'application/json':'json', 'application/javascript':'javascript', 'application/ecmascript':'javascript', 'application/edifact':'edifact', 'text/css':'css', 'text/html':'html', 'text/xml':'xml'};
  var editorLanguage = map[mime] || (mime.indexOf('xml') !== -1 ? 'xml' : undefined);
  if (editorLanguage) {
    this.setAceMode(editorLanguage);
  }
}, setAceMode:function(editorLanguage) {
  this.editor.getSession().setMode('ace/mode/' + editorLanguage);
}, onResize:function() {
  if (this.editor) {
    this.editor.resize();
  }
}, getValue:function() {
  if (this.editor) {
    return this.editor.getValue();
  }
}, setValue:function(value) {
  if (this.editor) {
    this.editor.setValue(value, -1);
    this.updateLineCount();
  }
}, updateLineCount:function() {
  this.lineButton.setText(this.getLineCount());
}, getLineCount:function() {
  var doc = this.editor.getSession().getDocument();
  return (doc ? doc.getAllLines() || [] : []).length;
}, destroyEditor:function() {
  if (this.editor) {
    this.editor.destroy.bind(this.editor);
  }
}, fullWidthContainer:function(id) {
  return Ext.create({xtype:'container', html:'\x3cdiv style\x3d"height: 100%;width: 100%"\x3e\x3cdiv style\x3d"height: 100%;width: 100%" id\x3d"' + id + '"\x3e\x3c/div\x3e\x3c/div\x3e'});
}});
Ext.define('documentation.components.Window', {extend:'Ext.window.Window', alias:'widget.documentationWindow', mixins:['documentation.mixins.Component'], doGetStateData:function() {
  var position = this.getXY();
  var $jscomp$destructuring$var10 = $jscomp.makeIterator(position);
  var winX = $jscomp$destructuring$var10.next().value;
  var winY = $jscomp$destructuring$var10.next().value;
  var width = this.getWidth();
  var height = this.getHeight();
  return {width:width, height:height, winX:winX, winY:winY};
}});
Ext.define('documentation.util.Cache', {singleton:true, diagrams:{}, add:function(id, data) {
  this.diagrams[id] = data;
}, get:function(id) {
  if (Object.hasOwn(this.diagrams, id)) {
    return Object.assign({}, this.diagrams[id]);
  }
}, remove:function(id) {
  if (Object.hasOwn(this.diagrams, id)) {
    delete this.diagrams[id];
  }
}, reset:function() {
  this.diagrams = {};
}});
Ext.define('documentation.util.Image', {singleton:true, prepareImageUrlFromNode:function(node) {
  if (!node || !node.isLeaf()) {
    return null;
  }
  var scaleValue = node.get('zoomValue') ? node.get('zoomValue') : 100;
  return node.get('imageUrl') + '\x26zoomScaleValue\x3d' + scaleValue / 100 + '\x26_dc\x3d' + this.getLoadTimeStamp();
}, loadTimestamp:undefined, getLoadTimeStamp:function() {
  if (!this.loadTimestamp) {
    this.loadTimestamp = new Date();
  }
  return this.loadTimestamp.getTime();
}, restBaseUrl:function(moduleId) {
  return documentation.Module.moduleBaseUrl() + encodeURIComponent(moduleId) + '/';
}, getImageUrl:function(moduleId, node) {
  return this.restBaseUrl(moduleId) + this.prepareImageUrlFromNode(node);
}, loadImageAsBlob:function(url) {
  return fetch(url).then(function(r) {
    if (!r.ok) {
      throw new Error('request error');
    }
    return r.blob();
  }).then(function(blob) {
    return blob;
  });
}, getImageAsDataUrl:function(url) {
  var $jscomp$this = this;
  var $jscomp$destructuring$var11 = $jscomp.makeIterator(url.split('?'));
  var path = $jscomp$destructuring$var11.next().value;
  var params = $jscomp$destructuring$var11.next().value;
  var $jscomp$destructuring$var12 = documentation.util.Url.parseParams(params);
  var lang = $jscomp$destructuring$var12.lang;
  var zoomScaleValue = $jscomp$destructuring$var12.zoomScaleValue;
  var $jscomp$destructuring$var13 = $jscomp.makeIterator(path.split('/').reverse());
  var imagePath = $jscomp$destructuring$var13.next().value;
  var id = [imagePath, 'image', lang, zoomScaleValue].join('_');
  var data = documentation.util.Cache.get(id);
  if (data) {
    return Promise.resolve(data.dataUrl);
  }
  return this.loadImageAsBlob(url).then(function(blob) {
    return $jscomp$this.blobToDataUrl(blob);
  }).then(function(dataUrl) {
    documentation.util.Cache.add(id, {dataUrl:dataUrl});
    return dataUrl;
  });
}, blobToDataUrl:function(blob) {
  return (new Promise(function(r) {
    var a = new FileReader();
    a.onload = r;
    a.readAsDataURL(blob);
  })).then(function(e) {
    return e.target.result;
  });
}});
Ext.define('documentation.util.Metadata', {singleton:true, LinkToObject:function(item) {
  var $jscomp$destructuring$var14 = item;
  var modelName = $jscomp$destructuring$var14.modelName;
  var objectName = $jscomp$destructuring$var14.objectName;
  var value = $jscomp$destructuring$var14.value;
  modelName = modelName || '';
  objectName = objectName || '';
  var v;
  if (objectName.length) {
    v = modelName + '  (' + objectName + ')';
  }
  return v || modelName;
}, I18NString:function(item) {
  var $jscomp$destructuring$var15 = item;
  var values = $jscomp$destructuring$var15.values;
  if (Array.isArray(values)) {
    var isEn = documentation.Module.language === 'en';
    var $jscomp$destructuring$var16 = $jscomp.makeIterator(values.filter(function(item) {
      return isEn ? Object.hasOwn(item, 'lang') : !Object.hasOwn(item, 'lang');
    }));
    var m = $jscomp$destructuring$var16.next().value;
    if (!m && values.length === 1) {
      var $jscomp$destructuring$var17 = $jscomp.makeIterator(values);
      m = $jscomp$destructuring$var17.next().value;
    }
    if (m && Object.hasOwn(m, 'value')) {
      return m.value;
    }
  }
}, prepareKey:function(data) {
  var langPart = documentation.Module.language;
  var property = 'name';
  var $jscomp$destructuring$var18 = $jscomp.makeIterator([[property, langPart].join('.'), property].map(function(propName) {
    return data[propName];
  }).filter(function(value) {
    return typeof value !== 'undefined' && value !== null;
  }));
  var item = $jscomp$destructuring$var18.next().value;
  return item;
}, prepareValue:function(data) {
  var $jscomp$destructuring$var19 = data;
  var type = $jscomp$destructuring$var19.type;
  var values = $jscomp$destructuring$var19.values;
  var langPart = documentation.Module.language;
  var property = 'name';
  if (type === 'MultipleMetadata') {
    return values.map(function(item) {
      var $jscomp$destructuring$var20 = $jscomp.makeIterator([[property, langPart].join('.'), property].map(function(propName) {
        return item[propName];
      }).filter(function(value) {
        return typeof value !== 'undefined' && value !== null;
      }));
      var match = $jscomp$destructuring$var20.next().value;
      if (match) {
        var $jscomp$destructuring$var21 = item;
        var type$1 = $jscomp$destructuring$var21.type;
        var displayValue;
        if (type$1 === 'LinkToObject') {
          displayValue = documentation.util.Metadata[type$1](item);
          var $jscomp$destructuring$var22 = item;
          var modelName = $jscomp$destructuring$var22.modelName;
          var objectName = $jscomp$destructuring$var22.objectName;
          var value = $jscomp$destructuring$var22.value;
          if (displayValue) {
            displayValue = '\x3ca class\x3d"documentation_linkToObject" href\x3d"#" data-modelname\x3d"' + modelName + '" data-objectname\x3d"' + objectName + '" data-moduleid\x3d"' + value + '"\x3e' + displayValue + '\x3c/a\x3e';
          }
        }
        if (type$1 === 'I18NString') {
          displayValue = documentation.util.Metadata[type$1](item);
        }
        return {key:match, type:item.type, displayValue:displayValue, _item:item};
      }
    }).filter(function(i) {
      return typeof i !== 'undefined';
    }).filter(function(i) {
      var $jscomp$destructuring$var23 = i;
      var displayValue = $jscomp$destructuring$var23.displayValue;
      return typeof displayValue !== 'undefined' && displayValue.trim().length > 0;
    }).map(function(i) {
      var $jscomp$destructuring$var24 = i;
      var key = $jscomp$destructuring$var24.key;
      var displayValue = $jscomp$destructuring$var24.displayValue;
      return key + ' ' + displayValue;
    }).join('\x3cbr\x3e');
  }
  if (type === 'LinkToObject') {
    var displayValue = documentation.util.Metadata[type](data);
    var $jscomp$destructuring$var25 = data;
    var modelName = $jscomp$destructuring$var25.modelName;
    var objectName = $jscomp$destructuring$var25.objectName;
    var value = $jscomp$destructuring$var25.value;
    if (displayValue) {
      var title = documentation.Support.TR('DIAGRAM_LINK');
      displayValue = '\x3ca title \x3d"' + title + '" class\x3d"documentation_linkToObject" href\x3d"#" data-modelname\x3d"' + modelName + '" data-objectname\x3d"' + objectName + '" data-moduleid\x3d"' + value + '"\x3e' + displayValue + '\x3c/a\x3e';
    }
    return displayValue || '';
  }
  if (type === 'I18NDocumentExternal' || type === 'ExternalDocument') {
    var displayValue$2;
    var $jscomp$destructuring$var26 = data;
    var values$3 = $jscomp$destructuring$var26.values;
    values$3 = values$3 || [];
    var $jscomp$destructuring$var27 = $jscomp.makeIterator(values$3.filter(function(o) {
      return Object.hasOwn(o, 'lang') && o.lang === documentation.Module.language;
    }));
    var match = $jscomp$destructuring$var27.next().value;
    if (!match) {
      var $jscomp$destructuring$var28 = $jscomp.makeIterator(values$3.filter(function(o) {
        return !Object.hasOwn(o, 'lang');
      }));
      match = $jscomp$destructuring$var28.next().value;
    }
    if (match) {
      var $jscomp$destructuring$var29 = match;
      var Parameter = $jscomp$destructuring$var29.Parameter;
      var $jscomp$destructuring$var30 = Parameter || {};
      var value$4 = $jscomp$destructuring$var30.value;
      var OptionalName = $jscomp$destructuring$var30.OptionalName;
      if (value$4) {
        var title$5 = documentation.Support.TR('EXTERNAL_LINK');
        displayValue$2 = '\x3ca title \x3d"' + title$5 + '" class\x3d"documentation_linkToObject" href\x3d"#" data-url\x3d"' + value$4 + '" data-name\x3d"' + value$4 + '"\x3e' + (OptionalName || value$4) + '\x3c/a\x3e';
      }
    }
    return displayValue$2 || '';
  }
  if (type === 'I18NString') {
    return documentation.util.Metadata[type](data);
  }
  return '';
}, prepare:function(data) {
  var $jscomp$this = this;
  return data.map(function(i) {
    return {key:$jscomp$this.prepareKey(i), value:$jscomp$this.prepareValue(i)};
  }).map(function(item) {
    var $jscomp$destructuring$var31 = item;
    var key = $jscomp$destructuring$var31.key;
    var value = $jscomp$destructuring$var31.value;
    var visible = (key || '').trim().length > 0 && (value || '').trim().length > 0;
    item.hidden = !visible;
    return item;
  });
}});
Ext.define('documentation.util.SessionState', {singleton:true, get:function(id, raw) {
  raw = raw === void 0 ? false : raw;
  var str = sessionStorage.getItem(this.getId(id));
  if (raw) {
    return str;
  }
  str = str || '';
  try {
    return str.length === 0 ? undefined : JSON.parse(str);
  } catch (e) {
    return undefined;
  }
}, set:function(id, data) {
  if (!data) {
    return;
  }
  if (typeof data !== 'string') {
    try {
      data = JSON.stringify(data);
    } catch (e) {
      return;
    }
  }
  sessionStorage.setItem(this.getId(id), data);
}, getId:function(id) {
  var prefix = 'documentation', userId = BpcCommon.Api.getUserName();
  return [prefix, userId, id].join('-');
}, getWindowState:function() {
  return this.get('window');
}});
Ext.define('documentation.util.State', {singleton:true, get:function(id, raw) {
  raw = raw === void 0 ? false : raw;
  var str = localStorage.getItem(this.getId(id));
  if (raw) {
    return str;
  }
  str = str || '';
  try {
    return str.length === 0 ? undefined : JSON.parse(str);
  } catch (e) {
    return undefined;
  }
}, set:function(id, data) {
  if (!data) {
    return;
  }
  if (typeof data !== 'string') {
    try {
      data = JSON.stringify(data);
    } catch (e) {
      return;
    }
  }
  return this.doStore(this.getId(id), data);
}, doStore:function(id, data) {
  try {
    localStorage.setItem(id, data);
    return true;
  } catch (e) {
    console.error('error storing item', e);
  }
}, copyFromSession:function(key) {
  var data = documentation.util.SessionState.get(key);
  if (data) {
    return this.set(key, data);
  }
}, getId:function(id) {
  var prefix = 'documentation', userId = BpcCommon.Api.getUserName();
  return [prefix, userId, id].join('-');
}, getWindowState:function(id) {
  id = id === void 0 ? 'window' : id;
  return this.get(id);
}});
Ext.define('documentation.util.String', {singleton:true, paddedIntString:function(v, count) {
  count = count === void 0 ? 4 : count;
  v = String(v);
  return v.repeat(count).split('').join(' ');
}});
Ext.define('documentation.util.Url', {singleton:true, getDiagramRoute:function() {
  var diagramRoute = BpcCommon.Api.routeController.getRoute();
  if (diagramRoute.includes('\x26diagram')) {
    diagramRoute = diagramRoute.substring(0, diagramRoute.indexOf('\x26diagram'));
  }
  return diagramRoute;
}, diagramDataFromRecord:function(record) {
  var $jscomp$destructuring$var32 = record;
  var parentNode = $jscomp$destructuring$var32.parentNode;
  var diagramType = parentNode.parentNode.get('wfType');
  var diagramGroup = parentNode.get('wfType');
  var diagram = record.get('text');
  return {diagramType:diagramType, diagramGroup:diagramGroup, diagram:diagram};
}, getUrlFromRecord:function(record) {
  if (!record) {
    return;
  }
  return window.location.origin + '/?#' + documentation.util.Url.getDiagramRoute() + '\x26' + (new URLSearchParams(this.diagramDataFromRecord(record))).toString();
}, parseParams:function(str) {
  var urlParams = new URLSearchParams(str);
  var obj = {};
  for (var $jscomp$iter$0 = $jscomp.makeIterator(urlParams.keys()), $jscomp$key$key = $jscomp$iter$0.next(); !$jscomp$key$key.done; $jscomp$key$key = $jscomp$iter$0.next()) {
    var key = $jscomp$key$key.value;
    {
      obj[key] = urlParams.get(key);
    }
  }
  return obj;
}});
Ext.define('documentation.view.export.ApplicationToolbar', {extend:'Ext.toolbar.Toolbar', alias:'widget.documentationAppToolbar', mixins:['documentation.mixins.Component'], overflowHandler:'scroller', initComponent:function() {
  var $jscomp$this = this;
  this.items = ['-\x3e', {xtype:'splitbutton', iconCls:this.faIcon('fa-bookmark'), handler:'createConfigWindow', hidden:this.moduleInstance.exportDisabled, menu:[{iconCls:this.faIcon('fa-list'), localized:{text:'DOCUMENTATION_MANAGE_CONFIG'}, handler:function() {
    return $jscomp$this.createConfigWindow();
  }}]}];
  this.callParent(arguments);
}, flag:true, controlFlag:false, cancelFlag:false, createConfigWindow:function() {
  try {
    var me = this;
    if (this.moduleId) {
      var exportConfig = this.getSetting('export_config');
      if (exportConfig && exportConfig.configs && Ext.isArray(exportConfig.configs)) {
        var store = Ext.create('Ext.data.Store', {data:exportConfig.configs});
        var window = Ext.create('Ext.window.Window', {title:this.TR('SAVED_CONFIG'), iconCls:this.faIcon('fa-bookmark'), height:650, width:950, modal:true, layout:{type:'hbox', align:'stretch'}, buttons:[{text:this.TR('SAVE_CONFIG'), iconCls:this.faIcon('fa-save'), handler:function() {
          var cfg = window.down('exportConfig');
          me.saveConfig(cfg, window);
        }}, {text:this.TR('CLOSE'), iconCls:this.faIcon('fa-times'), handler:function() {
          window.close();
        }}], items:[{xtype:'grid', border:false, viewConfig:{emptyText:'No configurations saved'}, flex:2, selType:'cellmodel', plugins:[Ext.create('Ext.grid.plugin.RowEditing', {clicksToEdit:2, listeners:{afteredit:function(editor, context) {
          try {
            var exportConfigModel = BpcCommon.Api.getSetting(window.config.items[1].moduleId, 'export_config', true);
            var exportConfig = Ext.clone(exportConfigModel.get('value'));
            if (exportConfig && exportConfig.configs && Ext.isArray(exportConfig.configs)) {
              Ext.Array.each(exportConfig.configs, function(config, index, configs) {
                if (config.id === context.value) {
                  config.id = window.down('grid').getSelection()[0].id;
                  return false;
                }
              });
            }
            var hasDuplicate = false;
            Ext.each(exportConfigModel.data.value.configs, function(rec) {
              if (rec.id == context.newValues.id) {
                hasDuplicate = true;
                return false;
              }
            });
            if (!hasDuplicate) {
              exportConfigModel.set('value', exportConfig);
              exportConfigModel.save({failure:function(record, operation) {
                var errorResponse = JSON.parse(operation.getError().response.responseText);
                if (errorResponse) {
                  BpcCommon.Api.showNotification({title:errorResponse.error.name, text:errorResponse.error.message, type:'ERROR', popUp:'true'});
                }
              }, success:function(record, operation) {
                Ext.GlobalEvents.fireEvent('exportConfigUpdated', record);
                window.down('grid').getStore().loadData(exportConfig.configs);
              }, callback:function(record, operation, success) {
                window.setLoading(false);
              }});
            } else {
              Ext.create('Ext.window.MessageBox', {closeAction:'destroy'}).alert('Error', BpcCommon.Api.getTranslation('DOCUMENTATION_CONFIG_ALREADY_EXISTS'));
              context.record.reject();
            }
          } catch (e) {
            console.error('updateConfig', e);
          }
        }}})], requires:['Ext.grid.plugin.Editable'], columns:[{header:this.TR('TABLE_HEADER'), dataIndex:'id', flex:1, editable:true, editor:{xtype:'textfield', allowBlank:false}}, {xtype:'actioncolumn', width:70, header:this.TR('TABLE_ACTION'), editable:false, items:[{iconCls:this.faIcon('fa-trash'), handler:function(gridView, rowIdx, colIdx, item, e, rec, row) {
          Ext.create('Ext.window.MessageBox', {closeAction:'destroy'}).show({title:BpcCommon.Api.getTranslation('DOCUMENTATION_DELETE'), message:BpcCommon.Api.getTranslation('DOCUMENTATION_DELETE_CONFIG'), buttons:Ext.Msg.YESNO, icon:Ext.Msg.QUESTION, fn:function(button, text) {
            if (button == 'yes') {
              window.setLoading(true);
              me.deleteExportConfig(rec, window);
            }
          }});
        }}]}], store:store, listeners:{selectionchange:function(view, selections, options) {
          var exportConfigModel = BpcCommon.Api.getSetting(me.moduleId, 'export_config', true);
          var exportConfig = Ext.clone(exportConfigModel.get('value'));
          var fields = window.down('exportConfig').getForm().getFields().items;
          var cfg = window.down('exportConfig');
          var grid = window.down('grid');
          var count = 0;
          Ext.each(exportConfig.configs, function(rec) {
            count = count + 1;
            if (rec.id == fields[13].value) {
              Ext.each(fields, function(field) {
                if (field.value != rec[field.name]) {
                  if (me.controlFlag) {
                    me.flag = false;
                  }
                  if (me.cancelFlag) {
                    Ext.Msg.show({title:BpcCommon.Api.getTranslation('DOCUMENTATION_SAVE_CONFIG'), message:BpcCommon.Api.getTranslation('DOCUMENTATION_SAVE_CONFIG_MSG'), buttons:Ext.Msg.YESNOCANCEL, icon:Ext.Msg.QUESTION, closable:false, fn:function(btn) {
                      if (btn === 'yes') {
                        me.saveConfig(cfg, window);
                        cfg.getController().loadData(grid.getSelection()[0].data);
                        me.flag = true;
                      } else if (btn === 'no') {
                        if (cfg && cfg.isComponent) {
                          cfg.getController().loadData(grid.getSelection()[0].data);
                        }
                        me.flag = true;
                      } else if (btn === 'cancel') {
                        me.cancelFlag = false;
                        me.flag = true;
                        me.controlFlag = false;
                        count = window.down('grid').getStore().indexOf(rec);
                        grid.setSelection(count);
                      }
                    }});
                  }
                }
              });
            }
          });
        }, rowclick:function(gridView, rec, el, rowIdx, e, eOpts) {
          if (me.flag) {
            var cfg = window.down('exportConfig');
            if (cfg && cfg.isComponent) {
              cfg.getController().loadData(rec.getData());
            }
            me.controlFlag = true;
            me.cancelFlag = true;
          }
        }}}, {xtype:'exportConfig', split:true, border:true, flex:2, moduleId:this.moduleId}]}).show();
        window.down('exportConfig').viewModel.data.saveConfigHidden = true;
        window.down('exportConfig').viewModel.data.generatedocHidden = true;
      }
    }
  } catch (e) {
    console.error('createConfigWindow', e);
  }
}, deleteExportConfig:function(rec, win) {
  try {
    var exportConfigModel = BpcCommon.Api.getSetting(this.moduleId, 'export_config', true);
    var exportConfig = Ext.clone(exportConfigModel.get('value'));
    if (exportConfig && exportConfig.configs && Ext.isArray(exportConfig.configs)) {
      Ext.Array.each(exportConfig.configs, function(config, index, configs) {
        if (rec.get('id') === config.id) {
          configs.splice(index, 1);
          return false;
        }
      });
    }
    exportConfigModel.set('value', exportConfig);
    exportConfigModel.save({failure:function(record, operation) {
      var errorResponse = JSON.parse(operation.getError().response.responseText);
      if (errorResponse) {
        BpcCommon.Api.showNotification({title:errorResponse.error.name, text:errorResponse.error.message, type:'ERROR', popUp:'true'});
      }
    }, success:function(record, operation) {
      Ext.GlobalEvents.fireEvent('exportConfigUpdated', record);
      win.down('grid').getStore().loadData(exportConfig.configs);
    }, callback:function(record, operation, success) {
      win.setLoading(false);
    }});
  } catch (e) {
    console.error('deleteExportConfig', e);
  }
}, saveConfig:function(configName, window) {
  try {
    var configSetting = BpcCommon.Api.getSetting(this.moduleId, 'export_config', true);
    var configItems = configName.form.getFields().items;
    var configSettingItems = configSetting.data.value.configs;
    Ext.each(configSettingItems, function(rec) {
      if (rec.id == configItems[13].value) {
        Ext.each(configItems, function(config) {
          rec[config.name] = config.value;
        });
      }
    });
    configSetting.save({failure:function(record, operation) {
      var errorResponse = JSON.parse(operation.getError().response.responseText);
      if (errorResponse) {
        BpcCommon.Api.showNotification({title:errorResponse.error.name, text:errorResponse.error.message, type:'ERROR', popUp:'true'});
      }
    }, success:function(record, operation) {
      Ext.GlobalEvents.fireEvent('exportConfigUpdated', record);
      window.down('grid').getStore().loadData(configSetting.data.value.configs);
      BpcCommon.Api.showNotification({title:'Updated', text:BpcCommon.Api.getTranslation('DOCUMENTATION_UPDATE_SUCCESS_MSG'), type:'SUCCESS', popUp:'true'});
    }, callback:function(record, operation, success) {
    }});
  } catch (e) {
    console.error('saveConfig', e);
  }
}});
Ext.define('documentation.view.DiagramTree', {extend:'Ext.tree.TreePanel', alias:'widget.diagramTree', mixins:['documentation.mixins.Component'], border:1, animate:true, viewConfig:{plugins:{ptype:'treeviewdragdrop', dragText:'Drag and drop to reorganize'}}, doOpenExpandSelect:function(node) {
  this.expandPath(this.getStore().getNodeById(node.id).getPath());
  this.setSelection(node);
}, findNodesByUrl:function(value, property) {
  property = property === void 0 ? 'imageUrl' : property;
  var nodes = [];
  value = documentation.Module.replaceSpace(value);
  this.getStore().getRoot().findChildBy(function(record) {
    var url = record.get(property) || '';
    if (url.length && url.indexOf(value) !== -1) {
      nodes.push(record);
    }
  }, this, true);
  return nodes;
}, doFindNodes:function(text) {
  var nodes = [];
  this.getStore().getRoot().findChildBy(function(record) {
    if (record.get('text') === text) {
      nodes.push(record);
    }
  }, this, true);
  return nodes;
}, scrollToNodeInTree:function(node) {
  var myNode = this.getStore().getNodeById(node.id);
  var nodeEl = this.getView().getNode(myNode);
  if (nodeEl) {
    this.getView().getScrollable().scrollTo(0, nodeEl.offsetTop, true);
  }
}, doGetStateData:function() {
  var width = this.getWidth();
  this.saveLocal('treegrid', {width:width});
}, setLoading:function() {
  var $jscomp$destructuring$var33 = $jscomp.makeIterator(Array.from(arguments));
  var strOrBool = $jscomp$destructuring$var33.next().value;
  if (typeof strOrBool === 'string') {
    strOrBool = this.TR(strOrBool);
  }
  this.callParent([strOrBool]);
}, beforeNodeDrop:function(data, overModel) {
  var nodeDropped = data.records[0];
  if (!nodeDropped.isLeaf()) {
    var srcRoot = data.view.up('diagramTree').getRootNode();
    var dropNodeFromSrc = srcRoot.findChild('id', nodeDropped.id, true);
    var targetRoot;
    if (overModel.isRoot()) {
      targetRoot = overModel;
    } else {
      targetRoot = overModel.getOwnerTree().getRootNode();
    }
    Ext.createByAlias('widget.docuSelectChildrenWindow', {srcData:data, srcNode:dropNodeFromSrc, targetRoot:targetRoot, srcView:this}).show();
  } else {
    this.processNodeDrop(data, overModel);
  }
  var window = data.view.up('window');
  var checkBoxes = Ext.ComponentQuery.query('checkbox', window);
  if (checkBoxes && Ext.isArray(checkBoxes) && checkBoxes.length > 0) {
    Ext.each(checkBoxes, function(checkBox) {
      var id = checkBox.id;
      Ext.getCmp(id).setValue(true);
    });
  }
}, processNodeDrop:function(data, overModel) {
  var me = this;
  var targetRoot;
  if (overModel.isRoot()) {
    targetRoot = overModel;
  } else {
    targetRoot = overModel.getOwnerTree().getRootNode();
  }
  var nodeDropped;
  if (data.records.length === 1) {
    nodeDropped = data.records[0];
    me.addNodeToTree(nodeDropped, data, targetRoot);
  } else {
    Ext.each(data.records, function(record) {
      me.addNodeToTree(record, data, targetRoot);
    });
  }
}, cancelNodeDrop:function() {
  return false;
}, addNodeToTree:function(nodeDropped, data, targetRoot) {
  var srcRoot, dropChild;
  if (data) {
    srcRoot = data.view.up('diagramTree').getRootNode();
  } else {
    srcRoot = this.up('documentationMain').srcTree.getRootNode();
  }
  dropChild = srcRoot.findChild('id', nodeDropped.getId(), true);
  if (!nodeDropped.isLeaf() && nodeDropped.childNodes.length !== nodeDropped.get('children').length) {
    Ext.each(nodeDropped.get('children'), function(child) {
      nodeDropped.appendChild(dropChild.findChild('text', child.text).copy());
    });
  } else if (!nodeDropped.isLeaf() && nodeDropped.childNodes.length > 0) {
    Ext.each(nodeDropped.get('children'), function(child) {
      targetRoot.appendChild(child);
    });
  }
  if (nodeDropped.isLeaf()) {
    if (targetRoot.findChild('text', dropChild.parentNode.get('text'))) {
      targetRoot.findChild('text', dropChild.parentNode.get('text')).insertChild(0, nodeDropped);
    } else {
      targetRoot.insertChild(0, nodeDropped);
    }
  }
  targetRoot.getOwnerTree().expandAll();
  targetRoot.getOwnerTree().setSelection(nodeDropped);
}});
Ext.define('documentation.view.Main', {extend:'Ext.container.Container', alias:'widget.documentationMain', mixins:['documentation.mixins.Component'], layout:'border', style:'background-color: #fff;', viewModel:{data:{workFlowMetaData:undefined}}, displayTab:undefined, exportTab:undefined, eastPanel:undefined, documentationTabPanel:undefined, openDiagramByName:function(name, targetModuleId) {
  var nodes = this.srcTree.doFindNodes(name);
  var $jscomp$destructuring$var34 = $jscomp.makeIterator(nodes.reverse());
  var node = $jscomp$destructuring$var34.next().value;
  if (!node) {
    var $jscomp$destructuring$var35 = $jscomp.makeIterator(this.srcTree.findNodesByUrl(name).reverse());
    node = $jscomp$destructuring$var35.next().value;
  }
  if (node) {
    this.openNodeTreeElem(node, targetModuleId);
    return true;
  }
}, openNodeTreeElem:function(node, targetModuleId) {
  this.displayTab.activeModuleId = targetModuleId;
  var alreadyOpen = (this.getSelectedDiagramRecord() || {}).id === node.id;
  if (!alreadyOpen) {
    this.srcTree.doOpenExpandSelect(node);
  }
  if (alreadyOpen && typeof targetModuleId !== 'undefined') {
    this.displayTab.highlightTargetModule(targetModuleId);
  }
}, LAST_DIAGRAM_CACHE_ID:'last_diagram_details', doLoadNode:function(node) {
  console.debug('doLoadNode', node);
  if (node.get('leaf')) {
    var data = documentation.util.Url.diagramDataFromRecord(node);
    documentation.util.State.set(this.LAST_DIAGRAM_CACHE_ID, data);
  } else {
    this.infoView.doResetContent();
    this.metaViewMain.doResetContent();
  }
  this.displayTab.handleType(node);
}, initComponent:function() {
  try {
    documentation.Module.language = this.getLanguage();
    this.restBaseUrl = documentation.util.Image.restBaseUrl(this.moduleId);
    this.exportDisabled = this.getSetting('exportDisabled');
    this.bpcModuleHeader = Ext.create({xtype:'container', layout:{type:'hbox', align:'stretch'}, items:[]});
    this.leftToolbar = Ext.create({xtype:'toolbar'});
    this.rightToolbar = Ext.create({xtype:'toolbar'});
    var exportConfigTb = Ext.create({xtype:'exportconfigtoolbar', flex:1, moduleId:this.moduleId, hidden:this.exportDisabled});
    var documentationAppToolbar = Ext.create({xtype:'documentationAppToolbar', moduleId:this.moduleId, moduleInstance:this});
    this.bpcModuleHeader.add([this.leftToolbar, exportConfigTb, documentationAppToolbar, {xtype:'tbfill'}, this.rightToolbar]);
  } catch (e) {
  }
  this.callParent();
  try {
    this.doCreateMainView();
  } catch (e$6) {
  }
}, doCreateMainView:function() {
  var $jscomp$this = this;
  var actions = [{iconCls:this.faIcon('fa-plus'), tooltip:this.TR('CONTEXT_MENU_ADD_TO_EXPORT'), hidden:this.exportDisabled, handler:function(view, rI, cI, item, e, r) {
    return $jscomp$this.addToExport(r);
  }, isActionDisabled:function(view, rI, cI, item, r) {
    var disabled = !r.get('leaf');
    item.iconCls = disabled ? null : $jscomp$this.faIcon('fa-plus');
    item.tooltip = disabled ? null : $jscomp$this.TR('CONTEXT_MENU_ADD_TO_EXPORT');
    return disabled;
  }}, {iconCls:this.faIcon('fa-copy'), tooltip:this.TR('CONTEXT_MENU_COPY_URL_TO_CLIPBOARD'), handler:function(view, rI, cI, item, e, r) {
    $jscomp$this.copyUrl(r);
  }, isActionDisabled:function(view, rI, cI, item, r) {
    var disabled = !r.get('leaf');
    item.iconCls = disabled ? null : $jscomp$this.faIcon('fa-copy');
    item.tooltip = disabled ? null : $jscomp$this.TR('CONTEXT_MENU_COPY_URL_TO_CLIPBOARD');
    return disabled;
  }}].filter(function(item, index) {
    return !(index === 0 && $jscomp$this.exportDisabled);
  });
  var treegridCfg = {region:'west', title:this.TR('SERVER_DIAGRAMS'), iconCls:this.faIcon('fa-sitemap'), rootVisible:false, collapsible:true, columns:[{xtype:'treecolumn', text:this.TR('DIAGRAMS'), dataIndex:'text', flex:1}, {xtype:'actioncolumn', width:actions.length * 30, items:actions}], split:true, emptyText:"\x3cdiv style\x3d'text-align: center;'\x3e" + BpcCommon.Api.getTranslation({key:'DOCUMENTATION_NO_SERVER_DIAGRAMS', data:{userGroup:this.getSetting('userGroup'), diagramType:this.getSetting('displayedDiagramTypes')}}) + 
  '\x3c/div\x3e', root:{nodeType:'async', text:this.TR('SERVER_DIAGRAMS'), draggable:false, expanded:true}, viewConfig:{plugins:{ptype:'treeviewdragdrop', dragText:this.TR('DRAG_DROP_TEXT'), copy:true, enableDrop:false, ddGroup:'myDropGroup'}, selectionModel:{type:'treemodel', ignoreRightMouseSelection:true}}, scrollable:true, containerScroll:true, reorder:false, listeners:{selectionchange:function(selModel, records) {
    var $jscomp$destructuring$var36 = $jscomp.makeIterator(records);
    var record = $jscomp$destructuring$var36.next().value;
    if (record) {
      documentation.Support.closeAllMetaDialogs();
      $jscomp$this.displayTab.folderUpBtn.setDisabled(record.isRoot());
      $jscomp$this.doLoadNode(record);
    }
  }, itemcontextmenu:function() {
    return $jscomp$this.onItemContextMenu;
  }, resize:function(c) {
    return c.saveLocal();
  }}};
  var cfg = this.getLocal('treegrid');
  var $jscomp$destructuring$var37 = cfg || {};
  var width = $jscomp$destructuring$var37.width;
  if (width) {
    treegridCfg.width = width;
  } else {
    treegridCfg.flex = 2;
  }
  this.srcTree = Ext.create('documentation.view.DiagramTree', treegridCfg);
  this.leftToolbar.add({iconCls:this.faIcon('fa-search'), text:this.TR('OPEN_SEARCH'), ui:'primary', handler:function() {
    var stateId = 'window-search';
    var state = documentation.util.State.getWindowState(stateId), position, winWidth, winHeight, validState = false;
    if (state) {
      var hasUndefinedProperties = Object.keys(function(k) {
        return typeof state[k] === 'undefined';
      }).indexOf(true) !== -1;
      validState = !hasUndefinedProperties;
      var $jscomp$destructuring$var38 = state;
      var width$7 = $jscomp$destructuring$var38.width;
      var winX = $jscomp$destructuring$var38.winX;
      var winY = $jscomp$destructuring$var38.winY;
      var height = $jscomp$destructuring$var38.height;
      if (validState) {
        position = [winX, winY];
        winWidth = width$7;
        winHeight = height;
      }
    }
    var w = documentation.Support.getWindow('SEARCH', 'fa-search', 'documentationSearch', {moduleId:$jscomp$this.moduleId, moduleInstance:$jscomp$this, header:false}, stateId);
    if (validState) {
      w.setWidth(winWidth);
      w.setHeight(winHeight);
    }
    documentation.Support.mayShowWindowAt(w, position);
  }});
  this.displayTab = Ext.create('documentation.view.display.DisplayTab', {iconCls:this.faIcon('fa-random'), moduleId:this.moduleId, moduleInstance:this, items:[{xtype:'label', html:this.TR('NO_DISPLAY_DIAGRAMS')}]});
  this.exportTab = Ext.create('documentation.view.export.ExportTab', {iconCls:this.faIcon('fa-download'), moduleId:this.moduleId, hidden:this.exportDisabled});
  this.documentationTabPanel = Ext.create({xtype:'tabpanel', region:'center', flex:5, items:[this.displayTab, this.exportTab]});
  this.infoView = Ext.create({xtype:'imageInfo', moduleId:this.moduleId});
  this.metaViewMain = Ext.create({xtype:'documentationMetaDataView', moduleId:this.moduleId});
  this.exportConfig = Ext.create({xtype:'exportConfig', moduleId:this.moduleId, iconCls:'fa fa-cog', trgTree:this.exportTab, srcTree:this.srcTree, width:370, hidden:this.exportDisabled});
  this.eastPanel = Ext.create({xtype:'tabpanel', region:'east', flex:2, collapsible:true, collapsed:true, split:true, itemId:'eastPanel', hidden:!this.getSetting('show_metadata'), header:false, title:this.TR('OVERVIEW'), iconCls:this.faIcon('fa-info'), layout:'fit', activeTab:0, titleCollapse:true, hideCollapseTool:false, items:[this.infoView, this.metaViewMain, this.exportConfig], listeners:{expand:function(p, eOpts) {
    return $jscomp$this.onEastExpand(p);
  }, resize:function(p) {
    return $jscomp$this.onEastResize(p);
  }, collapse:function() {
    return $jscomp$this.onEastCollapse();
  }}});
  this.add([this.srcTree, this.documentationTabPanel, this.eastPanel]);
  var wfName = this.getSetting('workflow_name');
  var $jscomp$destructuring$var39 = this.getSetting('ui_flags');
  var cacheTreeInLocalStorage = $jscomp$destructuring$var39.cacheTreeInLocalStorage;
  this.delay(300).then(function() {
    $jscomp$this.srcTree.makeStateful('treegrid');
    return $jscomp$this.loadSourceTree();
  }).then(function() {
    if (cacheTreeInLocalStorage) {
      $jscomp$this.sessionCacheKeys.map(function(key) {
        return documentation.util.State.copyFromSession(key);
      });
    }
    var opened = $jscomp$this.mayOpenDiagram(documentation.util.Url.parseParams(window.location.href));
    if (opened) {
      return;
    }
    if ((wfName || '').length) {
      var found = $jscomp$this.openDiagramByName(wfName);
      if (found) {
        return;
      }
    }
    $jscomp$this.openNodeTreeElem($jscomp$this.srcTree.getStore().getRoot());
  });
}, onEastExpand:function(p) {
  Ext.ComponentQuery.query('fieldset[wfModuleId]').map(function(fieldSet) {
    return fieldSet.collapse();
  });
  this.displayTab.collapseButtonRight.setDisabled(false);
  var w = p.getWidth();
  if (w <= 100) {
    p.setWidth(200);
  }
}, onEastCollapse:function() {
  this.displayTab.collapseButtonRight.setDisabled(true);
}, onEastResize:function(p) {
  var w = p.getWidth();
  if (w <= 50) {
    p.collapse();
  }
}, mayOpenDiagram:function(data) {
  var dataValid = this.validDiagramToOpen(data);
  if (dataValid) {
    this.openDiagramFromObject(data);
    return true;
  }
}, openDiagramFromObject:function(data) {
  var $jscomp$destructuring$var40 = data;
  var diagramType = $jscomp$destructuring$var40.diagramType;
  var diagramGroup = $jscomp$destructuring$var40.diagramGroup;
  var diagram = $jscomp$destructuring$var40.diagram;
  var lang = $jscomp$destructuring$var40.lang;
  var moduleId = $jscomp$destructuring$var40.moduleId;
  try {
    var opened = this.openDiagramByName(diagram, moduleId);
    this.srcTree.setLoading(false);
  } catch (e) {
    console.error('error opening diagram', e);
  }
}, validDiagramToOpen:function(data) {
  var $jscomp$destructuring$var41 = data || {};
  var diagramType = $jscomp$destructuring$var41.diagramType;
  var diagramGroup = $jscomp$destructuring$var41.diagramGroup;
  var diagram = $jscomp$destructuring$var41.diagram;
  return [diagramType, diagramGroup, diagram].map(function(v) {
    return v === null || typeof v === 'undefined';
  }).indexOf(true) === -1;
}, onItemContextMenu:function(tree, record, item, index, e, eOpts) {
  var $jscomp$this = this;
  var isLeaf = record.isLeaf();
  if (!isLeaf) {
    return;
  }
  var disableDelete = false;
  var diagramInExportTree = this.exportTab.getRootNode().findChild('text', record.get('text'), true);
  if (!this.exportTab || !diagramInExportTree) {
    disableDelete = true;
  }
  var treeMenu = new Ext.menu.Menu({items:[{text:this.TR('CONTEXT_MENU_ADD_TO_EXPORT'), iconCls:this.faIcon('fa-plus'), disabled:!disableDelete, handler:function() {
    return $jscomp$this.addToExport(record);
  }}, {text:this.TR('CONTEXT_MENU_DELETE_TO_EXPORT'), iconCls:this.faIcon('fa-minus'), disabled:disableDelete, handler:function(btn) {
    return diagramInExportTree.remove();
  }}, {text:this.TR('CONTEXT_MENU_COPY_URL_TO_CLIPBOARD'), iconCls:this.faIcon('fa-copy'), handler:function() {
    var record = $jscomp$this.getSelectedDiagramRecord();
    $jscomp$this.copyUrl(record);
  }}]});
  e.stopEvent();
  treeMenu.showAt(e.getXY());
}, getSelectedDiagramRecord:function() {
  var $jscomp$destructuring$var42 = $jscomp.makeIterator(this.srcTree.getSelection());
  var record = $jscomp$destructuring$var42.next().value;
  return record;
}, addToExport:function(record) {
  this.exportTab.addNodeToTree(record.copy(), null, this.exportTab.getRootNode());
  this.documentationTabPanel.setActiveTab(this.exportTab);
}, copyUrl:function(record, trKey) {
  trKey = trKey === void 0 ? 'URL_COPIED_SUCCESSFULLY' : trKey;
  if (!record) {
    return;
  }
  return this.doCopy(documentation.util.Url.getUrlFromRecord(record), trKey);
}, loadSourceTree:function() {
  var $jscomp$this = this;
  try {
    this.srcTree.setLoading('LOAD_DATA');
    var id = this.moduleId + '_root_' + documentation.Module.language;
    var data = this.getCacheFromBoth(id);
    if (data) {
      return this.doLoadTree(data);
    }
    return new Promise(function(resolve, reject) {
      var reqConfig = $jscomp$this._baseRequestConfig();
      reqConfig.params.diagramType = encodeURIComponent($jscomp$this.getSetting('displayedDiagramTypes').toString().replace(/\s/g, ''));
      Ext.Ajax.request(Ext.apply(reqConfig, {url:$jscomp$this.restBaseUrl, success:function(response) {
        var data;
        var $jscomp$destructuring$var43 = response;
        var responseXML = $jscomp$destructuring$var43.responseXML;
        if (responseXML) {
          data = $jscomp$this.constructTreeResponse(responseXML);
        }
        if (!data) {
          BpcCommon.Api.showNotification(BpcCommon.Api.getTranslation({key:'DOCUMENTATION_NO_SERVER_DIAGRAMS', data:{userGroup:$jscomp$this.getSetting('userGroup'), diagramType:$jscomp$this.getSetting('displayedDiagramTypes')}}));
          $jscomp$this.srcTree.getStore().removeAll();
        } else {
          documentation.util.SessionState.set(id, data);
          $jscomp$this.sessionCacheKeys.push(id);
          $jscomp$this.doLoadTree(data).then(function() {
            resolve(response.status);
          });
        }
      }, failure:function(response) {
        var k = 'ERROR_LOAD_DIAGRAMS';
        var $jscomp$destructuring$var44 = response;
        var status = $jscomp$destructuring$var44.status;
        if (status === 503) {
          k = 'SERVICE_UNAVAILABLE_MSG';
        } else if (status === 401) {
          k = 'UNAUTHORIZED';
        } else if (status === 417) {
          k = 'EXPECTATION_FAILED';
        }
        BpcCommon.Api.showNotification(BpcCommon.Api.getTranslation(k));
        $jscomp$this.srcTree.setLoading(false);
        reject(response.status);
      }}));
    });
  } catch (e) {
    console.error('loadSourceTree', e);
  }
}, doLoadTree:function(data) {
  var $jscomp$this = this;
  data.root.expanded = true;
  this.srcTree.getStore().setRoot(data.root);
  this.srcTree.setLoading('LOADING_WORKFLOWTYPES');
  return this.loadDiagramTypes().then(function(childNodes) {
    $jscomp$this.srcTree.setLoading('LOADING_PROCESSGROUPS');
    return $jscomp$this.loadProcessGroups(childNodes);
  }).then(function() {
    $jscomp$this.srcTree.setLoading(false);
  });
}, loadDiagramTypes:function(node) {
  var $jscomp$this = this;
  node = node || this.srcTree.getStore().getRoot();
  var proms = [];
  var childNodes = [];
  node.eachChild(function(childNode) {
    childNodes.push(childNode);
    proms.push($jscomp$this.onProcessTreeNodeBeforeExpand(childNode));
  });
  return Promise.all(proms).then(function() {
    return childNodes;
  });
}, loadProcessGroups:function(nodes) {
  var $jscomp$this = this;
  var processGroups = [];
  nodes.map(function(n) {
    n.eachChild(function(c) {
      processGroups.push($jscomp$this.onProcessTreeNodeBeforeExpand(c));
    });
  });
  return Promise.all(processGroups);
}, sessionCacheKeys:[], onProcessTreeNodeBeforeExpand:function(node, eOpts) {
  var $jscomp$this = this;
  var nodeType = node.get('type');
  var childCount = (node.childNodes || []).length;
  if (childCount === 0) {
    if (nodeType === 'wfType' || nodeType === 'processGroup') {
      var url = node.get(nodeType === 'wfType' ? 'wfTypeUrl' : 'pgUrl');
      var id = this.moduleId + '_' + nodeType + '_' + url + documentation.Module.language;
      var data = this.getCacheFromBoth(id);
      if (data) {
        return Promise.resolve(this.doHandleData(data, node));
      }
      return new Promise(function(resolve, reject) {
        Ext.Ajax.request(Ext.apply($jscomp$this._baseRequestConfig(), {url:url, success:function(response, opts) {
          var data = nodeType === 'wfType' ? $jscomp$this.handleProcessGroupResponse(response, node) : $jscomp$this.handleProcessResponse(response, node);
          documentation.util.SessionState.set(id, data);
          $jscomp$this.sessionCacheKeys.push(id);
          resolve($jscomp$this.doHandleData(data, node));
        }, failure:function(response, opts) {
          reject(response.status);
        }}));
      });
    }
  }
}, doCreateNodes:function(xml, elemName, nodeFn) {
  var elems = xml.getElementsByTagName(elemName);
  return Array.from(elems).map(nodeFn);
}, handleProcessGroupResponse:function(response, node) {
  var $jscomp$destructuring$var45 = response || {};
  var responseXML = $jscomp$destructuring$var45.responseXML;
  if (responseXML) {
    var diagramType = node.get('diagramType');
    var me = this;
    return this.doCreateNodes(responseXML, 'Group', function(elem) {
      var href = elem.getAttribute('href');
      var $jscomp$destructuring$var46 = $jscomp.makeIterator((href || '').split('/').reverse());
      var diagramNameWithParams = $jscomp$destructuring$var46.next().value;
      var $jscomp$destructuring$var47 = $jscomp.makeIterator(diagramNameWithParams.split('?'));
      var diagramName = $jscomp$destructuring$var47.next().value;
      var pgUrl = me.restBaseUrl + [diagramType, documentation.Module.replaceSpace(diagramName)].join('/');
      return {wfType:elem.getAttribute('name'), text:elem.getAttribute('name'), draggable:'true', nodeHref:elem.getAttribute('href'), leaf:false, userGroup:elem.getAttribute('group'), wfUser:elem.getAttribute('user'), type:'processGroup', pgHref:documentation.Module.replaceSpace(diagramName), diagramType:diagramType, pgUrl:pgUrl};
    });
  }
  return [];
}, doHandleData:function(data, node) {
  data = data === void 0 ? [] : data;
  data.sort(documentation.Support.getSortArrayFunction());
  node.appendChild(data);
  return data;
}, handleProcessResponse:function(response, node) {
  var $jscomp$destructuring$var48 = response || {};
  var responseXML = $jscomp$destructuring$var48.responseXML;
  if (responseXML) {
    var wfType = node.get('diagramType');
    var pgHref = node.get('pgHref');
    var diagramGroup = node.get('text');
    return this.doCreateNodes(responseXML, 'Process', function(p) {
      var href = p.getAttribute('href');
      var diagramNamelist = href.split('/');
      var diagramName = diagramNamelist[diagramNamelist.length - 1];
      var imageUrl = [wfType, diagramGroup, diagramName].map(function(s) {
        return documentation.Module.replaceSpace(s);
      }).join('/');
      var name = p.getAttribute('name');
      return {text:name, name:name, draggable:'true', nodeHref:href, leaf:true, userGroup:p.getAttribute('group'), wfUser:p.getAttribute('user'), type:'process', wfType:wfType, diagramType:wfType, diagramGroup:diagramGroup, diagramName:name, _diagramName:diagramName, pgHref:pgHref, icon:'/bpc-fe-documentation/resources/icons/' + wfType + '.png', imageUrl:imageUrl};
    });
  }
  return [];
}, constructTreeResponse:function(responseXml) {
  var $jscomp$this = this;
  var wfTypes = responseXml.getElementsByTagName('Type');
  var children = Array.from(wfTypes).map(function(wfType) {
    var wfTypeName = wfType.getAttribute('name');
    var text = wfTypeName || '';
    var sequence = 0;
    if (text === 'bpd') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_BPD');
      sequence = 1;
    } else if (text === 'technical') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_TECHNICAL');
      sequence = 6;
    } else if (text === 'soamap') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_SOAMAP');
      sequence = 4;
    } else if (text === 'systemdiagram') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_SYSTEMDIAGRAM');
      sequence = 5;
    } else if (text === 'organigram') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_ORGANIGRAM');
      sequence = 3;
    } else if (text === 'processmap') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_PROCESSMAP');
    } else if (text === 'constraintsdiagram') {
      text = $jscomp$this.TR('DIAGRAM_TYPE_CONSTRAINTSDIAGRAM');
      sequence = 2;
    }
    return {wfType:wfTypeName, sequence:sequence, text:text, nodeHref:wfType.getAttribute('href'), draggable:false, leaf:false, userGroup:$jscomp$this.getSetting($jscomp$this.moduleId, 'userGroup'), type:'wfType', diagramType:wfTypeName, wfTypeUrl:$jscomp$this.restBaseUrl + wfTypeName};
  });
  children.sort(documentation.Support.getSortArrayFunction('sequence', 'sequence', false));
  return {root:{text:this.TR('SERVER_DIAGRAMS'), draggable:'false', children:children}};
}, _baseRequestConfig:function() {
  return {method:'GET', defaultHeaders:{'Content-Type':'application/x-www-form-urlencoded; charset\x3dUTF-8'}, params:{userGroup:encodeURIComponent(this.getSetting('userGroup').toString().trim()), lang:documentation.Module.language}};
}, refreshTree:function() {
}});
Ext.define('documentation.view.Search', {extend:'Ext.panel.Panel', alias:'widget.documentationSearch', mixins:['documentation.mixins.Component'], frame:true, rotation:0, scrollable:true, layout:{type:'vbox', align:'stretch'}, moduleInstance:undefined, initComponent:function() {
  var $jscomp$this = this;
  this.iconCls = this.faIcon('fa-search');
  this.title = this.TR('SEARCH');
  this.searchField = Ext.create({xtype:'textfield', flex:1, enableKeyEvents:true, listeners:{keypress:function(textfield, eo) {
    if (eo.getCharCode() == Ext.EventObject.ENTER && (textfield.getValue() || '').length > 0) {
      $jscomp$this.searchForText();
    }
  }, change:function(f, value) {
    value = value || '';
    $jscomp$this.searchButton.setDisabled(value.length === 0);
  }, afterrender:function(field) {
    field.focus();
  }}});
  this.searchButton = Ext.create({xtype:'button', iconCls:this.faIcon('fa-search'), disabled:true, text:this.TR('SEARCH'), ui:'primary', handler:function() {
    return $jscomp$this.searchForText();
  }});
  var tbTop = this.defaultDockTb('top');
  Object.assign(tbTop, {items:[this.searchField, this.searchButton]});
  var tbBottom = this.defaultDockTb('bottom');
  Object.assign(tbBottom, {items:[{xtype:'tbfill'}, {text:this.TR('CLOSE'), iconCls:this.faIcon('fa-times'), ui:'secondary', handler:function() {
    $jscomp$this.up('window').close();
  }}]});
  this.dockedItems = [tbTop, tbBottom];
  this.callParent(arguments);
}, loadResultDiagram:function(resultData, diagramType) {
  var $jscomp$this = this;
  var $jscomp$destructuring$var49 = resultData;
  var Objects = $jscomp$destructuring$var49.Objects;
  return Objects.map(function(diagramData) {
    var $jscomp$destructuring$var50 = diagramData || {};
    var workflowDisplayName = $jscomp$destructuring$var50.workflowDisplayName;
    return {xtype:'tabpanel', frame:true, items:[{xtype:'panel', moduleId:$jscomp$this.moduleId, bodyPadding:20, width:'100%', layout:{type:'vbox', pack:'start', align:'stretch'}, 'default':{width:'100%', minHeight:20}, icon:'/bpc-fe-documentation/resources/icons/' + diagramType + '.png', iconAlign:'left', title:$jscomp$this.highlightSearchString(workflowDisplayName, $jscomp$this.searchField.getValue()), items:$jscomp$this.loadModuleForDiagrams(diagramData, diagramType), tabConfig:{listeners:{click:function() {
      $jscomp$this.openWorkflow(diagramData);
    }}}}]};
  });
}, openWorkflow:function(diagramData) {
  var $jscomp$destructuring$var51 = diagramData;
  var workflowDisplayName = $jscomp$destructuring$var51.workflowDisplayName;
  var targetModuleId = $jscomp$destructuring$var51.targetModuleId;
  this.moduleInstance.openDiagramByName(workflowDisplayName, targetModuleId);
}, loadModuleForDiagrams:function(diagramData, diagramType) {
  var $jscomp$this = this;
  var $jscomp$destructuring$var52 = diagramData;
  var moduleList = $jscomp$destructuring$var52.moduleList;
  var comments = $jscomp$destructuring$var52.comments;
  var diagramComment = comments || '';
  var commentsContainer = diagramComment !== '' ? [{header:false, html:this.highlightSearchString(diagramComment, this.searchField.getValue()), width:'100%'}] : [];
  moduleList = moduleList || [];
  var modules = moduleList.map(function(module) {
    return {xtype:'panel', header:false, items:$jscomp$this.loadModuleElement(diagramData, module, diagramType), layout:{type:'hbox', pack:'start', align:'stretch'}, width:'100%'};
  });
  return commentsContainer.concat(modules);
}, loadModuleElement:function(diagramData, eachModule, diagramType) {
  var $jscomp$this = this;
  var moduleItem = [];
  var moduleTypeProp = '';
  if (diagramType === 'bpd') {
    var propertyArr = eachModule.properties;
    if (propertyArr) {
      for (var j = 0; j < propertyArr.length; j++) {
        var propertyName = propertyArr[j].name;
        if (propertyName === 'TriggeredByEvent' && eachModule.moduleType === 'SubProcess' && propertyArr[j].innerHTML === 'true') {
          moduleTypeProp = 'Event';
        }
        if (eachModule.moduleType === 'Gateway' && propertyName === 'GatewayType') {
          moduleTypeProp = propertyArr[j].displayValue;
        }
        if ((eachModule.moduleType === 'StartEvent' || eachModule.moduleType === 'IntermediateEvent') && propertyName === 'TriggerType') {
          moduleTypeProp = propertyArr[j].displayValue;
        }
        if (eachModule.moduleType === 'Task' && propertyName === 'TaskType') {
          moduleTypeProp = propertyArr[j].displayValue;
        }
        if (eachModule.moduleType === 'StopEvent' && propertyName === 'ResultType') {
          moduleTypeProp = propertyArr[j].displayValue;
        }
      }
    }
  }
  var module = {WorkFlowType:diagramType, ModuleType:diagramType === 'technical' ? eachModule.technicalModuleType : eachModule.moduleType, ModuleTypeProp:moduleTypeProp};
  var moduleName = this.highlightSearchString(eachModule.moduleDisplayName, this.searchField.getValue()) + ' (' + documentation.LegendIconMapping.getModuleNameForSearch(diagramType, eachModule.moduleType) + ')';
  var iconLink = documentation.LegendIconMapping.getIconSrc(module);
  if (iconLink) {
    moduleName = '\x3cu\x3e\x3cimg src\x3d"' + iconLink.src + '" style\x3d"display: inline-block;position: relative;top:2px; height:15px;width:17px"/\x3e\x26nbsp;\x26nbsp;' + moduleName + '\x3c/u\x3e';
  } else {
    moduleName = '\x3cu\x3e' + moduleName + '\x3c/u\x3e';
  }
  if (eachModule.moduleComments !== '') {
    moduleName = moduleName + '\x3cp\x3e\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;' + this.highlightSearchString(eachModule.moduleComments, this.searchField.getValue()) + '\x3c/p\x3e';
  }
  moduleItem.push({html:moduleName, minHeight:25, header:false, flex:1, listeners:{'afterrender':function(panel) {
    panel.el.on('click', function() {
      var data = Object.assign({}, diagramData);
      data.targetModuleId = eachModule.moduleId;
      $jscomp$this.openWorkflow(data);
    });
  }, el:{mouseover:function(e, el, eOpts) {
    this.el.setStyle('cursor', 'pointer');
  }, mouseout:function(e, el) {
  }}}});
  if (eachModule.metadata && eachModule.metadata.length > 0) {
    moduleItem.push({header:false, html:'\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x26nbsp;\x3cimg style\x3d"visibility:hidden;" src\x3d"' + iconLink.src + '" height\x3d"15" width\x3d"17"/\x3eMetadata', flex:2, listeners:{'afterrender':function(panel) {
      panel.el.on('click', function() {
        var modifiedMetadata = [];
        Ext.each(eachModule.metadata, function(eachMetadata) {
          eachMetadata.Name = $jscomp$this.highlightSearchString(eachMetadata.Name, $jscomp$this.searchField.getValue());
          if (eachMetadata.Type === 'LinkToObject') {
            modifiedMetadata.push({Name:eachMetadata.Name, Type:eachMetadata.Type, Search:true, Value:{WorkflowDisplayName:eachMetadata.Value.workflowDisplayName, WorkflowType:eachMetadata.Value.workflowType, WorkflowGroupDisplayName:eachMetadata.Value.workflowGroupDisplayName, ModuleName:eachMetadata.Value.moduleName, WorkflowName:eachMetadata.Value.workflowName, WorkflowGroup:eachMetadata.Value.workflowGroupName, WorkflowUserGroup:eachMetadata.Value.workflowUserGroup}});
          } else {
            eachMetadata.Search = true;
            eachMetadata.Value = $jscomp$this.highlightSearchString(eachMetadata.Value, $jscomp$this.searchField.getValue());
            modifiedMetadata.push(eachMetadata);
          }
        });
        $jscomp$this.wfModule = {MetaData:modifiedMetadata};
        documentation.Support.createMetaWindow($jscomp$this, documentation.LegendIconMapping.getModuleNameForSearch(diagramType, eachModule.moduleType).toUpperCase());
      });
    }, el:{mouseover:function(e, el, eOpts) {
      this.el.setStyle('cursor', 'pointer');
    }}}});
  }
  return moduleItem;
}, searchForText:function() {
  var $jscomp$this = this;
  this.removeAll();
  this.setLoading(this.TR('LOADING_DATA'));
  Ext.Ajax.request({method:'GET', defaultHeaders:{'Content-Type':'application/x-www-form-urlencoded; charset\x3dUTF-8'}, url:documentation.Module.moduleBaseUrl() + 'search/' + encodeURIComponent(this.moduleId) + '?' + (new URLSearchParams({searchText:this.searchField.getValue(), userGroup:(this.getSetting('userGroup') || '').trim(), lang:this.getLanguage(), diagramType:this.getSetting('displayedDiagramTypes').toString().replace(/\s/g, '')})).toString(), success:function(response, opts) {
    $jscomp$this.handleResponse(response);
    $jscomp$this.setLoading(false);
  }, failure:function(response, opts) {
    $jscomp$this.setLoading(false);
  }});
}, handleResponse:function(response) {
  var $jscomp$destructuring$var53 = response || {};
  var responseText = $jscomp$destructuring$var53.responseText;
  if (responseText) {
    var $jscomp$destructuring$var54 = documentation.Support.decode(responseText) || {};
    var SearchResult = $jscomp$destructuring$var54.SearchResult;
    SearchResult = SearchResult || {};
    if (Object.keys(SearchResult).length) {
      this.add(this.createSearchResultMain(SearchResult));
    } else {
      this.add({html:this.TR('NO_SEARCHRESULT')});
    }
  }
}, createSearchResultMain:function(SearchResult) {
  var $jscomp$this = this;
  var tabPanel = Ext.create({xtype:'tabpanel'});
  var tabs = Object.keys(SearchResult).map(function(diagramType) {
    return $jscomp$this.createMainSearchResultPanel(SearchResult[diagramType], diagramType);
  });
  tabPanel.add(tabs);
  if (tabs.length) {
    tabPanel.setActiveTab(0);
  }
  return tabPanel;
}, createMainSearchResultPanel:function(data, diagramType) {
  return Ext.create({xtype:'panel', moduleId:this.moduleId, itemId:diagramType, bodyPadding:10, icon:'/bpc-fe-documentation/resources/icons/' + diagramType + '.png', iconAlign:'left', title:documentation.Support.getWorkflowName(diagramType) + ' [' + data.Size + ']', items:this.loadResultDiagram(data, diagramType)});
}, highlightSearchString:function(displayName, searchText) {
  var displayNameString = JSON.stringify(displayName);
  var replacedString = displayNameString.replace(new RegExp('(' + searchText + ')', 'ig'), '\x3cb\x3e$1\x3c/b\x3e');
  return JSON.parse(replacedString);
}});
Ext.define('documentation.view.display.DisplayTab', {extend:'Ext.panel.Panel', alias:'widget.documentationDisplayTab', mixins:['documentation.mixins.Component'], frame:true, itemId:'displayTab', rotation:0, scrollable:true, layout:'fit', imageUrl:undefined, imageScale:100, viewModel:{data:{metaData:undefined, workFlowType:undefined, node:undefined, isScaled:false, enableZoomIn:true, enableZoomOut:true}}, activeModuleId:undefined, handleType:function(node) {
  var isImage = node.get('leaf');
  this.folderUpBtn.setVisible(!isImage);
  this.zoomInBtn.setVisible(isImage);
  this.zoomOutBtn.setVisible(isImage);
  this.resetBtn.setVisible(isImage);
  this.copyUrlBtn.setVisible(isImage);
  this.openXmlMetaBtn.setVisible(isImage);
  this.lastNode = node;
  try {
    this.pathField.setValue(this.getPathForNode(node).join(' \x3e '));
  } catch (e) {
    console.error('path handle error', e);
  }
  if (isImage) {
    this.loadImageDataForNode(node);
  } else {
    this.removeAll();
    this.add({xtype:'documentationThumbPreview', moduleId:this.moduleId, moduleInstance:this.moduleInstance, node:node});
  }
}, getPathForNode:function(node) {
  var $jscomp$this = this;
  var recordIds = (node.getPath() || '').split('/');
  return recordIds.map(function(name) {
    if (name === 'root') {
      return name;
    } else {
      var r = $jscomp$this.moduleInstance.srcTree.store.getById(name);
      if (r) {
        return r.get('text');
      }
      return name;
    }
  }).filter(function(n) {
    return (n || '').trim().length > 0 && (n || '').trim() !== 'root';
  });
}, newButtonCfg:function(cfg, margin) {
  margin = margin === void 0 ? 3 : margin;
  return Object.assign({xtype:'button', ui:'secondary', hidden:true, margin:this.paddedIntString(margin)}, cfg);
}, newButton:function(cfg) {
  return Ext.create(this.newButtonCfg(cfg));
}, initComponent:function() {
  var $jscomp$this = this;
  this.title = this.TR('DISPLAY');
  this.folderUpBtn = this.newButton({iconCls:this.faIcon('fa-arrow-up'), text:this.TR('ARROW_UP'), handler:function() {
    var $jscomp$destructuring$var55 = $jscomp.makeIterator($jscomp$this.moduleInstance.srcTree.getSelection());
    var currentSelection = $jscomp$destructuring$var55.next().value;
    if (currentSelection && !currentSelection.isRoot() && currentSelection.parentNode) {
      $jscomp$this.moduleInstance.openNodeTreeElem(currentSelection.parentNode);
    }
  }});
  this.zoomInBtn = this.newButton({iconCls:this.faIcon('fa-search-plus'), handler:function() {
    return $jscomp$this.resizeImage(10);
  }, text:this.TR('ZOOM_IN')});
  this.zoomOutBtn = this.newButton({iconCls:this.faIcon('fa-search-minus'), handler:function() {
    return $jscomp$this.resizeImage(-10);
  }, text:this.TR('ZOOM_OUT')});
  this.resetBtn = this.newButton({iconCls:this.faIcon('fa-expand'), handler:function() {
    return $jscomp$this.resizeImage('reset');
  }, text:this.TR('ORIGINAL_SIZE')});
  var uiFlags = this.getSetting('ui_flags') || {};
  var $jscomp$destructuring$var56 = uiFlags;
  var hideBreadCrumb = $jscomp$destructuring$var56.hideBreadCrumb;
  hideBreadCrumb = typeof hideBreadCrumb === 'boolean' ? hideBreadCrumb : false;
  this.pathField = Ext.create({hidden:hideBreadCrumb, xtype:'displayfield', fieldLabel:' ', labelWidth:0, ui:'primary', labelSeparator:'', value:'', flex:1, fieldStyle:{textWrapMode:'nowrap'}});
  this.openXmlMetaBtn = this.newButton({iconCls:this.faIcon('fa-file'), hidden:!BpcCommon.Api.hasUserRight('documentation-debugger'), disabled:true, handler:function() {
    var w = documentation.Support.getWindow('XML', 'fa-file', 'documentationTextEditor', {value:$jscomp$this.lastXmlString});
    w.show();
  }, text:this.TR('OPEN_XML')});
  this.copyUrlBtn = this.newButton({iconCls:this.faIcon('fa-copy'), handler:function() {
    return $jscomp$this.copyUrl();
  }, text:this.TR('COPY_URL')});
  this.collapseButtonRight = this.newButton({iconCls:this.faIcon('fa-chevron-right'), hidden:false, disabled:true, handler:function() {
    $jscomp$this.moduleInstance.eastPanel.collapse();
  }, text:this.TR('COLLAPSE')});
  this.tbar = [this.folderUpBtn, this.zoomInBtn, this.zoomOutBtn, this.resetBtn, this.pathField, {xtype:'tbfill'}, this.openXmlMetaBtn, this.copyUrlBtn, this.collapseButtonRight];
  this.callParent(arguments);
}, getLastUrl:function() {
  return this.lastNode ? documentation.util.Url.getUrlFromRecord(this.lastNode) : undefined;
}, copyUrl:function() {
  var url = this.getLastUrl();
  if (url) {
    this.doCopy(url, 'URL_COPIED_SUCCESSFULLY');
  }
}, zoomValue:100, resizeImage:function(scale) {
  var node = this.getViewModel().get('node');
  var zoomValue = node.get('zoomValue') ? node.get('zoomValue') : this.zoomValue;
  if (scale === 'reset') {
    zoomValue = 100;
  } else if (scale === 'fit') {
  } else {
    zoomValue = zoomValue + scale;
  }
  if (zoomValue < 30) {
    zoomValue = 30;
    this.getViewModel().set('enableZoomOut', false);
  } else if (zoomValue > 300) {
    zoomValue = 300;
    this.getViewModel().set('enableZoomIn', false);
  } else {
    this.getViewModel().set('enableZoomIn', true);
    this.getViewModel().set('enableZoomOut', true);
  }
  zoomValue = parseInt(zoomValue);
  this.zoomValue = zoomValue;
  node.set('zoomValue', zoomValue);
  var $jscomp$destructuring$var57 = $jscomp.makeIterator(this.query('draw'));
  var hlCmp = $jscomp$destructuring$var57.next().value;
  var $jscomp$destructuring$var58 = hlCmp || {};
  var targetModuleId = $jscomp$destructuring$var58.targetModuleId;
  this.doLoadImageFromNode(node, targetModuleId);
}, doLoadImageFromNode:function(node, targetModuleId) {
  this.loadImage(documentation.util.Image.getImageUrl(this.moduleInstance.moduleId, node), targetModuleId);
}, loadImageDataForNode:function(node) {
  var $jscomp$this = this;
  this.removeAll();
  this.getViewModel().set('node', node);
  var diagramNamelist = node.data.nodeHref.split('/');
  var diagramNamehref = diagramNamelist[diagramNamelist.length - 1];
  var view = this.moduleInstance;
  this.setLoading('LOADING_META_DATA');
  this.loadImageMeta(diagramNamehref).then(function(resolveObj) {
    var $jscomp$destructuring$var59 = resolveObj || {};
    var data = $jscomp$destructuring$var59.data;
    var xml = $jscomp$destructuring$var59.xml;
    if (data) {
      $jscomp$this.lastXmlString = xml;
      var $jscomp$destructuring$var60 = data;
      var Workflow = $jscomp$destructuring$var60.Workflow;
      var DataLinks = $jscomp$destructuring$var60.DataLinks;
      var ConnectionLineLinks = $jscomp$destructuring$var60.ConnectionLineLinks;
      var $jscomp$destructuring$var61 = view;
      var metaViewMain = $jscomp$destructuring$var61.metaViewMain;
      var infoView = $jscomp$destructuring$var61.infoView;
      metaViewMain.getViewModel().set('metaData', Workflow);
      metaViewMain.getViewModel().set('DataLinks', DataLinks);
      metaViewMain.getViewModel().set('ConnectionLineLinks', ConnectionLineLinks);
      infoView.getViewModel().set('metaData', Workflow);
      view.getViewModel().set('workFlowMetaData', Workflow);
      view.getViewModel().set('DataLinks', DataLinks);
      view.getViewModel().set('ConnectionLineLinks', ConnectionLineLinks);
      var url = documentation.util.Image.getImageUrl(view.moduleId, node);
      $jscomp$this.setLoading('LOADING_DIAGRAM_IMAGE');
      return documentation.util.Image.getImageAsDataUrl(url);
    }
    throw new Error('meta data not loaded');
  }).then(function() {
    $jscomp$this.setLoading(false);
    view.infoView.updateView();
    view.metaViewMain.updateView();
    $jscomp$this.doLoadImageFromNode(node);
  })["catch"](function() {
    BpcCommon.Api.showNotification(BpcCommon.Api.getTranslation('DOCUMENTATION_REJECT_STATUS'));
  });
}, loadImage:function(imgPath, targetModuleId) {
  var $jscomp$this = this;
  try {
    var $jscomp$destructuring$var62 = $jscomp.makeIterator(imgPath.split('?'));
    var url = $jscomp$destructuring$var62.next().value;
    var params = $jscomp$destructuring$var62.next().value;
    var $jscomp$destructuring$var63 = documentation.util.Url.parseParams(params);
    var lang = $jscomp$destructuring$var63.lang;
    var zoomScaleValue = $jscomp$destructuring$var63.zoomScaleValue;
    if (zoomScaleValue === '1') {
      var $jscomp$destructuring$var64 = $jscomp.makeIterator(url.split('/').reverse());
      var imagePath = $jscomp$destructuring$var64.next().value;
      var id = [imagePath, 'image', lang, zoomScaleValue].join('_');
      var data = documentation.util.Cache.get(id);
      var $jscomp$destructuring$var65 = data || {};
      var dataUrl = $jscomp$destructuring$var65.dataUrl;
      if (dataUrl) {
        imgPath = dataUrl;
      }
    }
    this.removeAll();
    this.rotation = 0;
    this.setLoading(this.TR('LOADING_DATA'));
    var workFlowMetaData = this.getViewModel().get('workFlowMetaData');
    var hotSpots = this.prepareHotSpots(workFlowMetaData);
    var dataLinks = this.getViewModel().get('DataLinks');
    if (dataLinks && dataLinks.length > 0) {
      this.prepareDataLinkasHotSpot(dataLinks, hotSpots);
    }
    var connectionLinks = this.getViewModel().get('ConnectionLineLinks');
    if (connectionLinks && connectionLinks.length > 0) {
      this.prepareConnectionLineLinkAsHotSpot(connectionLinks, hotSpots);
    }
    this.imageMap = null;
    this.imageMapWrapper = Ext.create({xtype:'container', layout:'center', listeners:{afterrender:function(c) {
      $jscomp$this.getEl().on('click', function(cmp, elem) {
        if (elem.id === $jscomp$this.imageMapWrapper.id) {
          documentation.Support.closeAllMetaDialogs();
        }
      });
    }}});
    this.add(this.imageMapWrapper);
    this.srcHotSpots = hotSpots.map(function(hs) {
      return hs;
    });
    this.imageMap = this.imageMapWrapper.add({xtype:'imageMap', moduleInstance:this.moduleInstance, src:imgPath, hotSpots:hotSpots});
    this.img = new Image();
    this.img.onload = function() {
      $jscomp$this.readImageSize();
      if ($jscomp$this.activeModuleId) {
        targetModuleId = targetModuleId || $jscomp$this.activeModuleId;
      }
      $jscomp$this.highlightTargetModule(targetModuleId);
      $jscomp$this.activeModuleId = undefined;
    };
    this.img.src = imgPath;
  } catch (e) {
    console.error('error opening diagram', e);
  }
}, getTargetHotspot:function(targetModuleId) {
  var $jscomp$destructuring$var66 = $jscomp.makeIterator(this.srcHotSpots.filter(function(hs) {
    return hs.id === targetModuleId;
  }));
  var targetModuleSourceDimension = $jscomp$destructuring$var66.next().value;
  return targetModuleSourceDimension;
}, doGetSprite:function(targetModuleId) {
  var workFlowMetaData = this.getViewModel().get('workFlowMetaData');
  var targetModuleSourceDimension;
  if (targetModuleId) {
    targetModuleSourceDimension = this.getTargetHotspot(targetModuleId);
  }
  if (targetModuleSourceDimension) {
    var margin = workFlowMetaData.WorkFlowType === 'technical' ? 0 : 5;
    var $jscomp$destructuring$var67 = targetModuleSourceDimension;
    var x1 = $jscomp$destructuring$var67.x1;
    var y1 = $jscomp$destructuring$var67.y1;
    var x2 = $jscomp$destructuring$var67.x2;
    var y2 = $jscomp$destructuring$var67.y2;
    x1 = x1 * this.zoomValue / 100;
    x2 = x2 * this.zoomValue / 100;
    y1 = y1 * this.zoomValue / 100;
    y2 = y2 * this.zoomValue / 100;
    return {x:x1 - margin, y:y1 - margin, width:x2 - x1 + 2 * margin, height:y2 - y1 + 2 * margin};
  }
}, highlightTargetModule:function(targetModuleId) {
  var sprite = this.doGetSprite(targetModuleId);
  if (sprite) {
    var zoomValue = this.zoomValue;
    this.query('draw').map(function(cmp) {
      return cmp.destroy();
    });
    this.addHighlightComponent({xtype:'draw', targetModuleId:targetModuleId, itemId:'highlightImage', bodyStyle:'background:transparent !important;', listeners:{render:function(c) {
      c.getEl().on({click:function() {
        var highLight = c.getEl();
        if (highLight) {
          highLight.el.hide();
          c.destroy();
        }
      }});
    }}, sprites:[this.getSpriteCfg(sprite)]});
    var $jscomp$destructuring$var68 = sprite;
    var x = $jscomp$destructuring$var68.x;
    var y = $jscomp$destructuring$var68.y;
    var scrollId = this.getEl().el.component.body.getId();
    var ele = Ext.getElementById(scrollId);
    ele.scroll(x * (zoomValue / 100), y * (zoomValue / 100));
  }
}, getSpriteCfg:function(sprite) {
  var sprites = sprite;
  var $jscomp$destructuring$var69 = sprites;
  var x = $jscomp$destructuring$var69.x;
  var y = $jscomp$destructuring$var69.y;
  var width = this.imageMap.getWidth();
  var height = this.imageMap.getHeight();
  var drawWidth = sprites.width;
  var drawHeight = sprites.height;
  if (drawWidth + x > width) {
    drawWidth = width - (x + 1);
  }
  if (drawHeight + y > height) {
    drawHeight = height - (y + 1);
  }
  return {type:'rect', surface:'anim', x:x, y:y, width:drawWidth, height:drawHeight, strokeStyle:'red'};
}, addHighlightComponent:function(cmp) {
  cmp = cmp === void 0 ? {} : cmp;
  var targetCmp = this.imageMap.up();
  var $jscomp$destructuring$var70 = $jscomp.makeIterator(this.imageMap.getXY());
  var x = $jscomp$destructuring$var70.next().value;
  var y = $jscomp$destructuring$var70.next().value;
  targetCmp.add(Object.assign(cmp, {x:x, y:y, width:this.imageMap.getWidth(), height:this.imageMap.getHeight()}));
}, prepareHotSpots:function(workFlowMetaData) {
  var $jscomp$this = this;
  if (workFlowMetaData) {
    var $jscomp$destructuring$var71 = workFlowMetaData;
    var WorkFlowType = $jscomp$destructuring$var71.WorkFlowType;
    var WorkFlowModules = $jscomp$destructuring$var71.WorkFlowModules;
    this.getViewModel().set('workFlowType', WorkFlowType);
    if (Array.isArray(WorkFlowModules)) {
      return WorkFlowModules.map(function(module) {
        return $jscomp$this.prepareHotSpot(module);
      });
    }
  }
  return [];
}, prepareDataLinkasHotSpot:function(datalinks, hotspots) {
  var hotspot = {name:'', id:datalinks[0].WorkflowLinkId, x1:datalinks[0].LinkCoordinates.x1, y1:datalinks[0].LinkCoordinates.y1, x2:datalinks[0].LinkCoordinates.x2, y2:datalinks[0].LinkCoordinates.y2};
  Ext.applyIf(hotspot, {WorkflowLink:datalinks});
  hotspots.push(hotspot);
}, prepareConnectionLineLinkAsHotSpot:function(connectionLinks, hotspots) {
  var tempHotspotMap = {};
  Ext.Array.each(connectionLinks, function(connectionLink) {
    if (!tempHotspotMap[connectionLink.ConnectionLineKey]) {
      tempHotspotMap[connectionLink.ConnectionLineKey] = [];
      tempHotspotMap[connectionLink.ConnectionLineKey].push(connectionLink);
    } else {
      tempHotspotMap[connectionLink.ConnectionLineKey].push(connectionLink);
    }
  });
  if (Object.keys(tempHotspotMap).length > 0) {
    Object.keys(tempHotspotMap).forEach(function(eachKey) {
      var temp = {name:'', id:eachKey, x1:tempHotspotMap[eachKey][0].LinkCoordinates.x1, y1:tempHotspotMap[eachKey][0].LinkCoordinates.y1, x2:tempHotspotMap[eachKey][0].LinkCoordinates.x2, y2:tempHotspotMap[eachKey][0].LinkCoordinates.y2};
      Ext.applyIf(temp, {WorkflowLink:tempHotspotMap[eachKey]});
      hotspots.push(temp);
    });
  }
}, prepareHotSpot:function(module) {
  var workFlowType = this.getViewModel().get('workFlowType');
  var x1, y1, x2, y2;
  x1 = Number(module.StyleSheet.xPos);
  y1 = Number(module.StyleSheet.yPos);
  if (workFlowType) {
    if (workFlowType in documentation.ModuleDimentions) {
      if (documentation.ModuleDimentions[workFlowType][module.ModuleType]) {
        x2 = Number(module.StyleSheet.xPos) + documentation.ModuleDimentions[workFlowType][module.ModuleType].width;
        y2 = Number(module.StyleSheet.yPos) + documentation.ModuleDimentions[workFlowType][module.ModuleType].height;
      } else if (workFlowType === 'technical') {
        x2 = Number(module.StyleSheet.xPos) + 60;
        y2 = Number(module.StyleSheet.yPos) + 45;
      } else {
        x2 = Number(module.StyleSheet.xPos) + 100;
        y2 = Number(module.StyleSheet.yPos) + 60;
      }
    }
  } else {
    x2 = Number(module.StyleSheet.xPos) + 100;
    y2 = Number(module.StyleSheet.yPos) + 60;
  }
  if (module.StyleSheet.width) {
    x2 = x1 + Number(module.StyleSheet.width);
  }
  if (module.StyleSheet.height) {
    y2 = y1 + Number(module.StyleSheet.height);
  }
  var hotspot = {name:module.ModuleName, type:module.ModuleType, typeProp:module.ModuleTypeProp, wfType:module.WorkFlowType, id:module.ModuleId, x1:x1, y1:y1, x2:x2, y2:y2};
  if (module.MetaData) {
    Ext.applyIf(hotspot, {MetaData:module.MetaData});
    Ext.applyIf(hotspot, {metaDataNew:module.metaDataNew});
  }
  if (module.WorkflowLink) {
    Ext.applyIf(hotspot, {WorkflowLink:module.WorkflowLink});
  }
  if (module.Comment) {
    Ext.applyIf(hotspot, {Comment:module.Comment});
  }
  return hotspot;
}, callIs:function(requestCfg) {
  requestCfg = requestCfg === void 0 ? {} : requestCfg;
  return Ext.Ajax.request(requestCfg).then(function(response, opts) {
    return response || {};
  }, function(response, opts) {
    return response;
  });
}, lastXmlString:'', loadImageMeta:function(imageName) {
  var $jscomp$this = this;
  var $jscomp$destructuring$var72 = $jscomp.makeIterator(imageName.split('?'));
  var cacheKey = $jscomp$destructuring$var72.next().value;
  var langQueryParam = $jscomp$destructuring$var72.next().value;
  var data = documentation.util.Cache.get(cacheKey);
  if (data) {
    return Promise.resolve(data);
  }
  return new Promise(function(resolve) {
    $jscomp$this.callIs({url:documentation.Module.moduleBaseUrl() + 'getPictureMeta/' + encodeURIComponent($jscomp$this.moduleId) + '/' + encodeURI(documentation.Module.replaceSpace(imageName))}).then(function(response) {
      var $jscomp$destructuring$var73 = response;
      var responseXML = $jscomp$destructuring$var73.responseXML;
      if (responseXML) {
        $jscomp$this.openXmlMetaBtn.setDisabled(false);
      }
      return $jscomp$this.constructWorkFlowResponse(responseXML);
    }).then(function(dataOrNull) {
      if (dataOrNull === null) {
        throw new Error('data tx error, data null');
      }
      documentation.util.Cache.add(cacheKey, dataOrNull);
      resolve(dataOrNull);
    }, function(response) {
      throw new Error('request error');
    });
  });
}, readImageSize:function() {
  try {
    this.setLoading(false);
    this.originalImgWidth = this.img.width;
    this.originalImgHeight = this.img.height;
    try {
      if (this.rotation === 90 || this.rotation === 270) {
        this.imageMapWrapper.setSize(this.originalImgHeight, this.originalImgWidth);
      } else {
        this.imageMapWrapper.setSize(this.originalImgWidth, this.originalImgHeight);
      }
    } catch (e) {
    }
    this.getViewModel().set('isScaled', false);
  } catch (e$8) {
  }
}, doGet:function(xml, elemName) {
  return Array.from(xml.getElementsByTagName(elemName));
}, constructWorkFlowResponse:function(xml) {
  try {
    var workFlowsArr = this.doGet(xml, 'Workflows');
    var workFlowObj = {};
    for (var i = 0; i < workFlowsArr.length; i++) {
      var workflowGroupArr = workFlowsArr[i].getElementsByTagName('WorkflowGroup');
      for (var j = 0; j < workflowGroupArr.length; j++) {
        var workFlowArr = workflowGroupArr[j].getElementsByTagName('Workflow');
        for (var k = 0; k < workFlowArr.length; k++) {
          workFlowObj = {'Workflow':this.getWorkFlowObject(workFlowArr[k]), 'DataLinks':this.getDataLinks(workFlowArr[k]), 'ConnectionLineLinks':this.getConnectionLineLinks(workFlowArr[k])};
        }
      }
    }
    return {data:workFlowObj, xml:this.dataToString(xml)};
  } catch (e) {
    return null;
  }
}, maybeTextForElement:function(element) {
  return element ? element.innerHTML : '';
}, getWorkFlowObject:function(workFlowArr) {
  return {'WorkFlowType':workFlowArr.getAttribute('workflowType'), 'WorkFlowName':this.maybeTextForElement(workFlowArr.getElementsByTagName('WorkFlowName')[0]), 'WorkflowUId':this.maybeTextForElement(workFlowArr.getElementsByTagName('WorkflowUId')[0]), 'Comment':this.getComment(workFlowArr), 'IsActive':this.maybeTextForElement(workFlowArr.getElementsByTagName('IsActive')[0]), 'WorkFlowGroupName':this.maybeTextForElement(workFlowArr.getElementsByTagName('WorkFlowGroupName')[0]), 'LastCheckinUser':'', 
  'LastCheckinDateTime':'', 'Owner':'', 'WorkFlowModules':this.getWorkFlowModules(workFlowArr)};
}, getDataLinks:function(workFlowArr) {
  var dataLinksArr = [];
  var dataLinks = workFlowArr.getElementsByTagName('DataLink');
  var language = documentation.Module.language;
  for (var i = 0; i < dataLinks.length; i++) {
    var WorkflowDisplayName = dataLinks[i].getElementsByTagName('WorkflowName')[0].getAttribute(language);
    if (!WorkflowDisplayName) {
      WorkflowDisplayName = this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowName')[0]);
    }
    var WorkflowGroupDisplayName = dataLinks[i].getElementsByTagName('WorkflowGroup')[0].getAttribute(language);
    if (!WorkflowGroupDisplayName) {
      WorkflowGroupDisplayName = this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowGroup')[0]);
    }
    var isBackLink = false;
    if (dataLinks[i].getAttribute('isBacklink') != null) {
      isBackLink = dataLinks[i].getAttribute('isBacklink');
    }
    dataLinksArr.push({'WorkflowLinkId':this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowLinkId')[0]), 'WorkflowName':this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowName')[0]), 'WorkflowDisplayName':WorkflowDisplayName, 'WorkflowType':this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowType')[0]), 'WorkflowGroup':this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowGroup')[0]), 'WorkflowGroupDisplayName':WorkflowGroupDisplayName, 
    'WorkflowUserGroups':this.maybeTextForElement(dataLinks[i].getElementsByTagName('WorkflowUserGroups')[0]), 'TargetModuleID':this.getTargetModuleId(dataLinks[i]), 'LinkCoordinates':{'x1':0, 'y1':0, 'x2':documentation.ModuleDimentions['link']['datalink'].width, 'y2':documentation.ModuleDimentions['link']['datalink'].height}, 'LinkType':'DataLink', 'isBacklink':isBackLink});
  }
  return dataLinksArr;
}, getConnectionLineLinks:function(workFlowArr) {
  var connectionLineLinksArray = [];
  var connectionLineLink = workFlowArr.getElementsByTagName('ConnectionLineLink');
  var language = documentation.Module.language;
  for (var i = 0; i < connectionLineLink.length; i++) {
    var WorkflowDisplayName = connectionLineLink[i].getElementsByTagName('WorkflowName')[0].getAttribute(language);
    if (!WorkflowDisplayName) {
      WorkflowDisplayName = this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowName')[0]);
    }
    var WorkflowGroupDisplayName = connectionLineLink[i].getElementsByTagName('WorkflowGroup')[0].getAttribute(language);
    if (!WorkflowGroupDisplayName) {
      WorkflowGroupDisplayName = this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowGroup')[0]);
    }
    var lineLinkCoordinates = this.getPositionForConnectionLink(connectionLineLink[i]);
    var key = 'LineLink_' + connectionLineLink[i].getElementsByTagName('ToModule')[0].getAttribute('id') + '_From_' + connectionLineLink[i].getElementsByTagName('FromModule')[0].getAttribute('id');
    var TargetModuleID = this.getTargetModuleId(connectionLineLink[i]);
    var isBackLink = false;
    if (connectionLineLink[i].getAttribute('isBacklink') != null) {
      isBackLink = connectionLineLink[i].getAttribute('isBacklink');
    }
    connectionLineLinksArray.push({'WorkflowLinkId':this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowLinkId')[0]), 'WorkflowName':this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowName')[0]), 'WorkflowDisplayName':WorkflowDisplayName, 'WorkflowType':this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowType')[0]), 'WorkflowGroup':this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowGroup')[0]), 'WorkflowGroupDisplayName':WorkflowGroupDisplayName, 
    'WorkflowUserGroups':this.maybeTextForElement(connectionLineLink[i].getElementsByTagName('WorkflowUserGroups')[0]), 'LinkCoordinates':lineLinkCoordinates, 'ConnectionLineKey':key, 'TargetModuleID':TargetModuleID, 'LinkType':'ConnectionLineLink', 'isBacklink':isBackLink});
  }
  return connectionLineLinksArray;
}, getPositionForConnectionLink:function(connectionLineLink) {
  var toModuleStylesheet = connectionLineLink.getElementsByTagName('ToModule')[0].getElementsByTagName('StyleSheet')[0];
  var fromModuleStylesheet = connectionLineLink.getElementsByTagName('FromModule')[0].getElementsByTagName('StyleSheet')[0];
  var toX = Number(toModuleStylesheet.getAttribute('xPos'));
  var toY = Number(toModuleStylesheet.getAttribute('yPos')) + documentation.ModuleDimentions['technical']['technical'].height / 2;
  var fromX = Number(fromModuleStylesheet.getAttribute('xPos')) + documentation.ModuleDimentions['technical']['technical'].width;
  var fromY = Number(fromModuleStylesheet.getAttribute('yPos')) + documentation.ModuleDimentions['technical']['technical'].height / 2;
  var x;
  var y;
  if (toX > fromX) {
    x = fromX + Math.abs((fromX - toX) / 2);
  } else {
    x = fromX - Math.abs((fromX - toX) / 2);
  }
  if (toY > fromY) {
    y = fromY + Math.abs((fromY - toY) / 2);
  } else {
    y = fromY - Math.abs((fromY - toY) / 2);
  }
  return {'x1':x - 10, 'x2':x + 10, 'y1':y - 10, 'y2':y + 10};
}, getComment:function(node) {
  var comment = '';
  if (!node) {
    return comment;
  }
  var language = documentation.Module.language;
  var commentsNode = node.childNodes;
  var commentNodeIndex;
  for (var i = 0; i < commentsNode.length; i++) {
    if (commentsNode[i].tagName === 'Comments') {
      var properties = commentsNode[i].getElementsByTagName('Property');
      for (var j = 0; j < properties.length; j++) {
        if (properties[j].getAttribute('name') == language) {
          comment = properties[j].innerHTML;
          break;
        }
      }
    } else if (commentsNode[i].tagName === 'Comment') {
      commentNodeIndex = i;
    }
    if (comment.trim() !== '') {
      break;
    }
  }
  if (comment.trim() === '' && commentNodeIndex !== undefined) {
    comment = node.childNodes[commentNodeIndex].innerHTML;
  }
  return comment;
}, getModuleName:function(node) {
  var moduleName = '';
  if (!node) {
    return moduleName;
  }
  var language = documentation.Module.language;
  var moduleNameNode = node.childNodes;
  var moduleNameNodeIndex;
  for (var i = 0; i < moduleNameNode.length; i++) {
    if (moduleNameNode[i].tagName === 'ModuleNames') {
      var properties = moduleNameNode[i].getElementsByTagName('Property');
      for (var j = 0; j < properties.length; j++) {
        if (properties[j].getAttribute('name') == language) {
          moduleName = properties[j].innerHTML;
          break;
        }
      }
    } else if (moduleNameNode[i].tagName === 'ModuleName') {
      moduleNameNodeIndex = i;
    }
    if (moduleName.trim() !== '') {
      break;
    }
  }
  if (moduleName.trim() === '' && moduleNameNodeIndex !== undefined) {
    moduleName = node.childNodes[moduleNameNodeIndex].innerHTML;
  }
  return moduleName;
}, getConnectionInformation:function(connection, workflowType) {
  if (workflowType === 'bpd') {
    var connectionType = connection.getAttribute('type');
    var connectionSubType = '';
    var propertyArr = connection.getElementsByTagName('Property');
    for (var j = 0; j < propertyArr.length; j++) {
      var propertyName = propertyArr[j].getAttribute('name');
      if (propertyName === 'ConditionType' || propertyName === 'Direction') {
        connectionSubType = propertyArr[j].innerHTML;
        break;
      }
    }
    if (connectionType !== '') {
      return connectionType + connectionSubType;
    }
    return null;
  } else if (workflowType === 'processmap') {
    var propertyArrPm = connection.getElementsByTagName('Property');
    for (var k = 0; k < propertyArrPm.length; k++) {
      var propertyNamePm = propertyArrPm[k].getAttribute('name');
      if (propertyNamePm === 'Type') {
        return propertyArrPm[k].innerHTML;
      }
    }
    return null;
  } else if (workflowType === 'constraintsdiagram') {
    var connectionTypeCd = connection.getAttribute('type');
    if (connectionTypeCd === 'generalization') {
      return 'generalization';
    } else {
      var propertyArrCd = connection.getElementsByTagName('Property');
      for (var l = 0; l < propertyArrCd.length; l++) {
        var propertyNameCd = propertyArrCd[l].getAttribute('name');
        if (propertyNameCd === 'association') {
          return 'association';
        } else if (propertyNameCd === 'aggregation') {
          return 'aggregation';
        } else if (propertyNameCd === 'composition') {
          return 'composition';
        }
      }
    }
    return null;
  }
}, getWorkFlowModules:function(workFlowArr) {
  var $jscomp$this = this;
  var workFlowModuleArr = [];
  var workFlowModule = workFlowArr.getElementsByTagName('WorkflowModule');
  var workflowType = workFlowArr.getAttribute('workflowType');
  for (var i = 0; i < workFlowModule.length; i++) {
    var moduleTypeProp = '';
    var connectionTypeProp = [];
    var moduleType = workFlowModule[i].getAttribute('moduleType');
    var connectionArr = workFlowModule[i].getElementsByTagName('Connection');
    for (var q = 0; q < connectionArr.length; q++) {
      var connectionProp = this.getConnectionInformation(connectionArr[q], workflowType);
      if (connectionProp !== undefined && connectionProp !== null) {
        connectionTypeProp.push(connectionProp);
      }
    }
    if (workflowType === 'bpd') {
      var propertyArr = workFlowModule[i].getElementsByTagName('Property');
      for (var j = 0; j < propertyArr.length; j++) {
        var propertyName = propertyArr[j].getAttribute('name');
        if (propertyName === 'TriggeredByEvent' && moduleType === 'SubProcess' && propertyArr[j].innerHTML === 'true') {
          moduleTypeProp = 'Event';
        }
        if (moduleType === 'Gateway' && propertyName === 'GatewayType') {
          moduleTypeProp = propertyArr[j].innerHTML;
        }
        if ((moduleType === 'StartEvent' || moduleType === 'IntermediateEvent') && propertyName === 'TriggerType') {
          moduleTypeProp = propertyArr[j].innerHTML;
        }
        if (moduleType === 'Task' && propertyName === 'TaskType') {
          moduleTypeProp = propertyArr[j].innerHTML;
        }
        if (moduleType === 'StopEvent' && propertyName === 'ResultType') {
          moduleTypeProp = propertyArr[j].innerHTML;
        }
      }
    } else if (workflowType === 'technical') {
      moduleType = workFlowModule[i].getAttribute('technicalModuleType');
      if (moduleType === undefined || moduleType === null) {
        moduleType = workFlowModule[i].getAttribute('moduleType');
      }
    }
    var metaDataNew = void 0;
    try {
      var elem = workFlowModule[i];
      if (elem) {
        var $jscomp$destructuring$var74 = $jscomp.makeIterator(this.doGet(elem, 'Metadata'));
        var metadataElem = $jscomp$destructuring$var74.next().value;
        if (metadataElem) {
          metaDataNew = this.getPropertyDirectChildren(metadataElem).map(function(el) {
            return $jscomp$this.propertyToJson(el);
          });
        }
      }
    } catch (e) {
      metaDataNew = undefined;
    }
    workFlowModuleArr.push({metaDataNew:metaDataNew, 'ModuleId':this.maybeTextForElement(workFlowModule[i].getElementsByTagName('ModuleId')[0]), 'ModuleName':this.getModuleName(workFlowModule[i]), 'ModuleType':moduleType, 'Comment':this.getComment(workFlowModule[i]), 'WorkFlowType':workflowType, 'StyleSheet':{'xPos':workFlowModule[i].getElementsByTagName('StyleSheet')[0] ? workFlowModule[i].getElementsByTagName('StyleSheet')[0].getAttribute('xPos') : 0, 'yPos':workFlowModule[i].getElementsByTagName('StyleSheet')[0] ? 
    workFlowModule[i].getElementsByTagName('StyleSheet')[0].getAttribute('yPos') : 0, 'width':workFlowModule[i].getElementsByTagName('StyleSheet')[0] ? workFlowModule[i].getElementsByTagName('StyleSheet')[0].getAttribute('width') : null, 'height':workFlowModule[i].getElementsByTagName('StyleSheet')[0] ? workFlowModule[i].getElementsByTagName('StyleSheet')[0].getAttribute('height') : null}, 'ModuleTypeProp':moduleTypeProp, 'ConnectionType':connectionTypeProp, 'ModuleGroupName':'', 'IsActive':this.maybeTextForElement(workFlowModule[i].getElementsByTagName('IsActive')[0]), 
    'MetaData':this.getMetaData(workFlowModule[i]), 'WorkflowLink':this.allModulesToLink(workFlowModule[i])});
  }
  return workFlowModuleArr;
}, allModulesToLink:function(workFlowArr) {
  var workFlowModuleArr = [];
  var workFlowLink = workFlowArr.getElementsByTagName('WorkflowLink');
  var language = documentation.Module.language;
  for (var i = 0; i < workFlowLink.length; i++) {
    var WorkflowDisplayName = '';
    if (workFlowLink[i].getElementsByTagName('WorkflowName').length > 0) {
      if (workFlowLink[i].getElementsByTagName('WorkflowName')[0].getAttribute(language) == null) {
        WorkflowDisplayName = this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowName')[0]);
      } else {
        WorkflowDisplayName = workFlowLink[i].getElementsByTagName('WorkflowName')[0].getAttribute(language);
      }
    }
    var WorkflowGroupDisplayName = '';
    if (workFlowLink[i].getElementsByTagName('WorkflowGroup').length > 0) {
      if (workFlowLink[i].getElementsByTagName('WorkflowGroup')[0].getAttribute(language) == null) {
        WorkflowGroupDisplayName = this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowGroup')[0]);
      } else {
        WorkflowGroupDisplayName = workFlowLink[i].getElementsByTagName('WorkflowGroup')[0].getAttribute(language);
      }
    }
    var isBackLink = false;
    if (workFlowLink[i].getAttribute('isBacklink') != null) {
      isBackLink = workFlowLink[i].getAttribute('isBacklink');
    }
    var TargetModuleID = this.getTargetModuleId(workFlowLink[i]);
    workFlowModuleArr.push({'WorkflowLinkId':this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowLinkId')[0]), 'WorkflowName':this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowName')[0]), 'WorkflowDisplayName':WorkflowDisplayName, 'WorkflowType':this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowType')[0]), 'WorkflowGroup':this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowGroup')[0]), 'WorkflowGroupDisplayName':WorkflowGroupDisplayName, 
    'WorkflowUserGroups':this.maybeTextForElement(workFlowLink[i].getElementsByTagName('WorkflowUserGroups')[0]), 'TargetModuleID':TargetModuleID, 'LinkType':'Module', 'isBacklink':isBackLink});
  }
  var moduleProperties = workFlowArr.getElementsByTagName('Properties');
  for (var j = 0; j < moduleProperties.length; j++) {
    var moduleProperty = moduleProperties[j].getElementsByTagName('Property');
    for (var k = 0; k < moduleProperty.length; k++) {
      var propertyName = moduleProperty[k].getAttribute('name');
      if (propertyName == 'poollink') {
        var poolLinkProperties = moduleProperty[k].getElementsByTagName('Property');
        var wfName = '';
        var wfDisplayName = '';
        var workflowType = '';
        var moduleId = '';
        var workflowGroup = '';
        var workflowGroupDisplayName = '';
        var workflowUserGroups = '';
        var name;
        for (var l = 0; l < poolLinkProperties.length; l++) {
          name = poolLinkProperties[l].getAttribute('name');
          if (name == 'diagram') {
            wfName = this.maybeTextForElement(poolLinkProperties[l]);
            wfDisplayName = poolLinkProperties[l].getAttribute(language);
            if (!wfDisplayName) {
              wfDisplayName = wfName;
            }
          }
          if (name == 'type') {
            workflowType = this.maybeTextForElement(poolLinkProperties[l]);
          }
          if (name == 'moduleid') {
            moduleId = this.maybeTextForElement(poolLinkProperties[l]);
          }
          if (name == 'WorkflowGroup') {
            workflowGroup = this.maybeTextForElement(poolLinkProperties[l]);
            workflowGroupDisplayName = poolLinkProperties[l].getAttribute(language);
            if (!workflowGroupDisplayName) {
              workflowGroupDisplayName = workflowGroup;
            }
          }
          if (name == 'WorkflowUserGroups') {
            workflowUserGroups = this.maybeTextForElement(poolLinkProperties[l]);
          }
        }
        workFlowModuleArr.push({'WorkflowLinkId':moduleId, 'WorkflowName':wfName, 'WorkflowDisplayName':wfDisplayName, 'WorkflowType':workflowType, 'WorkflowGroup':workflowGroup, 'WorkflowGroupDisplayName':workflowGroupDisplayName, 'WorkflowUserGroups':workflowUserGroups, 'TargetModuleID':moduleId, 'LinkType':'Module', 'isBacklink':false});
      }
    }
  }
  return workFlowModuleArr;
}, getTextFromElem:function(elem) {
  return ((elem || {}).innerHTML || '').trim();
}, setLoading:function() {
  var $jscomp$destructuring$var75 = $jscomp.makeIterator(Array.from(arguments));
  var strOrBool = $jscomp$destructuring$var75.next().value;
  if (typeof strOrBool === 'string') {
    strOrBool = this.TR(strOrBool);
  }
  this.callParent([strOrBool]);
}, propertyToJson:function(propertyElem) {
  var $jscomp$this = this;
  var attributeNames = Array.from(propertyElem.getAttributeNames());
  var data = {};
  attributeNames.map(function(name) {
    data[name] = propertyElem.getAttribute(name);
  });
  var $jscomp$destructuring$var76 = data;
  var type = $jscomp$destructuring$var76.type;
  if (type === 'LinkToObject') {
    data.value = this.getTextFromElem(propertyElem);
  }
  if (type === 'I18NString') {
    data.values = this.getPropertyDirectChildren(propertyElem, 'Value').map(function(el) {
      var o = $jscomp$this.propertyToJson(el);
      o.value = $jscomp$this.getTextFromElem(el);
      return o;
    });
  }
  if (type === 'I18NDocumentExternal') {
    data.values = this.getPropertyDirectChildren(propertyElem, 'Value').map(function(el) {
      var o = $jscomp$this.propertyToJson(el);
      var $jscomp$destructuring$var77 = $jscomp.makeIterator($jscomp$this.getPropertyDirectChildren(el, 'ApplicationProfile').map(function(e) {
        var o = $jscomp$this.propertyToJson(e);
        o.value = $jscomp$this.getTextFromElem(e);
        return o;
      }));
      var ApplicationProfile = $jscomp$destructuring$var77.next().value;
      var $jscomp$destructuring$var78 = $jscomp.makeIterator($jscomp$this.getPropertyDirectChildren(el, 'Parameter').map(function(e) {
        var o = $jscomp$this.propertyToJson(e);
        o.value = $jscomp$this.getTextFromElem(e);
        return o;
      }));
      var Parameter = $jscomp$destructuring$var78.next().value;
      Object.assign(o, {ApplicationProfile:ApplicationProfile, Parameter:Parameter});
      o.value = $jscomp$this.getTextFromElem(el);
      return o;
    });
  }
  if (type === 'MultipleMetadata') {
    data.values = this.getPropertyDirectChildren(propertyElem).map(function(el) {
      return $jscomp$this.propertyToJson(el);
    });
  }
  return data;
}, getPropertyDirectChildren:function(elem, tagName) {
  tagName = tagName === void 0 ? 'Property' : tagName;
  return elem.hasChildNodes() ? Array.from(elem.childNodes).filter(function(elem) {
    return elem.tagName === tagName;
  }) : [];
}, getMetaData:function(workFlowModule) {
  var $jscomp$destructuring$var79 = $jscomp.makeIterator(this.doGet(workFlowModule, 'Metadata'));
  var metadataElem = $jscomp$destructuring$var79.next().value;
  var resultMetaData = [];
  if (metadataElem) {
    var propertyArr = metadataElem.getElementsByTagName('Property');
    var language = documentation.Module.language;
    for (var i = 0; i < propertyArr.length; i++) {
      var name = propertyArr[i].getAttribute('name.' + language);
      var type = propertyArr[i].getAttribute('type');
      var values = propertyArr[i].getElementsByTagName('Value');
      var value;
      var langIndex;
      if (values.length > 0) {
        langIndex = 0;
        for (var j = 0; j < values.length; j++) {
          if (values[j].getAttribute('lang') == language) {
            langIndex = j;
            break;
          }
        }
        if (type === 'I18NDocumentExternal') {
          if (values[langIndex].getElementsByTagName('Parameter').length == 0 && values[0].getElementsByTagName('Parameter').length == 0) {
            value = {'Parameter':'', 'OptionalName':''};
          } else {
            var parameter = values[langIndex].getElementsByTagName('Parameter').length == 0 ? values[0].getElementsByTagName('Parameter')[0] : values[langIndex].getElementsByTagName('Parameter')[0];
            value = {'Parameter':parameter.innerHTML, 'OptionalName':parameter.getAttribute('OptionalName') != null ? parameter.getAttribute('OptionalName') : ''};
          }
        } else {
          value = values[langIndex].innerHTML;
        }
      } else {
        if (type === 'LinkToObject') {
          var workflowName = propertyArr[i].getAttribute('modelName') == null ? '' : propertyArr[i].getAttribute('modelName');
          var workflowGroup = propertyArr[i].getAttribute('WorkflowGroup') == null ? '' : propertyArr[i].getAttribute('WorkflowGroup');
          value = {'WorkflowName':workflowName, 'WorkflowDisplayName':propertyArr[i].getAttribute('modelDisplayName') == null ? workflowName : propertyArr[i].getAttribute('modelDisplayName'), 'WorkflowType':propertyArr[i].getAttribute('WorkflowType') == null ? '' : propertyArr[i].getAttribute('WorkflowType'), 'WorkflowGroup':workflowGroup, 'WorkflowGroupDisplayName':propertyArr[i].getAttribute('WorkflowGroupDisplayName') == null ? workflowGroup : propertyArr[i].getAttribute('WorkflowGroupDisplayName'), 
          'WorkflowUserGroups':propertyArr[i].getAttribute('WorkflowUserGroups') == null ? '' : propertyArr[i].getAttribute('WorkflowUserGroups'), 'TargetModuleID':propertyArr[i].innerHTML};
        } else if (type === 'ExternalDocument') {
          value = {'Parameter':propertyArr[i].innerHTML, 'OptionalName':propertyArr[i].getAttribute('optionalName')};
        } else {
          value = propertyArr[i].innerHTML;
        }
      }
      if (!name || name.trim() == '') {
        name = propertyArr[i].getAttribute('name');
      }
      resultMetaData.push({'Name':name, 'Value':value, 'Type':type});
    }
  }
  return resultMetaData;
}, getTargetModuleId:function(workFlowLink) {
  var TargetModuleID = -1;
  if (workFlowLink.getElementsByTagName('TargetModuleId').length > 0) {
    TargetModuleID = this.maybeTextForElement(workFlowLink.getElementsByTagName('TargetModuleId')[0]);
  } else if (workFlowLink.getElementsByTagName('From').length > 0) {
    if (workFlowLink.getElementsByTagName('From')[0].innerHTML === workFlowLink.getElementsByTagName('To')[0].innerHTML) {
      TargetModuleID = this.maybeTextForElement(workFlowLink.getElementsByTagName('From')[0]);
    } else {
      TargetModuleID = 'LineLink_' + this.maybeTextForElement(workFlowLink.getElementsByTagName('To')[0]) + '_From_' + this.maybeTextForElement(workFlowLink.getElementsByTagName('From')[0]);
    }
  }
  return TargetModuleID;
}});
Ext.define('documentation.view.display.ImageInfo', {extend:'Ext.panel.Panel', alias:'widget.imageInfo', mixins:['documentation.mixins.Component'], moduleId:undefined, layout:{type:'vbox', align:'stretch'}, viewModel:{data:{metaData:undefined}}, initComponent:function() {
  this.title = this.TR('INFO');
  this.iconCls = this.faIcon('fa-info');
  this.items = [this.getInitContent()];
  this.callParent(arguments);
}, getInitContent:function() {
  return {padding:10, style:'display: flex;justify-content: center;align-items: center;', flex:1, html:this.TR('NO_DESC')};
}, doResetContent:function() {
  this.removeAll();
  this.add(this.getInitContent());
}, updateView:function() {
  var $jscomp$this = this;
  var metaData = this.getViewModel().get('metaData');
  if (metaData.hasOwnProperty('Comment') && !Ext.isEmpty(metaData.Comment)) {
    this.removeAll();
    this.add({padding:10, style:'display: flex;justify-content: center;align-items: center;', flex:1, html:'\x3cb\x3e' + BpcCommon.lang.Current.DOCUMENTATION_LABEL + '\x3c/b\x3e\x3cbr\x3e\x3cbr\x3e' + Ext.util.Format.htmlDecode(metaData.Comment)});
  } else {
    this.doResetContent();
  }
  var legendPanel = {xtype:'panel', itemId:'docuLegendContainer', iconCls:this.faIcon('fa-list-alt'), title:this.TR('DOCUMENTATION_LEGEND'), scrollable:true, layout:{type:'vbox', align:'stretch'}, collapsible:true, collapseDirection:'bottom', titleCollapse:true, animCollapse:false, defaults:{xtype:'panel'}, items:[]};
  var moduleCategories = [], modules = [], connectionCategories = [], connections = [];
  var moduleCategoriesPanels = {}, connectionCategoriesPanels = {};
  Ext.each(metaData.WorkFlowModules, function(module) {
    if (module.ModuleType === 'PoolLane') {
      module.ModuleType = 'PoolHorizontal';
    }
    var moduleIconProps = documentation.LegendIconMapping.getIconSrc(module);
    if (moduleIconProps && moduleCategories.indexOf(moduleIconProps.category) === -1) {
      moduleCategories.push(moduleIconProps.category);
      modules.push(moduleIconProps.text);
      moduleCategoriesPanels[moduleIconProps.category] = {layout:{type:'vbox', align:'stretch'}, collapsible:true, collapseDirection:'bottom', titleCollapse:true, animCollapse:false, header:{style:{backgroundColor:'lightgrey', color:'white', padding:'1px 5px'}, title:moduleIconProps.category}, items:[$jscomp$this.getLegendIcon(moduleIconProps)]};
    } else if (moduleIconProps && modules.indexOf(moduleIconProps.text) === -1) {
      modules.push(moduleIconProps.text);
      moduleCategoriesPanels[moduleIconProps.category].items.push($jscomp$this.getLegendIcon(moduleIconProps));
    }
    var connectionTypeFromModule = module.ConnectionType;
    for (var k = 0; k < connectionTypeFromModule.length; k++) {
      var connectionIconProps = documentation.LegendIconMapping.getConnectionIconSrc(module, connectionTypeFromModule[k]);
      if (connectionIconProps && connectionCategories.indexOf(connectionIconProps.category) === -1) {
        connectionCategories.push(connectionIconProps.category);
        connections.push(connectionIconProps.text);
        connectionCategoriesPanels[connectionIconProps.category] = {layout:{type:'vbox', align:'stretch'}, collapsible:true, collapseDirection:'bottom', titleCollapse:true, animCollapse:false, header:{style:{backgroundColor:'lightgrey', color:'white', padding:'1px 5px'}, title:connectionIconProps.category}, items:[$jscomp$this.getLegendIcon(connectionIconProps)]};
      } else if (connectionIconProps && connections.indexOf(connectionIconProps.text) === -1) {
        connections.push(connectionIconProps.text);
        connectionCategoriesPanels[connectionIconProps.category].items.push($jscomp$this.getLegendIcon(connectionIconProps));
      }
    }
  });
  if (!Ext.Object.isEmpty(moduleCategoriesPanels)) {
    Ext.Object.each(moduleCategoriesPanels, function(k, v) {
      legendPanel.items.push(v);
    });
  }
  if (!Ext.Object.isEmpty(connectionCategoriesPanels)) {
    Ext.Object.each(connectionCategoriesPanels, function(k, v) {
      legendPanel.items.push(v);
    });
  }
  this.add(legendPanel);
}, getLegendIcon:function(moduleProps) {
  return {xtype:'box', margin:'0 0 3 0', height:24, html:'\x3ctable\x3e \x3ctr\x3e \x3ctd\x3e \x3cimg src\x3d' + moduleProps.src + ' height \x3d "22"\x3e \x3c/td\x3e \x3ctd\x3e' + moduleProps.text + ' \x3c/td\x3e\x3c/tr\x3e \x3c/table\x3e'};
}});
Ext.define('documentation.view.display.ImageMap', {extend:'Ext.Img', alias:'widget.imageMap', mixins:['documentation.mixins.Component'], hotSpots:undefined, hotspot:undefined, wfModule:undefined, onHotspot:undefined, initComponent:function() {
  this.autoEl = Ext.apply({}, this.initialConfig, this.autoEl);
  this.moduleId = this.moduleInstance.moduleId;
  var $jscomp$destructuring$var80 = this.getSetting('ui_flags');
  var ignoreOpenEmptyModules = $jscomp$destructuring$var80.ignoreOpenEmptyModules;
  this.ignoreOpenEmptyModules = ignoreOpenEmptyModules;
  this.callParent();
  this.tooltip = Ext.create('Ext.tip.ToolTip', {html:''});
}, initEvents:function() {
  var imageElement = this.getEl();
  imageElement.on('click', this.onClick, this);
  imageElement.on('mousemove', this.onMouseMove, this);
  imageElement.on('contextmenu', this.onContextMenu, this);
}, onContextMenu:function(e) {
  var $jscomp$this = this;
  e.preventDefault();
  this.tooltip.hide();
  var links = documentation.Support.convertToLinkedDiagramData(this.wfModule.WorkflowLink || []);
  var linkMenuItems = links.map(function(item) {
    return {text:item.linkName, _item:item, handler:function(b) {
      $jscomp$this.moduleInstance.openDiagramByName(b._item.WorkflowDisplayName);
    }};
  });
  var menu = new Ext.menu.Menu({listeners:{boxready:function() {
    $jscomp$this.tooltip.hide();
  }}, items:[{text:this.getDialogHeader(), iconCls:this.faIcon('fa-info'), handler:function() {
    return $jscomp$this.openMetaWindow(true);
  }, tooltip:documentation.Support.getModuleName(this.wfModule)}, {xtype:'menuseparator'}, {text:this.TR('LINKED_DIAGRAMS'), iconCls:this.faIcon('fa-link'), disabled:links.length === 0, menu:linkMenuItems.length ? linkMenuItems : undefined}, {xtype:'menuseparator'}, {text:this.TR('CONTEXT_MENU_COPY_URL_TO_CLIPBOARD'), iconCls:this.faIcon('fa-copy'), handler:function() {
    var url = $jscomp$this.moduleInstance.displayTab.getLastUrl();
    url += '\x26moduleId\x3d' + $jscomp$this.wfModule.id;
    $jscomp$this.doCopy(url, 'URL_COPIED_SUCCESSFULLY');
  }}]});
  menu.showAt(e.getXY());
}, onMouseMove:function(e) {
  var me = this;
  me.onHotspot = false;
  var imageXYOffset = this.el.getXY();
  var xy = e.getXY();
  var x = xy[0] - imageXYOffset[0];
  var y = xy[1] - imageXYOffset[1];
  var smallerSpot;
  if (this.hotSpots) {
    var scale = this.moduleInstance.displayTab.zoomValue / 100;
    var hotspots = this.hotSpots.filter(function(hotspot) {
      return x >= hotspot.x1 * scale && x <= hotspot.x2 * scale && y >= hotspot.y1 * scale && y <= hotspot.y2 * scale;
    });
    if (hotspots.length > 1) {
      var small = hotspots[0].x2 - hotspots[0].x1;
      smallerSpot = hotspots[0];
      Ext.each(hotspots, function(spot) {
        if (spot.x2 - spot.x1 < small) {
          smallerSpot = spot;
          small = spot.x2 - spot.x1;
        }
      });
      me.hotspot = smallerSpot.name;
      me.wfModule = smallerSpot;
      me.onHotspot = true;
    } else {
      var $jscomp$destructuring$var81 = $jscomp.makeIterator(hotspots);
      var hotspot = $jscomp$destructuring$var81.next().value;
      if (hotspot) {
        me.hotspot = hotspot.name;
        me.wfModule = hotspot;
        me.onHotspot = true;
      }
    }
  }
  if (me.onHotspot) {
    var $jscomp$destructuring$var82 = this;
    var wfModule = $jscomp$destructuring$var82.wfModule;
    var changed = false;
    var $jscomp$destructuring$var83 = wfModule || {};
    var id = $jscomp$destructuring$var83.id;
    var type = $jscomp$destructuring$var83.type;
    if (id !== this.lastHotspotId) {
      this.lastHotspotId = id;
      changed = true;
    }
    this.el.setStyle('cursor', 'pointer');
    var $jscomp$destructuring$var84 = $jscomp.makeIterator(e.getXY());
    var x$9 = $jscomp$destructuring$var84.next().value;
    var y$10 = $jscomp$destructuring$var84.next().value;
    this.tooltip.setHtml(this.getDialogHeader());
    this.tooltip.showAt([x$9 + 15, y$10 - 15]);
  } else {
    this.el.setStyle('cursor', 'default');
    this.tooltip.hide();
  }
}, lastHotspotId:undefined, isElementEmpty:function() {
  var copy = Object.assign({}, this.wfModule);
  var $jscomp$destructuring$var85 = copy;
  var Comment = $jscomp$destructuring$var85.Comment;
  var metaDataNew = $jscomp$destructuring$var85.metaDataNew;
  var WorkflowLink = $jscomp$destructuring$var85.WorkflowLink;
  Comment = (Comment || '').trim();
  metaDataNew = metaDataNew || [];
  WorkflowLink = WorkflowLink || [];
  var visibleMetaData = documentation.util.Metadata.prepare(metaDataNew).filter(function(i) {
    return !i.hidden;
  });
  var links = documentation.Support.convertToLinkedDiagramData(WorkflowLink);
  return Comment.length === 0 && visibleMetaData.length === 0 && links.length === 0;
}, openMetaWindow:function(force) {
  force = force === void 0 ? false : force;
  if (this.onHotspot) {
    var canOpen = true;
    if (!force && this.ignoreOpenEmptyModules) {
      canOpen = !this.isElementEmpty();
    }
    if (canOpen) {
      this.tooltip.hide();
      documentation.Support.createMetaWindow(this, this.getDialogHeader());
    } else {
      documentation.Support.closeAllMetaDialogs();
    }
  }
}, onClick:function(e) {
  var $jscomp$this = this;
  var $jscomp$destructuring$var86 = this;
  var onHotspot = $jscomp$destructuring$var86.onHotspot;
  var hotspot = $jscomp$destructuring$var86.hotspot;
  var wfModule = $jscomp$destructuring$var86.wfModule;
  var moduleId = $jscomp$destructuring$var86.moduleId;
  var moduleInstance = $jscomp$destructuring$var86.moduleInstance;
  var metaContainer = moduleInstance.down('#metadataContainer');
  var fieldSets = Ext.ComponentQuery.query('fieldset[wfModuleId]');
  var showMetadata = this.getSetting('show_metadata');
  this.openMetaWindow();
  if (onHotspot) {
    if (showMetadata) {
      if (hotspot && wfModule && wfModule.MetaData) {
        if (metaContainer && metaContainer.isComponent) {
          metaContainer.expand();
          if (Array.isArray(fieldSets)) {
            Ext.Array.each(fieldSets, function(fieldSet) {
              if (fieldSet.wfModuleId === $jscomp$this.wfModule.id) {
                fieldSet.expand();
                if (fieldSet.el && fieldSet.el.dom) {
                  var listOffset = fieldSet.el.dom.offsetTop;
                  metaContainer.getScrollable().scrollTo(0, listOffset, true);
                }
              } else {
                fieldSet.collapse();
              }
            });
          }
        }
      }
    }
  }
}, getDialogHeader:function() {
  if (this.wfModule.WorkflowLink.length > 0 && (this.wfModule.WorkflowLink[0].LinkType === 'DataLink' || this.wfModule.WorkflowLink[0].LinkType === 'ConnectionLineLink')) {
    return this.TR('INFOS');
  } else {
    var moduleType = (documentation.LegendIconMapping.getModuleName(this) || '').trim();
    return moduleType.length ? moduleType : this.TR('MODULE_INFOS');
  }
}});
Ext.define('documentation.view.display.ImageThumbnail', {extend:'Ext.Container', alias:'widget.imageThumbnail', mixins:['documentation.mixins.Component'], layout:{type:'vbox', align:'center'}, width:250, height:210, style:{borderStyle:'solid', borderWidth:'medium', borderColor:'white', padding:'1px 15px', display:'inline-block', textAlign:'center'}, node:undefined, moduleId:undefined, initComponent:function() {
  var items = [];
  if (this.node) {
    var $jscomp$destructuring$var87 = this.getSetting('ui_flags') || {};
    var diagram_thumbnails_doNotLoad = $jscomp$destructuring$var87.diagram_thumbnails_doNotLoad;
    var diagram_thumbnails_titlePosition = $jscomp$destructuring$var87.diagram_thumbnails_titlePosition;
    diagram_thumbnails_titlePosition = diagram_thumbnails_titlePosition || 'bottom';
    var isLeaf = this.node.isLeaf();
    if (!isLeaf || diagram_thumbnails_doNotLoad) {
      this.height = 115;
      var iconCls = !isLeaf ? 'fa-folder fa-5x' : 'fa-file fa-4x';
      items.push(this.getSimpleItem(iconCls));
    } else {
      items.push({xtype:'container', layout:'fit', width:210, height:150, style:{borderStyle:'solid', borderWidth:'1px', borderColor:'lightgrey'}, items:[{xtype:'documentationImage', shrinkWrap:true, treeNode:this.node, moduleId:this.moduleId}]});
    }
    var titleItem = this.getTitleItem();
    var titleBottom = ['bottom', 'b', 'unten', 'down', undefined, null].indexOf(diagram_thumbnails_titlePosition) !== -1;
    items = titleBottom ? items.concat([titleItem]) : [titleItem].concat(items);
  }
  this.items = items;
  this.callParent(arguments);
}, splitLength:26, getTitleItem:function() {
  return {xtype:'box', html:'\x3cpre\x3e' + this.getDisplayTextFromNode() + '\x3c/pre\x3e'};
}, getDisplayTextFromNode:function() {
  var $jscomp$this = this;
  var diagramName = this.node.get('text') || '';
  if (diagramName.length > this.splitLength) {
    var parts = diagramName.split(' ');
    var name = '';
    return parts.map(function(part, i, array) {
      if ((name + part).length + i + 1 >= $jscomp$this.splitLength) {
        part = '\n' + part;
      }
      name += part;
      return part;
    }).join(' ');
  }
  return diagramName;
}, getSimpleItem:function(iconCls) {
  iconCls = iconCls === void 0 ? '' : iconCls;
  return {xtype:'box', style:{margin:'20px 0px 0px 0px'}, html:'\x3cspan class\x3d"' + this.faIcon(iconCls) + '" style\x3d"color: lightgrey"\x3e\x3c/span\x3e'};
}, open:function() {
  this.moduleInstance.openNodeTreeElem(this.node);
}, listeners:{el:{mouseover:function(e, el, eOpts) {
  this.el.setStyle('cursor', 'pointer');
  this.el.setStyle('border-color', '#ffefbb');
}, mouseout:function(e, el) {
  this.el.setStyle('border-color', 'white');
}, click:function(e, el) {
  this.component.open();
}}}});
Ext.define('documentation.view.display.MetaDataView', {extend:'Ext.panel.Panel', alias:'widget.documentationMetaDataView', header:false, mixins:['documentation.mixins.Component'], layout:{type:'vbox', align:'stretch'}, viewModel:{data:{metaData:undefined, hasMetaData:false}}, initComponent:function() {
  this.title = this.TR('METADATA');
  this.iconCls = this.faIcon('fa-clipboard-list');
  this.items = [this.getInitContent()];
  this.callParent();
}, getInitContent:function() {
  return {padding:10, style:'display: flex;justify-content: center;align-items: center;', flex:1, html:this.TR('NO_META')};
}, doResetContent:function() {
  this.removeAll();
  this.add(this.getInitContent());
}, updateView:function() {
  var $jscomp$this = this;
  try {
    this.removeAll();
    var metaContainer = {xtype:'panel', layout:'form', scrollable:true, flex:5, header:false, itemId:'metadataContainer', items:[]};
    var metaData = this.getViewModel().get('metaData');
    var dataLinks = this.getViewModel().get('DataLinks');
    var connectionLineLinks = this.getViewModel().get('ConnectionLineLinks');
    var itemArray = [];
    var workFlowModules = metaData.WorkFlowModules;
    console.log(workFlowModules);
    var $jscomp$destructuring$var88 = metaData;
    var WorkFlowModules = $jscomp$destructuring$var88.WorkFlowModules;
    WorkFlowModules = !Array.isArray(WorkFlowModules) ? [] : WorkFlowModules;
    var mData = WorkFlowModules.map(function(workflowModule) {
      var $jscomp$destructuring$var89 = workflowModule || {};
      var metaDataNew = $jscomp$destructuring$var89.metaDataNew;
      var ModuleName = $jscomp$destructuring$var89.ModuleName;
      var ModuleId = $jscomp$destructuring$var89.ModuleId;
      metaDataNew = metaDataNew || [];
      metaDataNew = documentation.util.Metadata.prepare(metaDataNew);
      return Object.assign({}, {metaDataNew:metaDataNew, ModuleName:ModuleName, ModuleId:ModuleId});
    });
    console.log(mData);
    this.add({xtype:'grid', flex:5, columns:[{dataIndex:'ModuleName', flex:1}], store:this.newLocalStore(mData), plugins:[{ptype:'rowwidget', widget:{xtype:'container', layout:'fit', items:[]}, _grid:this, onWidgetAttach:function(plugin, cmp, record) {
      cmp.removeAll();
      console.log(record);
      cmp.add({xtype:'grid', minHeight:120, hidden:$jscomp$this.metaDataHidden, flex:1, columns:[{text:$jscomp$this.TR('METADATA_NAME_TEXT'), dataIndex:'key'}, {flex:1, text:$jscomp$this.TR('METADATA_VALUE_TEXT'), dataIndex:'value', renderer:function(v) {
        return v;
      }}, {text:$jscomp$this.TR('METADATA_TYPE_TEXT'), dataIndex:'type'}], store:$jscomp$this.newLocalStore(record.get('metaDataNew'))});
    }}]});
    var hasMeta = false;
    var workflowLinksNew = [];
    if (workFlowModules && Ext.isArray(workFlowModules) && workFlowModules.length > 0) {
      var group, workflowLinks = [];
      Ext.Array.each(workFlowModules, function(dataItem) {
        if (dataItem.WorkflowLink) {
          Ext.each(dataItem.WorkflowLink, function(workflow) {
            if (workflowLinks.indexOf(workflow.WorkflowName) === -1) {
              workflowLinks.push(workflow.WorkflowName);
              workflowLinksNew.push(workflow);
            }
          });
        }
      }, this);
    }
    if (dataLinks) {
      Ext.each(dataLinks, function(dataLink) {
        workflowLinksNew.push(dataLink);
      });
    }
    if (connectionLineLinks) {
      Ext.each(connectionLineLinks, function(dataLink) {
        workflowLinksNew.push(dataLink);
      });
    }
    this.getViewModel().set('hasMetaData', hasMeta);
    this.add({xtype:'documentationLinkedDiagrams', workflowData:workflowLinksNew, minHeight:120, flex:1, collapsible:true, collapseDirection:'bottom', titleCollapse:true, animCollapse:false, listeners:{openWorkflow:function(c, recordData) {
      return $jscomp$this.openWorkflowLink(recordData);
    }}});
  } catch (e) {
    console.error('updateView', e);
  }
}, openWorkflowLink:function(workflow, targetModuleId) {
  this.moduleInstance.openDiagramByName(workflow.WorkflowDisplayName, targetModuleId);
}});
Ext.define('documentation.view.display.MetadataDialog', {extend:'documentation.components.Window', alias:'widget.documentationMetaWindow', layout:{type:'vbox', align:'stretch'}, overflow:'auto', scrollable:true, constrain:true, resizable:true, wfModule:undefined, parentCmp:undefined, initComponent:function() {
  var $jscomp$this = this;
  this.wfModule.WorkflowLink.sort(function(a, b) {
    return a.WorkflowDisplayName.localeCompare(b.WorkflowDisplayName);
  });
  var wfModule = Object.assign({}, this.wfModule);
  var workflowData = wfModule.WorkflowLink;
  var showMetaDataSettingValue = this.getSetting('show_metadata');
  var columns = this.getSetting('metadata_columns');
  var defaultColumns = ['key', 'value', 'type'];
  columns = columns || defaultColumns;
  var $jscomp$destructuring$var90 = wfModule || {};
  var metaDataNew = $jscomp$destructuring$var90.metaDataNew;
  var data = !Array.isArray(metaDataNew) ? [] : documentation.util.Metadata.prepare(metaDataNew);
  this.moduleId = this.moduleInstance.moduleId;
  this.store = this.newLocalStore(data);
  this.store.isEmptyFilterActive = false;
  if (this.getSetting('metadata_hide_unused')) {
    this.store.isEmptyFilterActive = true;
    this.store.filter([{property:'hidden', value:false}]);
  }
  this.metaDataHidden = showMetaDataSettingValue === false || this.store.getCount() === 0;
  this.createToolbars();
  this.items = [{xtype:'container', html:(Ext.htmlDecode(this.wfModule.Comment) || '').replaceAll('\n', '\x3cbr\x3e'), minHeight:100, padding:this.paddedIntString(5)}, {xtype:'splitter', hidden:this.metaDataHidden}, {xtype:'grid', minHeight:120, hidden:this.metaDataHidden, flex:1, columns:[{text:this.TR('METADATA_NAME_TEXT'), dataIndex:'key'}, {flex:1, text:this.TR('METADATA_VALUE_TEXT'), dataIndex:'value', renderer:function(v) {
    return v;
  }}, {text:this.TR('METADATA_TYPE_TEXT'), dataIndex:'type'}].filter(function(col) {
    var $jscomp$destructuring$var91 = col;
    var dataIndex = $jscomp$destructuring$var91.dataIndex;
    return columns.indexOf(dataIndex) !== -1;
  }), store:this.store}, {xtype:'documentationLinkedDiagrams', listeners:{openWorkflow:function(c, recordData) {
    return $jscomp$this.openWorkflowLink(recordData);
  }}, workflowData:workflowData}];
  this.listeners = {resize:function() {
    return $jscomp$this.saveLocal();
  }, move:function() {
    return $jscomp$this.saveLocal();
  }, boxready:function(c) {
    $jscomp$this.makeStateful('window');
    $jscomp$this.initHtmlLinks();
  }};
  this.callParent(arguments);
}, initHtmlLinks:function() {
  var $jscomp$this = this;
  try {
    this.delay(400).then(function() {
      var $jscomp$destructuring$var92 = $jscomp$this || {};
      var el = $jscomp$destructuring$var92.el;
      var $jscomp$destructuring$var93 = el || {};
      var dom = $jscomp$destructuring$var93.dom;
      if (dom) {
        var nodes = dom.querySelectorAll('a.documentation_linkToObject');
        Array.from(nodes).map(function(a) {
          a.addEventListener('click', function(e) {
            return $jscomp$this.onHtmlClick(e);
          });
        });
      }
    });
  } catch (e) {
    console.error('initHtmlLinks error', e);
  }
}, onHtmlClick:function(e) {
  try {
    var $jscomp$destructuring$var94 = e;
    var target = $jscomp$destructuring$var94.target;
    var $jscomp$destructuring$var95 = target;
    var dataset = $jscomp$destructuring$var95.dataset;
    var $jscomp$destructuring$var96 = dataset;
    var modelname = $jscomp$destructuring$var96.modelname;
    var moduleid = $jscomp$destructuring$var96.moduleid;
    var url = $jscomp$destructuring$var96.url;
    if (url) {
      window.open(url, '_blank');
      return;
    }
    this.openWorkflowLink({WorkflowDisplayName:modelname, TargetModuleID:moduleid});
  } catch (err) {
    console.error('onHtmlClick error', err);
  }
}, createToolbars:function() {
  var $jscomp$this = this;
  var topToolbar = this.defaultDockTb('top');
  Object.assign(topToolbar, {items:[{xtype:'displayfield', fieldLabel:' ', labelWidth:'auto', labelSeparator:'', value:['\x3cb\x3e', documentation.Support.getModuleName(this.wfModule), '\x3c/b\x3e'].join(''), ui:'primary'}, {xtype:'tbfill'}, {text:this.TR('REMOVE_METADATA_FILTER'), iconCls:this.faIcon('fa-remove'), ui:'secondary', hidden:this.metaDataHidden, handler:function(b) {
    if ($jscomp$this.store.isEmptyFilterActive) {
      $jscomp$this.store.clearFilter();
    } else {
      $jscomp$this.store.filter([{property:'hidden', value:false}]);
    }
    b.setText($jscomp$this.TR($jscomp$this.store.isEmptyFilterActive ? 'SET_METADATA_FILTER' : 'REMOVE_METADATA_FILTER'));
    b.setIconCls($jscomp$this.faIcon($jscomp$this.store.isEmptyFilterActive ? 'fa-filter' : 'fa-remove'));
    $jscomp$this.store.isEmptyFilterActive = !$jscomp$this.store.isEmptyFilterActive;
  }}, {iconCls:this.faIcon('fa-copy'), text:this.TR('URL_TO_DIAGRAM'), ui:'secondary', hidden:!this.parentCmp && !this.parentCmp.autoEl, handler:function() {
    var displayTab = $jscomp$this.parentCmp.up('documentationDisplayTab');
    var url = displayTab.getLastUrl();
    url += '\x26moduleId\x3d' + $jscomp$this.wfModule.id;
    $jscomp$this.doCopy(url, 'URL_COPIED_SUCCESSFULLY');
  }}]});
  var bottomToolbar = this.defaultDockTb('bottom');
  Object.assign(bottomToolbar, {items:[{xtype:'tbfill'}, {text:this.TR('CLOSE'), iconCls:this.faIcon('fa-times'), ui:'secondary', handler:function() {
    $jscomp$this.close();
  }}]});
  this.dockedItems = [topToolbar, bottomToolbar];
}, openWorkflowLink:function(workflow) {
  this.moduleInstance.openDiagramByName(workflow.WorkflowDisplayName, workflow.TargetModuleID);
}});
Ext.define('documentation.view.display.ThumbPreview', {extend:'Ext.panel.Panel', alias:'widget.documentationThumbPreview', mixins:['documentation.mixins.Component'], header:false, thumbComponents:undefined, loadSize:undefined, initComponent:function() {
  var $jscomp$this = this;
  var columns = !this.getSetting('show_metadata') ? 5 : 3;
  this.loadSize = columns;
  var userLoadSize = this.getSetting('loadSize');
  if (userLoadSize) {
    this.loadSize = userLoadSize;
  }
  this.layout = {type:'table', columns:columns, tableAttrs:{style:{borderCollapse:'separate', borderSpacing:'3em 3em'}}};
  this.defaults = {xtype:'imageThumbnail', moduleId:this.moduleId, moduleInstance:this.moduleInstance};
  var items = [];
  this.node.eachChild(function(child) {
    items.push({node:child});
  });
  this.items = items;
  this.listeners = {boxready:function() {
    return $jscomp$this.onBoxReady();
  }};
  this.callParent(arguments);
}, onBoxReady:function() {
  this.findAndSetAllImageComponents();
  this.loadImages();
}, loadImages:function() {
  var $jscomp$this = this;
  try {
    if (this.thumbComponents) {
      var cmps = this.getAllUnloadedImages();
      if (cmps) {
        var cmpsToLoad = this.loadSize === -1 ? cmps : cmps.slice(0, this.loadSize);
        var proms = cmpsToLoad.map(function(i) {
          return i.initImage();
        });
        Promise.all(proms).then(function() {
          $jscomp$this.loadImages();
        });
      }
    }
  } catch (e) {
  }
}, getAllUnloadedImages:function() {
  var notLoadedThumbs = this.thumbComponents.filter(function(i) {
    return i.imageLoaded === false && i.imageLoading === false;
  });
  return notLoadedThumbs.length ? notLoadedThumbs : undefined;
}, findAndSetAllImageComponents:function() {
  var thumbComponents = this.query('documentationImage');
  this.thumbComponents = thumbComponents.length === 0 ? undefined : thumbComponents;
}});
Ext.define('documentation.view.export.PollingWindow', {extend:'Ext.window.Window', mixins:['documentation.mixins.Component'], width:400, title:BpcCommon.Api.getTranslation('DOCUMENTATION_GENERATE_DOCUMENT'), layout:'fit', closable:false, initComponent:function() {
  this.failureCount = 0;
  this.polling = new Ext.util.DelayedTask(this.continuePolling, this);
  this.mainComponent = Ext.create({xtype:'form', labelWidth:120, bodyStyle:'padding: 15px;', labelAlign:'right', flex:1, hideLabels:true, items:[this.messageField = new Ext.form.DisplayField({value:this.TR('PROCESS_START')}), {xtype:'container', height:'10px'}, this.progressBar = new Ext.ProgressBar({}), {xtype:'container', height:'10px'}, this.cancelMessageField = new Ext.form.DisplayField({height:45, value:' '})]});
  this.progressBar.wait({increment:4, interval:2500});
  this.requestID = Ext.Ajax.request({url:this.url, timeout:600000, method:'POST', params:this.initialParams, scope:this, success:this.onInitialSuccess, failure:this.onInitialFailure});
  this.closeButton = Ext.create({xtype:'button', ui:'primary', text:this.TR('CLOSE'), scale:'medium', scope:this, handler:this.onClose});
  this.items = [this.mainComponent];
  this.bbar = [{xtype:'tbfill'}, this.closeButton];
  this.callParent(arguments);
  this.progressBar.wait({increment:4, interval:2500});
}, onClose:function() {
  try {
    if (!Ext.isEmpty(this.requestID)) {
      Ext.Ajax.abort(this.requestID);
      this.cancelled = true;
    }
    this.polling.cancel();
    this.up('window').close();
  } catch (e) {
    console.error('onClose', e);
  }
}, onSuccess:function(response, options) {
  try {
    this.requestID = '';
    if (!this.cancelled) {
      try {
        var d = Ext.decode(response.responseText);
        if (!d.success) {
          this.onFailure(response, options);
        } else {
          if (d.exists === 'true') {
            this.messageField.setValue(this.TR('PROCESS_COMPLETED'));
            this.callback.call(this.scope, this, true, response, this.params);
            this.close();
          } else if (d.error === 'true') {
            Ext.Msg.alert(this.TR('ERROR'), this.TR('GENERATE_DOCUMENT_ERROR'));
            this.close();
          } else {
            this.polling.delay(this.pollingInterval);
          }
        }
      } catch (e) {
        this.onFailure(response, options, e);
      }
    }
  } catch (e$11) {
    console.error('onSuccess', e$11);
  }
}, onFailure:function(response, options, e) {
  try {
    if (!this.cancelled) {
      this.failureCount++;
      if (this.failureCount === 10) {
        Ext.Msg.alert(this.TR('ERROR'), this.TR('SERVER_ERROR'));
        this.requestID = '';
        this.callback.call(this.scope, this, false, response, e);
        this.close();
      }
    }
  } catch (evt) {
    console.error('onFailure', e);
  }
}, onInitialFailure:function(response, options) {
  try {
    Ext.Msg.alert(this.TR('ERROR'), this.TR('GENERATE_DOCUMENT_ERROR'));
    this.close();
  } catch (e) {
    console.error('in init failure', e);
  }
}, onInitialSuccess:function(response, options) {
  try {
    var data = Ext.decode(response.responseText);
    if (data && data.success) {
      this.params = {operation:'canDownload', 'var.file':data.file};
      this.polling.delay(this.pollingInterval);
      this.messageField.setValue(this.TR('GENERATE_PROCESSING'));
      this.cancelMessageField.setValue(this.TR('GENERATE_DOCUMENT_FOR_DOWNLOAD'));
    } else {
      if (data && data.msg && data.msg !== '') {
        Ext.Msg.alert(this.TR('ERROR'), data.msg);
      } else {
        Ext.Msg.alert(this.TR('ERROR'), this.TR('GENERATE_DOCUMENT_ERROR'));
      }
    }
  } catch (e) {
    console.error('on init success', e);
  }
}, continuePolling:function() {
  this.requestID = Ext.Ajax.request({url:this.url, method:'POST', params:this.params, scope:this, success:this.onSuccess, failure:this.onFailure});
}});
Ext.define('documentation.view.export.ExportConfigPanel', {extend:'Ext.form.FormPanel', alias:'widget.exportConfig', requires:['documentation.view.export.PollingWindow'], controller:'exportConfigController', layout:{type:'vbox', align:'stretch'}, bodyStyle:{padding:'10px'}, localized:{title:'DOCUMENTATION_EXPORT_CONFIG'}, header:false, autoScroll:true, scrollable:true, defaults:{width:360}, viewModel:{data:{moduleOptionChecked:false, export_workflowspics:undefined, viewMode:false, generatedocHidden:false, 
saveConfigHidden:true}}, getCustomFields:function() {
  var data = [{'id':'en', 'name':BpcCommon.Api.getTranslation('EXPORT_CONFIGURATION_DROPDOWN_ENGLISH')}, {'id':'de', 'name':BpcCommon.Api.getTranslation('EXPORT_CONFIGURATION_DROPDOWN_GERMAN')}];
  return data;
}, initComponent:function(config) {
  var $jscomp$this = this;
  this.dockedItems = [{xtype:'toolbar', dock:'bottom', ui:'footer', defaults:{minWidth:65}, overflowHandler:'scroller', items:[{localized:{text:'DOCUMENTATION_GENERATE_DOCUMENT'}, formBind:true, iconCls:documentation.Support.faIcon('fa-file-pdf'), handler:'generateDocument', bind:{hidden:'{generatedocHidden}'}}, {localized:{text:'DOCUMENTATION_SAVE_CONFIG'}, iconCls:documentation.Support.faIcon('fa-save'), handler:'saveConfigPrompt', bind:{hidden:'{viewMode || saveConfigHidden}'}}, {localized:{text:'DOCUMENTATION_RESET'}, 
  iconCls:documentation.Support.faIcon('fa-undo'), handler:'reset', bind:{hidden:'{viewMode || saveConfigHidden}'}}]}];
  this.items = [{xtype:'tbspacer', height:20}, {xtype:'fieldset', localized:{title:'DOCUMENTATION_EXPORT_TEXT'}, labelWidth:110, layout:{type:'vbox', align:'stretch', pack:'start'}, items:[{xtype:'combo', labelWidth:95, labelAlign:'top', localized:{fieldLabel:'DOCUMENTATION_REPORT_LANGUAGE'}, valueField:'id', name:'reportLanguage', displayField:'name', value:documentation.Module.language === 'en' ? 'en' : 'de', mode:'local', triggerAction:'all', allowBlank:false, store:new Ext.data.Store({fields:['id', 
  'name'], data:this.getCustomFields()})}, {xtype:'combo', labelWidth:95, labelAlign:'top', localized:{fieldLabel:'DOCUMENTATION_DIAGRAM_LANGUAGES'}, valueField:'id', name:'diagramsLanguage', displayField:'name', value:documentation.Module.language === 'en' ? 'en' : 'de', mode:'local', triggerAction:'all', allowBlank:false, store:new Ext.data.Store({fields:['id', 'name'], data:this.getCustomFields()})}, {xtype:'textfield', labelAlign:'top', name:'fileName', bind:{readOnly:'{viewMode}'}, value:documentation.Support.exportName(), 
  width:250, regex:/^[A-Za-z0-9._-]*$/, localized:{regexText:'DOCUMENTATION_FILENAME_INVALID', fieldLabel:'DOCUMENTATION_FILE_NAME'}, allowBlank:false, stateful:true, stateEvents:['change'], stateId:'fileName_state'}]}, {xtype:'fieldset', localized:{title:'DOCUMENTATION_IMAGE_OPTIONS'}, labelWidth:110, layout:{type:'vbox', align:'stretch', pack:'start'}, items:[{xtype:'statefulCheckbox', fieldLabel:'', focusable:false, hideLabel:true, localized:{boxLabel:'DOCUMENTATION_IMAGE_COMMENTS'}, bind:{readOnly:'{viewMode}'}, 
  name:'export_diag_comments', checked:true, stateId:'export_diag_comments_state', inputValue:'true'}, {xtype:'statefulCheckbox', fieldLabel:'', focusable:false, hideLabel:true, localized:{boxLabel:'DOCUMENTATION_IMAGE_ILLUSTRATIONS'}, bind:{readOnly:'{viewMode}'}, name:'export_workflowspics', checked:true, inputValue:'true', stateId:'export_workflowspics_state', listeners:{change:function(cb, newValue) {
    $jscomp$this.getViewModel().set('export_workflowspics', newValue);
  }}}, {xtype:'combo', hideLabel:true, itemId:'imageScaleCombo', store:new Ext.data.Store({autoLoad:true, fields:['selectId', 'selectText'], data:[{selectId:1, selectText:BpcCommon.Api.getTranslation('DOCUMENTATION_SCALE_IMAGES')}, {selectId:2, selectText:BpcCommon.Api.getTranslation('DOCUMENTATION_SPLIT_IMAGES')}]}), name:'pictureScaling', valueField:'selectId', displayField:'selectText', mode:'local', triggerAction:'all', editable:false, allowBlank:false, hiddenName:'scale_diagramm_picture', bind:{disabled:'{!export_workflowspics}', 
  readOnly:'{viewMode}'}, value:0, stateful:true, stateEvents:['change'], stateId:'pictureScaling_state', listeners:{afterrender:function(cmp) {
    if (!cmp.getValue()) {
      cmp.setValue(cmp.getStore().getAt(0));
    }
  }}}]}, {xtype:'fieldset', localized:{title:'DOCUMENTATION_MODULE_OPTIONS'}, labelWidth:95, layout:{type:'vbox', align:'stretch', pack:'start'}, items:[{xtype:'statefulCheckbox', fieldLabel:'', focusable:false, hideLabel:true, localized:{boxLabel:'DOCUMENTATION_MODULE_LIST'}, bind:{readOnly:'{viewMode}'}, name:'export_modullist', stateId:'export_modullist_state', switchField:'export_modullist', inputValue:'true', listeners:{change:function(cb, newValue) {
    $jscomp$this.getViewModel().set('moduleOptionChecked', newValue);
  }}}, {xtype:'statefulCheckbox', fieldLabel:'', focusable:false, localized:{boxLabel:'DOCUMENTATION_MODULES_ONLY_WITH_METADATA'}, hideLabel:true, bind:{disabled:'{!moduleOptionChecked}', readOnly:'{viewMode}'}, name:'export_modul_emptyskipped', stateId:'export_modul_emptyskipped_state', checked:true, inputValue:'true'}, {xtype:'statefulCheckbox', fieldLabel:'', hideLabel:true, focusable:false, localized:{boxLabel:'DOCUMENTATION_GROUP_COMMENTS'}, bind:{disabled:'{!moduleOptionChecked}', readOnly:'{viewMode}'}, 
  name:'export_modul_associations', stateId:'export_modul_associations_state', checked:true, inputValue:'true'}, {xtype:'statefulCheckbox', fieldLabel:'', focusable:false, checked:false, inputValue:'true', localized:{boxLabel:'DOCUMENTATION_EXPORT_EDGES'}, bind:{disabled:'{!moduleOptionChecked}', readOnly:'{viewMode}'}, hideLabel:true, name:'export_edges', stateId:'export_edges_state'}]}, {xtype:'fieldset', localized:{title:'DOCUMENTATION_GENERAL_OPTIONS'}, layout:{type:'vbox', align:'stretch', pack:'start'}, 
  labelWidth:110, items:[{xtype:'textfield', localized:{fieldLabel:'DOCUMENTATION_DOCUMENT_TITLE'}, allowBlank:false, labelWidth:110, bind:{readOnly:'{viewMode}'}, width:250, name:'exportTitle', value:BpcCommon.Api.getTranslation('DOCUMENTATION_EXPORT_DOCUMENT_TITLE'), stateful:true, stateEvents:['change'], stateId:'exportTitle_state'}, {xtype:'textarea', localized:{fieldLabel:'DOCUMENTATION_INTRO_TEXT'}, allowBlank:true, labelWidth:110, bind:{readOnly:'{viewMode}'}, width:250, height:120, name:'introductionText', 
  value:'', stateful:true, stateEvents:['change'], stateId:'introductionText_state'}, {xtype:'statefulCheckbox', hideLabel:true, fieldLabel:'', focusable:false, bind:{readOnly:'{viewMode}'}, checked:true, boxLabel:BpcCommon.Api.getTranslation('DOCUMENTATION_RESOLVE_IMAGE_URL'), name:'resolv_img_urls', stateId:'resolv_img_urls_state', inputValue:'true'}, {xtype:'hiddenfield', name:'id'}]}];
  try {
    this.getViewModel().set('viewMode', false);
    if (this.getController().isSaveConfigAllowed()) {
      this.getViewModel().set('saveConfigHidden', false);
    }
  } catch (e) {
    console.error('init cmp', e);
  }
  this.callParent(arguments);
}});
Ext.define('documentation.view.export.ExportConfigPanelController', {extend:'Ext.app.ViewController', alias:'controller.exportConfigController', saveConfigPrompt:function(btn) {
  try {
    var me = this;
    var view = this.getView();
    Ext.create('Ext.window.MessageBox', {closeAction:'destroy'}).prompt(BpcCommon.Api.getTranslation('DOCUMENTATION_SAVE_CONFIG'), BpcCommon.Api.getTranslation('DOCUMENTATION_ENTER_CONFIG_NAME'), function(button, text) {
      if (button == 'ok') {
        if (!text) {
          me.saveConfigPrompt();
          return;
        }
        var configSetting = BpcCommon.Api.getSetting(view.moduleId, 'export_config', true);
        var existingConfigs = configSetting.get('value').configs;
        var alreadyExist = false;
        Ext.Array.each(existingConfigs, function(config, index, existingCfg) {
          if (config.id === text) {
            alreadyExist = true;
            return false;
          }
        });
        if (!alreadyExist) {
          me.saveConfig(text);
        } else {
          me.saveConfigPrompt();
          Ext.create('Ext.window.MessageBox', {closeAction:'destroy'}).alert('Error', BpcCommon.Api.getTranslation('DOCUMENTATION_CONFIG_ALREADY_EXISTS'));
        }
      }
    });
  } catch (e) {
    console.error('saveConfig error', e);
  }
}, isSaveConfigAllowed:function() {
  try {
    var view = this.getView();
    var configSetting = BpcCommon.Api.getSetting(view.moduleId, 'export_config', true);
    var isWriteable = configSetting.get('_writeable');
    if (isWriteable && isWriteable != undefined) {
      return true;
    }
    return false;
  } catch (e) {
    return false;
  }
}, saveConfig:function(configName) {
  try {
    var view = this.getView();
    var configSetting = BpcCommon.Api.getSetting(view.moduleId, 'export_config', true);
    var existingConfigs = configSetting.get('value').configs;
    var fields = view.getForm().getFields();
    var configObj = {id:configName};
    fields.each(function(field) {
      if (field.getName()) {
        configObj[field.getName()] = field.getValue();
      }
    });
    configObj.id = configName;
    existingConfigs.push(configObj);
    configSetting.save({failure:function(record, operation) {
      var errorResponse = JSON.parse(operation.getError().response.responseText);
      if (errorResponse) {
        BpcCommon.Api.showNotification({title:errorResponse.error.name, text:errorResponse.error.message, type:'ERROR', popUp:'true'});
      }
    }, success:function(record, operation) {
      Ext.GlobalEvents.fireEvent('exportConfigUpdated', record);
    }, callback:function(record, operation, success) {
    }});
  } catch (e) {
    console.error('saveConfig', e);
  }
}, reset:function() {
  this.getView().trgTree.setRootNode({nodeType:'async', text:BpcCommon.Api.getTranslation('DOCUMENTATION_REPORT_DIAGRAMS'), draggable:false, id:'targetDiagTree'});
}, generateDocument:function() {
  var view = this.getView();
  if (!view.trgTree.getRootNode().hasChildNodes()) {
    BpcCommon.Api.showNotification({text:BpcCommon.Api.getTranslation('DOCUMENTATION_NO_DIAGRAMS_SELECTED'), popUp:true, type:'ERROR'});
    return;
  }
  var tForm = view.getForm();
  var userGrps = [];
  var wfUser = [];
  if (tForm.isValid()) {
    var params = tForm.getFieldValues();
    var workflowNames = [];
    console.debug('params', params);
    view.trgTree.getRootNode().cascadeBy(function(node) {
      if (node.isLeaf()) {
        workflowNames.push(node.getData().text);
      }
      if (node.getData().userGroup && userGrps.indexOf(node.getData().userGroup) == -1) {
        userGrps.push(node.getData().userGroup);
      }
      if (node.getData().wfUser && wfUser.indexOf(node.getData().wfUser) == -1) {
        wfUser.push(node.getData().wfUser);
      }
    });
    var uniqueWorkflowNames = [].concat($jscomp.arrayFromIterable(new Set(workflowNames)));
    params.treeData = JSON.stringify(uniqueWorkflowNames);
    params.treeDataFormat = 'json';
    params.operation = 'createPDF';
    this.createPollingWindow(params, userGrps, wfUser);
  }
}, createPollingWindow:function(params, userGrps, wfUser) {
  var $jscomp$this = this;
  var pw = Ext.create('documentation.view.export.PollingWindow', {url:this.serverURL('PMRG_Aktionen', {'var.workflowGroup':userGrps.toString(), 'var.workflowUser':wfUser.toString(), 'var.fileName':params.fileName ? params.fileName : documentation.Support.exportName()}), initialParams:params, pollingInterval:params.treeData.length > 1000 ? 20000 : 10000, callback:function(options, success, response, data) {
    if (success) {
      var url = $jscomp$this.serverURL('PMRG_Download', {'var.file':data['var.file']});
      window.open(url, '_self');
    }
  }});
  pw.show();
}, serverURL:function(connector, params) {
  params = params === void 0 ? {} : params;
  try {
    var proxyId = BpcCommon.Api.getSetting(this.getView().moduleId, 'proxyId');
    var base = BpcCommon.Api.getBackendUrl(proxyId) + '/ibis/servlet/IBISHTTPUploadServlet/' + connector;
    return Ext.urlAppend(base, Ext.urlEncode(params));
  } catch (e) {
    console.error('serverUrl', e);
  }
}, loadData:function(data) {
  data = data === void 0 ? {} : data;
  try {
    var view = this.getView();
    if (Ext.isObject(data)) {
      view.getForm().getFields().each(function(field) {
        var fieldName = field.getName();
        if (fieldName) {
          field.setValue(data[fieldName]);
        }
      });
    }
  } catch (e) {
    console.log('error', e);
  }
}});
Ext.define('documentation.view.export.ExportConfigToolbar', {extend:'Ext.toolbar.Toolbar', alias:'widget.exportconfigtoolbar', mixins:['documentation.mixins.Component'], viewModel:{data:{}}, overflowHandler:'scroller', initComponent:function() {
  var $jscomp$this = this;
  this.callParent(arguments);
  Ext.on('exportConfigUpdated', function() {
    $jscomp$this.updateItems();
  });
}, updateItems:function() {
  var $jscomp$this = this;
  var $jscomp$destructuring$var97 = this.getSetting('export_config') || {};
  var configs = $jscomp$destructuring$var97.configs;
  configs = configs || [];
  var items = configs.map(function(config) {
    return {text:config.id, exportConfig:Ext.clone(config), handler:$jscomp$this.updateExportConfig};
  });
  this.removeAll();
  this.add(items);
}, updateExportConfig:function(btn) {
  try {
    var exportConfigView = Ext.first('exportConfig');
    if (exportConfigView && exportConfigView.isComponent) {
      exportConfigView.getController().loadData(btn.exportConfig);
    }
  } catch (e) {
    console.error('error', e);
  }
}});
Ext.define('documentation.view.export.ExportTab', {extend:'documentation.view.DiagramTree', controller:'exportTabController', itemId:'exportTab', localized:{title:'DOCUMENTATION_EXPORT'}, border:1, flex:1, reorder:true, autoScroll:true, containerScroll:true, reference:'targetDiagTree', root:{nodeType:'async', text:BpcCommon.Api.getTranslation('DOCUMENTATION_REPORT_DIAGRAMS'), draggable:false, id:'targetDiagTree'}, hideHeaders:true, columns:[{xtype:'treecolumn', flex:1, dataIndex:'text'}, {xtype:'actioncolumn', 
items:[{iconCls:'x-fal fa-trash', handler:'removeRecord', isDisabled:function(grid, rowIndex, colIndex, cmp, record) {
  return record.isRoot() && record.hasChildNodes() === false;
}}]}], listeners:{rowkeydown:'deleteOnDeleteKey', afterrender:'addDropTarget'}});
Ext.define('documentation.view.export.ExportTabPanelController', {extend:'Ext.app.ViewController', alias:'controller.exportTabController', addDropTarget:function(tree, eOpts) {
  this.dropTarget = tree.getEl();
  new Ext.dd.DropTarget(this.dropTarget, {ddGroup:'myDropGroup', notifyDrop:function(dd, e, data) {
    var node = data.records[0];
    if (node.parentNode && node.parentNode.isRoot()) {
      return false;
    } else {
      if (node.isLeaf()) {
        var alreadyExists = false;
        tree.getStore().each(function(record) {
          if (node.get('text') === record.get('text')) {
            alreadyExists = true;
            return false;
          }
        });
        if (!alreadyExists) {
          tree.addNodeToTree(node.copy(), null, tree.getRootNode());
        }
        return true;
      } else {
        tree.beforeNodeDrop(data, tree.getRootNode());
        return true;
      }
    }
    return false;
  }});
}, removeRecord:function(grid, rowIndex, colIndex, column, e, record, row) {
  if (!record.isRoot()) {
    record.remove();
  } else {
    var view = this.getView();
    view.setRootNode({nodeType:'async', text:BpcCommon.Api.getTranslation('DOCUMENTATION_REPORT_DIAGRAMS'), draggable:false, id:'targetDiagTree'});
  }
}, deleteOnDeleteKey:function(view, record, tr, rowIndex, e) {
  var tree = record.getOwnerTree();
  var nextSelection;
  if (record.isLast()) {
    nextSelection = record.previousSibling;
  } else {
    nextSelection = record.nextSibling;
  }
  if (e.keyCode === 46) {
    record.remove();
  }
  if (nextSelection) {
    tree.setSelection(nextSelection);
  }
}});
Ext.define('documentation.view.export.SelectChildrenToCopy', {extend:'Ext.window.Window', alias:'widget.docuSelectChildrenWindow', controller:'selectChildrenToCopyController', width:650, maxHeight:600, layout:'vbox', scrollable:true, localized:{title:'DOCUMENTATION_CHOOSE_DIAGRAM'}, srcNode:undefined, srcView:undefined, targetRoot:undefined, srcData:undefined, dropHandlers:undefined, viewModel:{data:{numberOfDiagramsSelected:0}, formulas:{diagramSelected:function(get) {
  var selected = false;
  if (get('numberOfDiagramsSelected') > 0) {
    selected = true;
  }
  return selected;
}}}, buttons:[{localized:{text:'DOCUMENTATION_SELECT_NONE'}, handler:'selectDeselectDiagrams'}, {localized:{text:'DOCUMENTATION_ADD_SELECTED_DIAGRAMS'}, bind:{disabled:'{!diagramSelected}'}, handler:'addSelectedDiagrams'}, {localized:{text:'CORE_CANCEL'}, handler:'closeWindow'}], initComponent:function() {
  var $jscomp$this = this;
  if (this.srcNode && this.srcView) {
    var fieldSet = {xtype:'fieldset', width:600, title:this.srcNode.get('text'), labelWidth:95, style:{margin:'0 0 0 15px'}, layout:{type:'vbox', align:'stretch', pack:'start'}, items:[]};
    if (this.srcNode.hasChildNodes()) {
      this.srcNode.eachChild(function(child) {
        var $jscomp$this = this;
        var childCheckBox = {xtype:'checkbox', fieldLabel:'', diagramId:child.id, hideLabel:true, boxLabel:child.get('text'), name:'selectedChildren', checked:false, inputValue:'true', listeners:{change:function(checkBox, newValue) {
          var numberOfDiagramsSelected = $jscomp$this.getViewModel().get('numberOfDiagramsSelected');
          if (newValue === true) {
            numberOfDiagramsSelected = numberOfDiagramsSelected + 1;
          } else {
            numberOfDiagramsSelected = numberOfDiagramsSelected - 1;
          }
          $jscomp$this.getViewModel().set('numberOfDiagramsSelected', numberOfDiagramsSelected);
        }}};
        fieldSet.items.push(childCheckBox);
      });
    } else {
      var wfType = this.srcNode.parentNode.data.wfType;
      var diagramNamelist = this.srcNode.data.nodeHref.split('/');
      Ext.Ajax.request({method:'GET', defaultHeaders:{'Content-Type':'application/x-www-form-urlencoded; charset\x3dUTF-8'}, params:{lang:documentation.Module.language}, url:documentation.Module.moduleBaseUrl() + encodeURIComponent(this.srcView.moduleId) + '/' + wfType + '/' + diagramNamelist[diagramNamelist.length - 1].split('?')[0].replace(/[ ]/g, '+'), success:function(response) {
        if (response && response.responseXML) {
          var process = response.responseXML.getElementsByTagName('Process');
          for (var i = 0; i < process.length; i++) {
            var processArr = {text:process[i].getAttribute('name'), name:process[i].getAttribute('name'), icon:'/bpc-fe-documentation/resources/icons/' + wfType + '.png', draggable:'true', nodeHref:process[i].getAttribute('href'), wfType:process[i].getAttribute('wfType'), leaf:true, userGroup:process[i].getAttribute('group'), wfUser:process[i].getAttribute('user'), type:'process'};
            $jscomp$this.srcNode.appendChild(processArr);
            var childCheckBox = {xtype:'checkbox', fieldLabel:'', diagramId:$jscomp$this.srcNode.getChildAt(i).id, hideLabel:true, boxLabel:process[i].getAttribute('name'), name:'selectedChildren', checked:false, inputValue:'true', listeners:{change:function(checkBox, newValue) {
              var numberOfDiagramsSelected = $jscomp$this.getViewModel().get('numberOfDiagramsSelected');
              if (newValue === true) {
                numberOfDiagramsSelected = numberOfDiagramsSelected + 1;
              } else {
                numberOfDiagramsSelected = numberOfDiagramsSelected - 1;
              }
              $jscomp$this.getViewModel().set('numberOfDiagramsSelected', numberOfDiagramsSelected);
            }}};
            fieldSet.items.push(childCheckBox);
          }
        }
      }, failure:function(response, opts) {
        console.error(' initComponent :  ERROR encountered while calling backend');
      }});
    }
    this.items = [fieldSet];
  }
  this.callParent(arguments);
}});
Ext.define('documentation.view.export.SelectChildrenToCopyController', {extend:'Ext.app.ViewController', alias:'controller.selectChildrenToCopyController', addAllDiagrams:function(btn) {
  var window = btn.up('window');
  var selectedDiagrams = [];
  var dropNode = window.srcNode.copy();
  dropNode.removeAll();
  dropNode.set('children', []);
  var checkBoxes = Ext.ComponentQuery.query('checkbox', window);
  if (checkBoxes && Ext.isArray(checkBoxes) && checkBoxes.length > 0) {
    Ext.each(checkBoxes, function(checkBox) {
      var diagram = window.srcNode.findChild('id', checkBox.diagramId);
      selectedDiagrams.push(diagram.copy());
      dropNode.appendChild(diagram.copy());
      dropNode.get('children').push(diagram.copy().getData());
    });
    if (window.targetRoot.hasChildNodes()) {
      var existingGroup = window.targetRoot.findChild('text', dropNode.get('text'));
      if (existingGroup && existingGroup.get('text') === dropNode.get('text')) {
        window.srcData.records = selectedDiagrams;
      } else {
        window.srcData.records[0] = dropNode;
      }
    } else {
      window.srcData.records[0] = dropNode;
    }
    window.close();
    if (window.dropHandlers) {
      window.dropHandlers.processDrop();
    } else {
      window.srcView.processNodeDrop(window.srcData, window.srcView.getRootNode());
    }
  }
}, selectDeselectDiagrams:function(btn) {
  var window = btn.up('window');
  var checkBoxes = Ext.ComponentQuery.query('checkbox', window);
  if (checkBoxes && Ext.isArray(checkBoxes) && checkBoxes.length > 0) {
    if (btn.getText() === BpcCommon.Api.getTranslation('DOCUMENTATION_SELECT_NONE')) {
      btn.setText(BpcCommon.Api.getTranslation('DOCUMENTATION_SELECT_ALL'));
      Ext.each(checkBoxes, function(checkBox) {
        var id = checkBox.id;
        Ext.getCmp(id).setValue(false);
      });
    } else if (btn.getText() === BpcCommon.Api.getTranslation('DOCUMENTATION_SELECT_ALL')) {
      btn.setText(BpcCommon.Api.getTranslation('DOCUMENTATION_SELECT_NONE'));
      Ext.each(checkBoxes, function(checkBox) {
        var id = checkBox.id;
        Ext.getCmp(id).setValue(true);
      });
    }
  }
}, addSelectedDiagrams:function(btn) {
  var window = btn.up('window');
  var selectedDiagrams = [];
  var dropNode = window.srcNode.copy();
  dropNode.removeAll();
  dropNode.set('children', []);
  var checkBoxes = Ext.ComponentQuery.query('checkbox', window);
  if (checkBoxes && Ext.isArray(checkBoxes) && checkBoxes.length > 0) {
    Ext.each(checkBoxes, function(checkBox) {
      if (checkBox.getValue() === true) {
        var diagram = window.srcNode.findChild('id', checkBox.diagramId);
        selectedDiagrams.push(diagram.copy());
        dropNode.appendChild(diagram.copy());
        dropNode.get('children').push(diagram.copy().getData());
      }
    });
    if (window.targetRoot.hasChildNodes()) {
      var existingGroup = window.targetRoot.findChild('text', dropNode.get('text'));
      if (existingGroup && existingGroup.get('text') === dropNode.get('text')) {
        window.srcData.records = selectedDiagrams;
      } else {
        window.srcData.records[0] = dropNode;
      }
    } else {
      window.srcData.records[0] = dropNode;
    }
    window.close();
    if (window.dropHandlers) {
      window.dropHandlers.processDrop();
    } else {
      window.srcView.processNodeDrop(window.srcData, window.srcView.getRootNode());
    }
  }
}, closeWindow:function(btn) {
  var window = btn.up('window');
  window.close();
  if (window.dropHandlers) {
    window.dropHandlers.cancelDrop();
  }
}});
